@@ -29,6 +29,8 @@
 #include "utils.h"
 #include "utils_gui.h"
 #include "utils_time.h"
+#include "utils_date.h"
+#include "utils_date_time.h"
 
 /*------------------------------------------------------------------------------*/
 
@@ -68,9 +70,9 @@ date_calculator_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer us
 void
 set_current_date (GtkWidget *year, GtkWidget *month, GtkWidget *day)
 {
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (year), utl_get_current_year ());
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (month), utl_get_current_month ());
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (day), utl_get_current_day ());
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (year), utl_date_get_current_year ());
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (month), utl_date_get_current_month ());
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (day), utl_date_get_current_day ());
 }
 
 /*------------------------------------------------------------------------------*/
@@ -219,98 +221,155 @@ reset_addsub_time_cb (GtkWidget *widget, gpointer user_data)
 
 /*------------------------------------------------------------------------------*/
 
+gint utl_calculate_weekend_days (GDate *f_date, GDate *s_date)
+{
+	gint st, en, nd, wd;
+
+	g_date_order (f_date, s_date);
+
+	st = g_date_get_weekday (f_date);
+	en = g_date_get_weekday (s_date);
+	nd = g_date_days_between (f_date, s_date);
+	wd = nd / 7 * 2;
+
+	if (st == G_DATE_SATURDAY) {
+
+		if (en == G_DATE_SATURDAY) wd += 1;
+		else wd += 2;
+
+	} else if (st == G_DATE_SUNDAY) {
+
+		if (en == G_DATE_SATURDAY) wd += 2;
+		else wd += 1;
+
+	} else {
+
+		if (en == G_DATE_SATURDAY) wd += 1;
+		else if (en == G_DATE_SUNDAY) wd += 2;
+		else if (st > en) wd += 2;
+
+	}
+
+	return wd;
+}
+
+/*============================================================================*/
+
 void
-set_result_cb (GtkWidget *widget, gpointer user_data)
+set_result_cb (GtkWidget *widget, GUI *appGUI)
 {
-	GUI *appGUI = (GUI *) user_data;
-	DATE date_from, date_to, date_diff;
-	TIME time_from, time_to, time_diff;
 	gint days, weeks;
 	guint64 hours, minutes, seconds;
 	gchar tmpbuf[BUFFER_SIZE];
+	gchar tmpbuf2[BUFFER_SIZE];
+	gint P, E, I;
+	gint we_d, working_days;
 
-    date_from.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_year));
-    date_from.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_month)) - 1;
-    date_from.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_day));
-    time_from.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour));
-    time_from.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute));
-    time_from.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_second));
+	gint dd, dm, dy, th, tm, ts;
+	GDate *date1, *date2;
+	TIME *time1, *time2;
 
-    days = g_date_get_days_in_month (date_from.month + 1, date_from.year);
-    if (date_from.day > days) {
-        date_from.day = days;
-        utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, COLOR_BG_FAIL, appGUI);
-    } else {
-        utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, NULL, appGUI);
-    }
+	dd = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_day));
+	dm = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_month));
+	dy = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_year));
+	th = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour));
+	tm = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute));
+	ts = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_second));
 
-    date_to.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_year));
-    date_to.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_month)) - 1;
-    date_to.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_day));
-    time_to.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_hour));
-    time_to.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_minute));
-    time_to.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_second));
+	if (utl_date_set_valid_dmy (&dd, dm, dy))
+		utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, COLOR_BG_FAIL, appGUI);
+	else
+		utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, NULL, appGUI);
 
-    days = g_date_get_days_in_month (date_to.month + 1, date_to.year);
-    if (date_to.day > days) {
-        date_to.day = days;
-        utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, COLOR_BG_FAIL, appGUI);
-    } else {
-        utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, NULL, appGUI);
-    }
+	date1 = g_date_new_dmy (dd, dm, dy);
+	time1 = utl_time_new_hms (th, tm, ts);
 
-    days = calculate_date_time_diff (date_from, time_from, date_to, time_to, &date_diff, &time_diff);
+	dd = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_day));
+	dm = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_month));
+	dy = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_year));
+	th = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_hour));
+	tm = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_minute));
+	ts = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_second));
 
-    if (days == -1)
-        days = calculate_date_time_diff (date_to, time_to, date_from, time_from, &date_diff, &time_diff);
+	if (utl_date_set_valid_dmy (&dd, dm, dy))
+		utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, COLOR_BG_FAIL, appGUI);
+	else
+		utl_gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, NULL, appGUI);
+
+	date2 = g_date_new_dmy (dd, dm, dy);
+	time2 = utl_time_new_hms (th, tm, ts);
+
+	utl_date_time_order (date1, time1, date2, time2);
+	days = g_date_days_between (date1, date2) - utl_time_subtract (time2, time1);
+	we_d = utl_calculate_weekend_days (date1, date2);
+
+	utl_date_diff (date1, date2, &dd, &dm, &dy);
+	utl_time_get_hms (time2, &th, &tm, &ts);
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%d %s, %d %s, %d %s</big>",
-	            date_diff.year, ngettext ("year", "years", date_diff.year),
-	            date_diff.month, ngettext ("month", "months", date_diff.month),
-	            date_diff.day, ngettext ("day", "days", date_diff.day));
+	            dy, ngettext ("year", "years", dy),
+	            dm, ngettext ("month", "months", dm),
+	            dd, ngettext ("day", "days", dd));
 	gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%d %s, %d %s, %d %s</big>",
-	            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
-	            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
-	            time_diff.second, ngettext ("second", "seconds", time_diff.second));
+	            th, ngettext ("hour", "hours", th),
+	            tm, ngettext ("minute", "minutes", tm),
+	            ts, ngettext ("second", "seconds", ts));
 	gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), tmpbuf);
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
 	            _("or"),
 	            days, ngettext ("day", "days", days),
-	            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
-	            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
-	            time_diff.second, ngettext ("second", "seconds", time_diff.second));
+	            th, ngettext ("hour", "hours", th),
+	            tm, ngettext ("minute", "minutes", tm),
+	            ts, ngettext ("second", "seconds", ts));
 	gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_2), tmpbuf);
 
-    seconds = (guint64)time_diff.second + (guint64)time_diff.minute * 60 +
-              (guint64)time_diff.hour * 3600 + (guint64)days * 24 * 3600;
-    minutes = seconds / 60;
-    hours = minutes / 60;
-    weeks = (gint)(hours / (24 * 7));
-	g_snprintf (tmpbuf, BUFFER_SIZE, "<small>%llu %s\n%llu %s (%s)\n%llu %s (%s)\n%d %s (%s)</small>",
+	seconds = (guint64) utl_time_get_seconds (time2) + (guint64) days * 24 * 3600;
+	minutes = seconds / 60;
+	hours = minutes / 60;
+	weeks = (gint) (hours / (24 * 7));
+	working_days = days - we_d + 1;
+	g_snprintf (tmpbuf, BUFFER_SIZE, "<small>%llu %s\n%llu %s (%s)\n%llu %s (%s)\n%d %s (%s)\n%d %s (%s)\n%d %s (%s)</small>",
 	            seconds, ngettext ("second", "seconds", seconds),
 	            minutes, ngettext ("minute", "minutes", minutes), _("rounded down"),
 	            hours, ngettext ("hour", "hours", hours), _("rounded down"),
-	            weeks, ngettext ("week", "weeks", weeks), _("rounded down"));
+	            weeks, ngettext ("week", "weeks", weeks), _("rounded down"),
+	            working_days, ngettext ("working day", "working days", working_days), _("time is ignored"),
+	            we_d, ngettext ("weekend day", "weekend days", we_d), _("time is ignored"));
+
+	if (appGUI->cal->datecal_bio == TRUE) {
+		P = 100.0 * sin (2.0 * M_PI * days / 23.0);
+		E = 100.0 * sin (2.0 * M_PI * days / 28.0);
+		I = 100.0 * sin (2.0 * M_PI * days / 33.0);
+		g_snprintf (tmpbuf2, BUFFER_SIZE,
+		            "<small>\n\nBiorhythms:\nPhysical: %d%%, Emotional: %d%%, Intellectual: %d%%</small>", P, E, I);
+		g_strlcat (tmpbuf, tmpbuf2, BUFFER_SIZE);
+	}
+
 	gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_3), tmpbuf);
+
+	g_date_free (date1);
+	g_date_free (date2);
+	utl_time_free (time1);
+	utl_time_free (time2);
 }
 
-/*------------------------------------------------------------------------------*/
+/*============================================================================*/
 
 void
-set_result2_cb (GtkWidget *widget, gpointer user_data)
+set_result2_cb (GtkWidget *widget, GUI *appGUI)
 {
-	GUI *appGUI = (GUI *) user_data;
 	gint year, month, day;
 	gint64 hour, minute, second;
 	gint year2, month2, week2, day2;
 	gint64 hour2, minute2, second2;
-	gint n;
-	guint32 julian;
-	gchar timebuf[BUFFER_SIZE];
-	gchar tmpbuf[BUFFER_SIZE];
+	gint n, ignore_weekend_days;
+	guint32 julian = 0;
+	gchar *str, *text;
+	GDate *s_date, *e_date;
+	gint wd_n = 0, wd_p;
 
     year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_year));
     month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_month)) - 1;
@@ -333,78 +392,126 @@ set_result2_cb (GtkWidget *widget, gpointer user_data)
         utl_gui_change_bg_widget_state (appGUI->cal->spinbutton2_start_day, NULL, appGUI);
     }
 
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->radiobutton_add)) == TRUE) {
-    /* add */
-        year += year2;
-        month += month2;
-        year += month / 12;
-        month %= 12;
+	ignore_weekend_days = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->ignore_weekend_days_checkbutton));
 
-        /* 31 January + one month = 28 or 29 February */
-        n = g_date_get_days_in_month (month + 1, year);
-        if (day > n) {
-            day = n;
-        }
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->radiobutton_add)) == TRUE) {
+	/* add */
+		if (ignore_weekend_days == TRUE) {
 
-        julian = utl_dmy_to_julian (day, month + 1, year);
+			s_date = g_date_new_dmy (day, month + 1, year);
+			e_date = g_date_new_dmy (day, month + 1, year);
+			wd_n = 0;
 
-        second += second2;
-        minute += minute2 + second / 60;
-        second %= 60;
-        hour += hour2 + minute / 60;
-        minute %= 60;
-        day2 += hour / 24;
-        hour %= 24;
+			if (day2 > 0) {
+				g_date_add_days (e_date, day2 - 1);
+				do {
+					wd_p = wd_n;
+					wd_n = utl_calculate_weekend_days (s_date, e_date);
+					g_date_add_days (e_date, wd_n - wd_p);
+				} while (wd_n - wd_p > 0);
+			}
 
-        julian += day2 + week2 * 7;
+			julian = g_date_get_julian (e_date);
 
-    } else {
-    /* subtract */
-        year = year - year2 - (month2 / 12);
-        month -= month2 % 12;
+			g_date_free (s_date);
+			g_date_free (e_date);
 
-        if (month < 0) {
-            year--;
-            month += 12;
-        }
+		} else {
 
-        if (year > 0) {
-            /* 31 March - one month = 28 or 29 February */
-            n = g_date_get_days_in_month (month + 1, year);
-            if (day > n) {
-                day = n;
-            }
+			year += year2;
+			month += month2;
+			year += month / 12;
+			month %= 12;
 
-            julian = utl_dmy_to_julian (day, month + 1, year);
+			/* 31 January + one month = 28 or 29 February */
+			n = g_date_get_days_in_month (month + 1, year);
+			if (day > n) {
+				day = n;
+			}
 
-            minute2 += second2 / 60;
-            second -= second2 % 60;
-            if (second < 0) {
-                minute--;
-                second += 60;
-            }
+			julian = utl_date_dmy_to_julian (day, month + 1, year);
 
-            hour2 += minute2 / 60;
-            minute -= minute2 % 60;
-            if (minute < 0) {
-                hour--;
-                minute += 60;
-            }
+			second += second2;
+			minute += minute2 + second / 60;
+			second %= 60;
+			hour += hour2 + minute / 60;
+			minute %= 60;
+			day2 += hour / 24;
+			hour %= 24;
 
-            day2 += hour2 / 24;
-            hour -= hour2 % 24;
-            if (hour < 0) {
-                julian--;
-                hour += 24;
-            }
+			julian += day2 + week2 * 7;
+		}
+	} else {
+	/* subtract */
+		if (ignore_weekend_days == TRUE) {
 
-            julian = julian - day2 - week2 * 7;
+			s_date = g_date_new_dmy (day, month + 1, year);
+			e_date = g_date_new_dmy (day, month + 1, year);
+			wd_n = 0;
 
-            if (!(g_date_valid_julian (julian))) {
-                year = 0;
-            }
-        }
-    }
+			if (day2 > 0) {
+				g_date_subtract_days (s_date, day2 - 1);
+				do {
+					wd_p = wd_n;
+					wd_n = utl_calculate_weekend_days (s_date, e_date);
+					g_date_subtract_days (s_date, wd_n - wd_p);
+				} while (wd_n - wd_p > 0);
+			}
+
+			julian = g_date_get_julian (s_date);
+
+			g_date_free (s_date);
+			g_date_free (e_date);
+
+		} else {
+
+			year = year - year2 - (month2 / 12);
+			month -= month2 % 12;
+
+			if (month < 0) {
+				year--;
+				month += 12;
+			}
+
+			if (year > 0) {
+				/* 31 March - one month = 28 or 29 February */
+				n = g_date_get_days_in_month (month + 1, year);
+				if (day > n) {
+					day = n;
+				}
+
+				julian = utl_date_dmy_to_julian (day, month + 1, year);
+
+				minute2 += second2 / 60;
+				second -= second2 % 60;
+				if (second < 0) {
+					minute--;
+					second += 60;
+				}
+
+				hour2 += minute2 / 60;
+				minute -= minute2 % 60;
+				if (minute < 0) {
+					hour--;
+					minute += 60;
+				}
+
+				day2 += hour2 / 24;
+				hour -= hour2 % 24;
+				if (hour < 0) {
+					julian--;
+					hour += 24;
+				}
+
+				julian = julian - day2 - week2 * 7;
+
+			}
+
+			if (!(g_date_valid_julian (julian))) {
+				year = 0;
+			}
+		}
+	}
 
 	if (year < 1) {
 
@@ -412,14 +519,22 @@ set_result2_cb (GtkWidget *widget, gpointer user_data)
 
 	} else {
 
-		if (hour == 0 && minute == 0 && second == 0) {
-			g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%s</big>", julian_to_str (julian, DATE_FULL));
+		if (ignore_weekend_days) {
+			str = utl_date_print_j (julian, DATE_FULL, config.override_locale_settings);
+			text = g_strdup_printf ("<big>%s</big>\n<small>(%d %s)</small>", str,
+			                        wd_n, ngettext ("weekend day ignored", "weekend days ignored", wd_n));
+		} else if (hour == 0 && minute == 0 && second == 0) {
+			str = utl_date_print_j (julian, DATE_FULL, config.override_locale_settings);
+			text = g_strdup_printf ("<big>%s</big>", str);
 		} else {
-			g_snprintf (timebuf, BUFFER_SIZE, "%02d:%02d.%02d", (gint)hour, (gint)minute, (gint)second);
-			g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%s, %s</big>", timebuf, julian_to_str (julian, DATE_FULL));
+			str = utl_date_time_print_js (julian, DATE_FULL,
+			                              utl_time_hms_to_seconds (hour, minute, second), TIME_HH_MM_SS,
+			                              config.override_locale_settings);
+			text = g_strdup_printf ("<big>%s</big>", str);
 		}
-		gtk_label_set_markup (GTK_LABEL (appGUI->cal->label2_result), tmpbuf);
-
+		gtk_label_set_markup (GTK_LABEL (appGUI->cal->label2_result), text);
+		g_free (str);
+		g_free (text);
 	}
 
 	appGUI->cal->julian_jumpto = julian;
@@ -446,6 +561,28 @@ GDate *cdate;
 
 /*------------------------------------------------------------------------------*/
 
+void
+ignore_weekend_days_cb (GtkToggleButton *togglebutton, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+	gint flag;
+
+	flag = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (togglebutton));
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_start_hour, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_start_minute, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_start_second, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_year, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_month, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_week, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_hour, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_minute, !flag);
+	gtk_widget_set_sensitive (appGUI->cal->spinbutton2_end_second, !flag);
+
+	set_result2_cb (NULL, appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 calendar_create_calc_window (GUI *appGUI) {
 
@@ -481,6 +618,7 @@ GtkWidget *button2_start_now;
 GtkWidget *button2_start_clear;
 GtkWidget *button2_end_clear;
 GtkWidget *vbox10;
+GtkWidget *vbox22;
 GtkWidget *hbox10;
 GSList    *radiobutton_add_group = NULL;
 GtkWidget *radiobutton_sub;
@@ -488,6 +626,7 @@ GtkWidget *close_button;
 GtkWidget *hbox11;
 GtkWidget *hbox12;
 GtkWidget *hbox13;
+GtkWidget *hbox14;
 GtkWidget *hbox_bst;
 GtkWidget *hbox_bet;
 GtkWidget *hbox_b2st;
@@ -938,9 +1077,13 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
+    vbox22 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox22);
+    gtk_container_add (GTK_CONTAINER (alignment), vbox22);
+
     hbox9 = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox9);
-    gtk_container_add (GTK_CONTAINER (alignment), hbox9);
+    gtk_box_pack_start (GTK_BOX (vbox22), hbox9, TRUE, TRUE, 0);
 
     vbox8 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox8);
@@ -1091,6 +1234,27 @@ char      tmpbuf[BUFFER_SIZE];
 	}
     g_signal_connect (button2_start_clear, "clicked", G_CALLBACK (reset_current_time_start2_cb), appGUI);
 
+    hbox14 = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (hbox14);
+    gtk_box_pack_start (GTK_BOX (vbox22), hbox14, FALSE, FALSE, 4);
+
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Operation"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (hbox14), label, FALSE, FALSE, 0);
+
+    appGUI->cal->radiobutton_add = gtk_radio_button_new_with_mnemonic (NULL, _("add"));
+    gtk_widget_show (appGUI->cal->radiobutton_add);
+    gtk_box_pack_start (GTK_BOX (hbox14), appGUI->cal->radiobutton_add, FALSE, FALSE, 0);
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add),radiobutton_add_group);
+    radiobutton_add_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add));
+
+    radiobutton_sub = gtk_radio_button_new_with_mnemonic (NULL, _("subtract"));
+    gtk_widget_show (radiobutton_sub);
+    gtk_box_pack_start (GTK_BOX (hbox14), radiobutton_sub, FALSE, FALSE, 0);
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_sub), radiobutton_add_group);
+    radiobutton_add_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_sub));
+
 	g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Date and time to add or subtract from"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
@@ -1133,21 +1297,21 @@ char      tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    spinbutton_adjustment = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    spinbutton_adjustment = gtk_adjustment_new (0, 0, 10000, 1, 10, 0);
     appGUI->cal->spinbutton2_end_year = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adjustment), 1, 0);
     gtk_widget_show (appGUI->cal->spinbutton2_end_year);
     gtk_table_attach (GTK_TABLE (table), appGUI->cal->spinbutton2_end_year, 0, 1, 1, 2,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    spinbutton_adjustment = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    spinbutton_adjustment = gtk_adjustment_new (0, 0, 100000, 1, 10, 0);
     appGUI->cal->spinbutton2_end_month = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adjustment), 1, 0);
     gtk_widget_show (appGUI->cal->spinbutton2_end_month);
     gtk_table_attach (GTK_TABLE (table), appGUI->cal->spinbutton2_end_month, 1, 2, 1, 2,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    spinbutton_adjustment = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    spinbutton_adjustment = gtk_adjustment_new (0, 0, 1000000, 1, 10, 0);
     appGUI->cal->spinbutton2_end_day = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adjustment), 1, 0);
     gtk_widget_show (appGUI->cal->spinbutton2_end_day);
     gtk_table_attach (GTK_TABLE (table), appGUI->cal->spinbutton2_end_day, 2, 3, 1, 2,
@@ -1168,7 +1332,7 @@ char      tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    spinbutton_adjustment = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    spinbutton_adjustment = gtk_adjustment_new (0, 0, 1000000, 1, 10, 0);
     appGUI->cal->spinbutton2_end_week = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adjustment), 1, 0);
     gtk_widget_show (appGUI->cal->spinbutton2_end_week);
     gtk_table_attach (GTK_TABLE (table), appGUI->cal->spinbutton2_end_week, 3, 4, 1, 2,
@@ -1228,22 +1392,13 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_widget_show (hbox10);
     gtk_box_pack_start (GTK_BOX (vbox10), hbox10, TRUE, TRUE, 4);
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Operation"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (hbox10), label, FALSE, FALSE, 0);
-
-    appGUI->cal->radiobutton_add = gtk_radio_button_new_with_mnemonic (NULL, _("add"));
-    gtk_widget_show (appGUI->cal->radiobutton_add);
-    gtk_box_pack_start (GTK_BOX (hbox10), appGUI->cal->radiobutton_add, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add),radiobutton_add_group);
-    radiobutton_add_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add));
-
-    radiobutton_sub = gtk_radio_button_new_with_mnemonic (NULL, _("subtract"));
-    gtk_widget_show (radiobutton_sub);
-    gtk_box_pack_start (GTK_BOX (hbox10), radiobutton_sub, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_sub), radiobutton_add_group);
-    radiobutton_add_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_sub));
+	appGUI->cal->ignore_weekend_days_checkbutton = gtk_check_button_new_with_mnemonic (_("Ignore weekend days"));
+	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->ignore_weekend_days_checkbutton, GTK_CAN_FOCUS);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->ignore_weekend_days_checkbutton), FALSE);
+	g_signal_connect (G_OBJECT (appGUI->cal->ignore_weekend_days_checkbutton), "toggled",
+	                  G_CALLBACK (ignore_weekend_days_cb), appGUI);
+	gtk_box_pack_start (GTK_BOX (hbox10), appGUI->cal->ignore_weekend_days_checkbutton, FALSE, FALSE, 2);
+	gtk_widget_show (appGUI->cal->ignore_weekend_days_checkbutton);
 
     if (config.default_stock_icons) {
         button2_end_clear = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
