@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "utils_date.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -38,6 +39,8 @@ fullyear_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data
 {
 	GUI *appGUI = (GUI *) user_data;
 
+	appGUI->cal->last_selected_year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton));
+
 	gtk_window_get_size (GTK_WINDOW (appGUI->cal->fullyear_window),
 	                     &config.fy_window_size_x, &config.fy_window_size_y);
 	gtk_widget_destroy (appGUI->cal->fullyear_window);
@@ -158,7 +161,7 @@ void
 change_to_current_year_cb (GtkWidget *widget, gpointer user_data)
 {
 	GUI *appGUI = (GUI *) user_data;
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), utl_get_current_year ());
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), utl_date_get_current_year ());
 }
 
 /*------------------------------------------------------------------------*/
@@ -202,7 +205,7 @@ guint i, month, year;
 
 	year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
 
-	if (year == utl_get_current_year ()) {
+	if (year == utl_date_get_current_year ()) {
 		gtk_widget_set_sensitive (appGUI->cal->cyear_button, FALSE);
 	} else {
 		gtk_widget_set_sensitive (appGUI->cal->cyear_button, TRUE);
@@ -219,22 +222,6 @@ guint i, month, year;
 
 /*------------------------------------------------------------------------*/
 
-gint
-fullyear_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
-{
-	GUI *appGUI = (GUI *) user_data;
-
-	switch (event->keyval) {
-		case GDK_Escape:
-			gtk_widget_destroy (appGUI->cal->fullyear_window);
-			return TRUE;
-	}
-
-	return FALSE;
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 year_info_cb (GtkWidget *widget, gpointer user_data)
 {
@@ -254,7 +241,7 @@ gchar tmpbuf[BUFFER_SIZE];
 	            _("Year"), year, _("Leap year"), g_date_is_leap_year (year) ? _("Yes"):_("No"),
 	            _("Chinese year animal"), get_chinese_year_name (year),
 	            _("Number of days"), utl_get_days_per_year (year),
-	            _("Number of weeks"), weeks_in_year (year),
+	            _("Number of weeks"), utl_weeks_in_year (year),
 	            _("Number of weekend days"), w_days, (double) w_days / utl_get_days_per_year (year) * 100.0);
 
 	utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cal->fullyear_window));
@@ -262,6 +249,31 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
+gint
+fullyear_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+
+	switch (event->keyval) {
+		case GDK_Escape:
+			gtk_widget_destroy (appGUI->cal->fullyear_window);
+			return TRUE;
+		case GDK_F1:
+			g_signal_emit_by_name (G_OBJECT(appGUI->cal->fy_alternative_view_checkbutton), "clicked");
+			return TRUE;
+		case GDK_F2:
+			year_info_cb (NULL, appGUI);
+			return TRUE;
+		case GDK_F3:
+			change_to_current_year_cb (NULL, appGUI);
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 alternative_view_cb (GtkToggleButton *togglebutton, gpointer user_data)
 {
@@ -280,6 +292,22 @@ alternative_view_cb (GtkToggleButton *togglebutton, gpointer user_data)
 
 /*------------------------------------------------------------------------------*/
 
+void
+calendar_dbclick_cb (GtkWidget *widget, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+	GDate *date = g_date_new ();
+
+	gui_calendar_get_gdate (GUI_CALENDAR (widget), date);
+	cal_jump_to_date (date, appGUI);
+	update_aux_calendars (appGUI);
+	g_date_free (date);
+
+	fullyear_window_close_cb (GTK_WIDGET (widget), NULL, appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 calendar_create_fullyear_window (GUI *appGUI)
 {
@@ -294,7 +322,6 @@ GtkObject   *fy_spinbutton_adj;
 GtkWidget   *next_button;
 GtkWidget   *fycal_scrolledwindow;
 GtkWidget   *fycal_viewport;
-GtkWidget   *fycal_alternative_view_checkbutton;
 GtkWidget   *vseparator;
 GtkWidget   *label;
 GtkWidget   *fycal_label, *fycal_vbox;
@@ -334,7 +361,7 @@ guint       month, year;
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label), 0, 4);
 
-	fy_spinbutton_adj = gtk_adjustment_new (utl_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 0);
+	fy_spinbutton_adj = gtk_adjustment_new (utl_date_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 0);
 	appGUI->cal->fy_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (fy_spinbutton_adj), 1, 0);
 	gtk_widget_show (appGUI->cal->fy_spinbutton);
 	g_signal_connect(appGUI->cal->fy_spinbutton, "value-changed", G_CALLBACK(change_year_spin_button_cb), appGUI);
@@ -407,13 +434,13 @@ guint       month, year;
 	gtk_widget_show (vseparator);
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
 
-	fycal_alternative_view_checkbutton = gtk_check_button_new_with_mnemonic (_("Alternative view"));
-	GTK_WIDGET_UNSET_FLAGS (fycal_alternative_view_checkbutton, GTK_CAN_FOCUS);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fycal_alternative_view_checkbutton), config.fy_alternative_view);
-	g_signal_connect (G_OBJECT (fycal_alternative_view_checkbutton), "toggled",
+	appGUI->cal->fy_alternative_view_checkbutton = gtk_check_button_new_with_mnemonic (_("Alternative view"));
+	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->fy_alternative_view_checkbutton, GTK_CAN_FOCUS);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton), config.fy_alternative_view);
+	g_signal_connect (G_OBJECT (appGUI->cal->fy_alternative_view_checkbutton), "toggled",
 	                  G_CALLBACK (alternative_view_cb), appGUI);
-	gtk_box_pack_start (GTK_BOX (hbox1), fycal_alternative_view_checkbutton, FALSE, FALSE, 2);
-	gtk_widget_show (fycal_alternative_view_checkbutton);
+	gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->fy_alternative_view_checkbutton, FALSE, FALSE, 2);
+	gtk_widget_show (appGUI->cal->fy_alternative_view_checkbutton);
 
 	fycal_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (fycal_scrolledwindow);
@@ -438,7 +465,7 @@ guint       month, year;
 		appGUI->cal->fycal_table_1 = gtk_table_new (MAX_MONTHS + 4, FULL_YEAR_COLS + 3, FALSE);
 	}
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fycal_alternative_view_checkbutton)) == FALSE) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton)) == FALSE) {
 		gtk_widget_show (appGUI->cal->fycal_table_1);
 	}
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->fycal_table_1, TRUE, TRUE, 0);
@@ -579,7 +606,7 @@ guint       month, year;
 		}
 	}
 
-	display_calendar (utl_get_current_year (), appGUI);
+	display_calendar (utl_date_get_current_year (), appGUI);
 	gtk_widget_set_sensitive (appGUI->cal->cyear_button, FALSE);
 
 	/*-------------------------------------------------------------------------------------*/
@@ -587,7 +614,7 @@ guint       month, year;
 
 	appGUI->cal->fycal_table_2 = gtk_table_new (3, 4, FALSE);
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fycal_alternative_view_checkbutton)) == TRUE) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton)) == TRUE) {
 		gtk_widget_show (appGUI->cal->fycal_table_2);
 	}
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->fycal_table_2, TRUE, TRUE, 0);
@@ -605,21 +632,23 @@ guint       month, year;
 			gtk_widget_show (fycal_label);
 			gtk_box_pack_start (GTK_BOX (fycal_vbox), fycal_label, FALSE, FALSE, 0);
 			appGUI->cal->fy_calendars[i] = gui_calendar_new ();
+			g_signal_connect (appGUI->cal->fy_calendars[i], 
+							  "day_selected_double_click", G_CALLBACK (calendar_dbclick_cb), appGUI);
 			gtk_widget_show (appGUI->cal->fy_calendars[i]);
 			GTK_WIDGET_UNSET_FLAGS (appGUI->cal->fy_calendars[i], GTK_CAN_FOCUS);
 			gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->fy_calendars[i]),
 			                                  (config.display_options & (GUI_CALENDAR_SHOW_DAY_NAMES |
 			                                  GUI_CALENDAR_WEEK_START_MONDAY)) | GUI_CALENDAR_NO_MONTH_CHANGE);
 			gui_calendar_enable_cursor (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), FALSE);
-			gui_calendar_set_event_marker_type (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.event_marker_type);
-			gui_calendar_set_event_marker_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_color);
-			gui_calendar_set_selector_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.selection_color);
-			gui_calendar_set_header_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.header_color);
-			gui_calendar_set_weekend_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.weekend_color);
-			gui_calendar_set_day_note_marker_type (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.day_note_marker);
-			gui_calendar_set_today_marker_type (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.today_marker_type);
-			gui_calendar_set_today_marker_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_current_day_color);
-			gui_calendar_set_today_marker_alpha (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_current_day_alpha);
+			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_color, 0, EVENT_MARKER_COLOR);
+			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.selection_color, 0, SELECTOR_COLOR);
+			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.header_color, 0, HEADER_COLOR);
+			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.weekend_color, 0, WEEKEND_COLOR);
+			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_current_day_color, config.mark_current_day_alpha, TODAY_MARKER_COLOR);
+            gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.birthday_mark_color, 0, BIRTHDAY_MARKER_COLOR);
+			gui_calendar_set_day_note_marker_symbol (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.day_note_marker);
+			gui_calendar_set_marker (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.today_marker_type, TODAY_MARKER);
+			gui_calendar_set_marker (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.event_marker_type, EVENT_MARKER);
 
 			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton));
 			month = i + 1;
@@ -633,6 +662,12 @@ guint       month, year;
 		}
 	}
 
+	if (appGUI->cal->last_selected_year == -1) {
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), utl_date_get_current_year ());
+	} else {
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), appGUI->cal->last_selected_year);
+	}
+
 	/*-------------------------------------------------------------------------------------*/
 
 	hseparator = gtk_hseparator_new ();
