@@ -24,6 +24,7 @@
 #include "calendar.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -80,7 +81,7 @@ gint a;
     if (event->keyval == GDK_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->day_entry))) == FALSE) {
-            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_day ());
+            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_day ());
             gtk_entry_set_text (GTK_ENTRY(appGUI->cal->day_entry), tmpbuf);
         }
 
@@ -111,7 +112,7 @@ gint a;
     if (event->keyval == GDK_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->month_entry))) == FALSE) {
-            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_month ());
+            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_month ());
             gtk_entry_set_text (GTK_ENTRY(appGUI->cal->month_entry), tmpbuf);
         }
 
@@ -260,11 +261,11 @@ char tmpbuf[BUFFER_SIZE];
                         G_CALLBACK (year_key_press_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->year_entry, FALSE, TRUE, 1);
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_day ());
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_day ());
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->day_entry), tmpbuf);
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_month ());
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_month ());
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->month_entry), tmpbuf);
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_year ());
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_year ());
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->year_entry), tmpbuf);
 
     hseparator = gtk_hseparator_new ();
