@@ -19,11 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
 #include "calendar_notes.h"
 #include "i18n.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "utils_date.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "stock_icons.h"
@@ -31,21 +31,16 @@
 /*------------------------------------------------------------------------------*/
 
 gboolean
-cal_check_note (GDate *date, GUI *appGUI)
+cal_check_note (guint32 julian, GUI *appGUI)
 {
-GSList *lnode;
-struct note *a;
-gint i;
+	GSList *node;
+	struct note *n;
 
-	if (appGUI->cal->notes_list != NULL) {
-
-		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-			a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-			if (a->date == g_date_get_julian (date))
-				return TRUE;
-		}
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
+		if (n->date == julian)
+			return TRUE;
 	}
 
     return FALSE;
@@ -54,44 +49,51 @@ gint i;
 /*------------------------------------------------------------------------------*/
 
 gboolean
-check_note (guint day, guint month, guint year, GUI *appGUI) {
+cal_check_notes (guint32 julian_start, guint32 julian_end, GUI *appGUI)
+{
+	GSList *node;
+	struct note *n;
 
-GSList *lnode;
-struct note *a;
-gint i;
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
-    if (appGUI->cal->notes_list != NULL) {
+		if (n->date >= julian_start && n->date <= julian_end)
+			return TRUE;
+	}
 
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-
-            a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-            if (a->day == day && a->month == month && a->year == year)
-                return TRUE;
-        }
-
-    }
     return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
 
-gchar *
-cal_get_note (GDate *date, GUI *appGUI)
+void
+cal_notes_foreach (guint32 julian_start, guint32 julian_end, gboolean (*cnfunc)(), GUI *appGUI)
 {
-GSList *lnode;
-struct note *a;
-gint i;
+	GSList *node;
+	struct note *n;
 
-	if (appGUI->cal->notes_list != NULL) {
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
-		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-			a = g_slist_nth_data (appGUI->cal->notes_list, i);
+		if (n->date >= julian_start && n->date <= julian_end)
+			if ((*cnfunc)(n, appGUI) == TRUE)
+				break;
+	}
+}
 
-			if (a->date == g_date_get_julian (date))
-				return a->note;
-		}
+/*------------------------------------------------------------------------------*/
 
+gchar *
+cal_get_note (guint32 julian, GUI *appGUI)
+{
+	GSList *node;
+	struct note *n;
+
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
+
+		if (n->date == julian)
+			return n->note;
 	}
 
     return NULL;
@@ -100,51 +102,16 @@ gint i;
 /*------------------------------------------------------------------------------*/
 
 gchar *
-get_note (guint day, guint month, guint year, GUI *appGUI) {
-
-GSList *lnode;
-struct note *a;
-gint i;
-
-    if (appGUI->cal->notes_list != NULL) {
-
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-
-            a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-            if (a->day == day && a->month == month && a->year == year) {
-
-                if (a->note != NULL) {
-                    return a->note;
-                } else {
-                    return NULL;
-                }
-
-            }
-        }
-    }
-
-    return NULL;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *
-cal_get_note_color (GDate *date, GUI *appGUI)
+cal_get_note_color (guint32 julian, GUI *appGUI)
 {
-GSList *lnode;
-struct note *a;
-gint i;
+	GSList *node;
+	struct note *n;
 
-	if (appGUI->cal->notes_list != NULL) {
-
-		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-			a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-			if (a->date == g_date_get_julian (date))
-				return a->color;
-		}
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
+		if (n->date == julian)
+			return n->color;
 	}
 
     return NULL;
@@ -152,98 +119,55 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
-gchar *
-get_color (guint day, guint month, guint year, GUI *appGUI) {
-
-GSList *lnode;
-struct note *a;
-gint i;
-
-    if (appGUI->cal->notes_list != NULL) {
-
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-
-            a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-            if (a->day == day && a->month == month && a->year == year) {
-
-                if (a->color != NULL) {
-                    return a->color;
-                } else {
-                    return NULL;
-                }
-
-            }
-        }
-    }
-
-    return NULL;
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 cal_replace_note_color (gchar *old_color, gchar *new_color, GUI *appGUI)
 {
-GSList *lnode;
-struct note *a;
-gint i;
+	GSList *node;
+	struct note *n;
 
-	g_return_if_fail (appGUI->cal->notes_list != NULL);
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
-	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-		a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-		if (a->color != NULL)
-			if (!strncmp (a->color, old_color, MAXCOLORNAME)) {
-				g_free (a->color);
-				a->color = g_strdup (new_color);
-			}
+		if (n->color != NULL && strncmp (n->color, old_color, MAXCOLORNAME) == 0) {
+			g_free (n->color);
+			n->color = g_strdup (new_color);
+		}
 	}
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-cal_add_note (GDate *date, gchar *color_str, gchar *text_note, GUI *appGUI)
+cal_add_note (guint32 julian, gchar *color_str, gchar *text_note, GUI *appGUI)
 {
-struct note *a;
+	struct note *n;
 
 	g_return_if_fail (text_note != NULL);
 
-	a = g_malloc (sizeof (struct note));
-	g_assert (a != NULL);
+	n = g_slice_new (struct note);
+	n->date = julian;
+	n->color = g_strdup (color_str);
+	n->note = g_strdup (text_note);
 
-	a->date = g_date_get_julian (date);
-	a->day = g_date_get_day (date);
-	a->month = g_date_get_month (date);
-	a->year = g_date_get_year (date);
-	a->color = (color_str != NULL) ? g_strdup (color_str) : NULL;
-	a->note = g_strdup (text_note);
-
-	cal_remove_note (date, appGUI);
-
-	appGUI->cal->notes_list = g_slist_append (appGUI->cal->notes_list, a);
+	cal_remove_note (julian, appGUI);
+	appGUI->cal->notes_list = g_slist_append (appGUI->cal->notes_list, n);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-cal_remove_note (GDate *date, GUI *appGUI)
+cal_remove_note (guint32 julian, GUI *appGUI)
 {
-GSList *lnode;
-struct note *a;
-gint i;
+	GSList *node;
+	struct note *n;
 
-	if (appGUI->cal->notes_list == NULL) return;
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
 
-	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-		a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-		if (a->date == g_date_get_julian (date)) {
-			if (a->color != NULL) g_free (a->color);
-			if (a->note != NULL) g_free (a->note);
-			appGUI->cal->notes_list = g_slist_remove (appGUI->cal->notes_list, a);
+		if (n->date == julian) {
+			g_free (n->color);
+			g_free (n->note);
+			appGUI->cal->notes_list = g_slist_remove (appGUI->cal->notes_list, n);
 			break;
 		}
 	}
@@ -254,22 +178,17 @@ gint i;
 void
 cal_free_notes_list (GUI *appGUI)
 {
-GSList *node;
-struct note *a;
-gint i = 0;
-
-	if (appGUI->cal->notes_list != NULL) {
-
-		for (node = appGUI->cal->notes_list; node != NULL; node = node->next, i++) {
-			a = g_slist_nth_data (appGUI->cal->notes_list, i);
-			if (a->color != NULL) g_free (a->color);
-			if (a->note != NULL) g_free (a->note);
-		}
-
-		g_slist_free (appGUI->cal->notes_list);
-		appGUI->cal->notes_list = NULL;
+	GSList *node;
+	struct note *n;
 
+	for (node = appGUI->cal->notes_list; node != NULL; node = node->next) {
+		n = (struct note *) node->data;
+		g_free (n->color);
+		g_free (n->note);
 	}
+
+	g_slist_free (appGUI->cal->notes_list);
+	appGUI->cal->notes_list = NULL;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -285,13 +204,9 @@ GdkPixbuf *image;
 guint32 julian;
 gint day, month, year;
 gchar *color_str, *note;
-GDate *date;
 
 	appGUI->cal->notes_list = NULL;
 
-	date = g_date_new ();
-	g_return_if_fail (date != NULL);
-
 	if (g_file_test (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE)
 		return;
 
@@ -320,6 +235,7 @@ GDate *date;
 								gtk_list_store_set (appGUI->opt->calendar_category_store, &iter, 0, image,
 								                    1, prop, 2, (gchar *) key, -1);
 								g_object_unref (image);
+								xmlFree (prop);
 								xmlFree (key);
 							}
 						}
@@ -347,11 +263,11 @@ GDate *date;
 					}
 
 					if (note != NULL && (g_date_valid_dmy (day, month, year) || g_date_valid_julian (julian))) {
-						if (g_date_valid_julian (julian)) g_date_set_julian (date, julian);
-						else g_date_set_dmy (date, day, month, year);
+						if (g_date_valid_julian (julian) == FALSE)
+							julian = utl_date_dmy_to_julian (day, month, year);
 
-						cal_add_note (date, color_str, note, appGUI);
-						if (color_str != NULL) g_free (color_str);
+						cal_add_note (julian, color_str, note, appGUI);
+						g_free (color_str);
 						g_free (note);
 					}
 				}
@@ -364,8 +280,6 @@ GDate *date;
 		xmlFree (node);
 		xmlFreeDoc (doc);
 	}
-
-	g_date_free (date);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -413,14 +327,12 @@ xmlChar *escaped;
 		a = g_slist_nth_data (appGUI->cal->notes_list, i);
 		note_node = xmlNewChild (main_node, NULL, (const xmlChar *) "note", (xmlChar *) NULL);
 		utl_xml_put_uint ("date", a->date, note_node);
-		utl_xml_put_int ("day", a->day, note_node);
-		utl_xml_put_int ("month", a->month, note_node);
-		utl_xml_put_int ("year", a->year, note_node);
 		utl_xml_put_str ("color", a->color, note_node, doc);
 		utl_xml_put_str ("message", a->note, note_node, doc);
 	}
 
 	xmlSaveFormatFileEnc (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), doc, "utf-8", 1);
+	xmlFree (attr);
 	xmlFreeDoc (doc);
 
 	appGUI->save_status &= ~WRT_CALENDAR_NOTES;
@@ -510,7 +422,7 @@ GSList          *lnode;
 struct note     *day_note;
 guint32         julian_day;
 GtkTreeIter     iter;
-gchar           *tmp_note, *search_key_1, *search_key_2;
+gchar           *tmp_note, *stripped, *search_key_1, *search_key_2;
 gboolean        show_flag, case_state;
 gint            i, l, n, m, n_items;
 gchar           tmpbuf[BUFFER_SIZE];
@@ -523,9 +435,11 @@ gchar           tmpbuf[BUFFER_SIZE];
 	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 
 		day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-		julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
+		julian_day = day_note->date;
 
 		tmp_note = cal_note_remove_empty_lines (day_note->note);
+		stripped = utl_gui_text_strip_tags (tmp_note);
+		g_free (tmp_note);
 
 		if (search_string == NULL) {
 			show_flag = TRUE;
@@ -534,8 +448,8 @@ gchar           tmpbuf[BUFFER_SIZE];
 
 				show_flag = FALSE;
 
-				l = strlen(search_string);
-				m = strlen(tmp_note) - l;
+				l = strlen (search_string);
+				m = strlen (stripped) - l;
 
 				if (m >= 0) {
 
@@ -550,9 +464,9 @@ gchar           tmpbuf[BUFFER_SIZE];
 					for (n = 0; n < m; n++) {
 
 						if (case_state == FALSE) {
-							search_key_2 = g_utf8_casefold (tmp_note+n, l);
+							search_key_2 = g_utf8_casefold (stripped+n, l);
 						} else {
-							search_key_2 = g_utf8_collate_key (tmp_note+n, l);
+							search_key_2 = g_utf8_collate_key (stripped+n, l);
 						}
 
 						if (g_utf8_collate(search_key_1, search_key_2) == 0) {
@@ -577,12 +491,12 @@ gchar           tmpbuf[BUFFER_SIZE];
 
 			gtk_list_store_append (appGUI->cal->day_notes_list_store, &iter);
 			gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter,
-								DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format),
+								DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format, config.override_locale_settings),
 								DN_COLUMN_DATE_JULIAN, julian_day,
-								DN_COLUMN_NOTE_LINE, tmp_note,
+								DN_COLUMN_NOTE_LINE, stripped,
 								DN_COLUMN_DONE, FALSE, -1);
 
-			if (julian_day < utl_get_current_julian ()
+			if (julian_day < utl_date_get_current_julian ()
 				&& gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->past_notes_checkbutton))) {
 
 				gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter, DN_COLUMN_DONE, TRUE, -1);
@@ -592,7 +506,7 @@ gchar           tmpbuf[BUFFER_SIZE];
 
 		}
 
-		g_free (tmp_note);
+		g_free (stripped);
 
 	}
 
@@ -626,33 +540,33 @@ gint month, year;
 	}
 
 	julian_start = julian_end = 0;
-	month = utl_get_current_month ();
-	year = utl_get_current_year ();
+	month = utl_date_get_current_month ();
+	year = utl_date_get_current_year ();
 
 	switch (filter_mode) {
 		case DN_FILTER_CURRENT_MONTH:
-			julian_start = utl_dmy_to_julian (1, month, year);
-			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			julian_start = utl_date_dmy_to_julian (1, month, year);
+			julian_end = utl_date_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
 			break;
 		case DN_FILTER_SELECTED_MONTH:
 			month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_month_spinbutton));
-			julian_start = utl_dmy_to_julian (1, month, year);
-			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			julian_start = utl_date_dmy_to_julian (1, month, year);
+			julian_end = utl_date_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
 			break;
 		case DN_FILTER_CURRENT_YEAR:
-			julian_start = utl_dmy_to_julian (1, 1, year);
-			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
+			julian_start = utl_date_dmy_to_julian (1, 1, year);
+			julian_end = utl_date_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
 			break;
 		case DN_FILTER_SELECTED_YEAR:
 			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_year_spinbutton));
-			julian_start = utl_dmy_to_julian (1, 1, year);
-			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
+			julian_start = utl_date_dmy_to_julian (1, 1, year);
+			julian_end = utl_date_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
 			break;
 		case DN_FILTER_SELECTED_MONTH_YEAR:
 			month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_month_spinbutton));
 			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_year_spinbutton));
-			julian_start = utl_dmy_to_julian (1, month, year);
-			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			julian_start = utl_date_dmy_to_julian (1, month, year);
+			julian_end = utl_date_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
 			break;
 		case DN_FILTER_ALL_NOTES:
 			julian_start = julian_end = 0;
@@ -822,7 +736,7 @@ gchar               tmpbuf[BUFFER_SIZE];
     g_signal_connect (appGUI->cal->notes_month_spinbutton, "value-changed", 
                       G_CALLBACK (notes_filter_changed_cb), appGUI);
 
-    notes_year_spinbutton_adj = gtk_adjustment_new (2008, 1000, 9999, 1, 10, 0);
+    notes_year_spinbutton_adj = gtk_adjustment_new (utl_date_get_current_year (), 1, 9999, 1, 10, 0);
     appGUI->cal->notes_year_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (notes_year_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->notes_year_spinbutton);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->notes_year_spinbutton, TRUE, TRUE, 0);
