@@ -22,9 +22,9 @@
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "i18n.h"
-#include "options_gui_tasks.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
+#include "tasks_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
 
@@ -97,7 +97,7 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 	struct note *a;
 	gint i;
 
-	gchar *wbuf1, *wbuf2;
+	gchar *wbuf1, *wbuf2, *stripped;
 	gchar buf1[BUFFER_SIZE], buf2[BUFFER_SIZE];
 	GDate *date, *sdate;
 	gint age, syear;
@@ -123,7 +123,7 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 		while (gtk_tree_model_get_iter (model, &iter, path) == TRUE) {
 			gtk_tree_model_get (model, &iter, TA_COLUMN_DUE_DATE_JULIAN, &tsk_julian, TA_COLUMN_CATEGORY, &wbuf1, -1);
 
-			if (tsk_julian == julian && tasks_category_get_state (wbuf1, STATE_CALENDAR, appGUI) == TRUE) {
+			if (tsk_julian == julian && tsk_get_category_state (wbuf1, STATE_CALENDAR, appGUI) == TRUE) {
 				gtk_tree_model_get (model, &iter, TA_COLUMN_DUE_TIME, &time, TA_COLUMN_SUMMARY, &wbuf2, -1);
 
 				if (time >= 0) {
@@ -246,18 +246,23 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 	/* day note */
 	if (config.cal_print_day_notes) {
 
+		wbuf1 = NULL;
+
 		if (appGUI->cal->notes_list != NULL) {
 
-			wbuf1 = NULL;
 			reg = g_regex_new ("\n", 0, 0, NULL);
 
 			for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 				a = g_slist_nth_data (appGUI->cal->notes_list, i);
+				stripped = utl_gui_text_strip_tags (a->note);
 
 				if (a->date == julian) {
-					wbuf1 = g_regex_replace_literal (reg, a->note, -1, 0, " ", 0, NULL);
+					wbuf1 = g_regex_replace_literal (reg, stripped, -1, 0, " ", 0, NULL);
+					g_free (stripped);
 					break;
 				}
+
+				g_free (stripped);
 			}
 
 			g_regex_unref (reg);
@@ -380,7 +385,9 @@ calendar_draw_page (GtkPrintOperation *operation, GtkPrintContext *context, gint
 
 	pango_layout_set_wrap (layout, PANGO_WRAP_WORD_CHAR);
 	pango_layout_set_width (layout, (day_width - padding * 2) * PANGO_SCALE);
+#ifdef HAVE_PANGO_1_20
 	pango_layout_set_height (layout, event_height * PANGO_SCALE);
+#endif /* HAVE_PANGO_1_20 */
 	pango_layout_set_ellipsize (layout, PANGO_ELLIPSIZE_END);
 	pango_layout_set_indent (layout, -4 * PANGO_SCALE);
 
@@ -484,8 +491,10 @@ calendar_print_start_cb (GtkWidget *widget, gpointer user_data)
 	    (GTK_TOGGLE_BUTTON (appGUI->cal->print_namedays_checkbutton));
 	config.cal_print_day_notes = gtk_toggle_button_get_active
 	    (GTK_TOGGLE_BUTTON (appGUI->cal->print_day_notes_checkbutton));
+	/*
 	config.cal_print_ical = gtk_toggle_button_get_active
 	    (GTK_TOGGLE_BUTTON (appGUI->cal->print_ical_checkbutton));
+	*/
 
 	gtk_widget_destroy (appGUI->cal->window_print_options);
 
@@ -752,6 +761,7 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_day_notes_checkbutton),
 	                              config.cal_print_day_notes);
 
+	/*
 	appGUI->cal->print_ical_checkbutton = gtk_check_button_new_with_mnemonic (_("ICal"));
 	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_ical_checkbutton, GTK_CAN_FOCUS);
 	gtk_widget_show (appGUI->cal->print_ical_checkbutton);
@@ -759,6 +769,7 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_widget_set_sensitive (appGUI->cal->print_ical_checkbutton, FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_ical_checkbutton),
 	                              config.cal_print_ical);
+	*/
 
 	g_snprintf (buffer, BUFFER_SIZE, "<b>%s</b>", _("Visible events"));
 	label = gtk_label_new (buffer);
