@@ -1,4 +1,3 @@
-
 /*
  * Osmo - a handy personal organizer
  *
@@ -27,29 +26,59 @@
 #include "utils_gui.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
-#include "options_gui_tasks.h"
 #include "calendar_utils.h"
 #include "stock_icons.h"
 #include "tasks_items.h"
+#include "tasks_utils.h"
 
 /*------------------------------------------------------------------------------*/
 
 #ifdef TASKS_ENABLED
+
+/*------------------------------------------------------------------------------*/
+
+#ifdef HAVE_LIBNOTIFY
+static void
+tsk_status_icon_set_normal (GUI *appGUI)
+{
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
+	gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+}
+#endif /* HAVE_LIBNOTIFY */
+
+/*------------------------------------------------------------------------------*/
+
+static gboolean
+tsk_check_notification_id (guint id, gint type, GUI *appGUI)
+{
+#ifdef HAVE_LIBNOTIFY
+	GSList *node;
+	TASK_NTF *a;
+
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
+		/* Don't show warning notification when alarm notification is visible */
+		if (a->id == id && (a->type == NOTIFY_ALARM || a->type == type))
+			return TRUE;
+	}
+#endif /* HAVE_LIBNOTIFY */
+	return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 #ifdef HAVE_LIBNOTIFY
 
 void
 free_notifications_list (GUI *appGUI)
 {
-GSList *node;
-TASK_NTF *a;
-guint i;
+	GSList *node;
+	TASK_NTF *a;
 
-	for (i = 0, node = appGUI->tsk->notifications; node != NULL; node = node->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
 		notify_notification_close (a->notify, NULL);
-		if (a->item != NULL) {
-			g_free (a->item);
-		}
+		g_free (a);
 	}
 
 	if (appGUI->tsk->notifications != NULL) {
@@ -73,107 +102,114 @@ gchar tmpbuf[BUFFER_SIZE];
 /*------------------------------------------------------------------------------*/
 
 void
-tsk_done_cb (NotifyNotification *n, const char *action, gpointer user_data)
+tsk_done_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 {
-GtkTreeIter *iter;
-GSList *tnode;
-TASK_NTF *a;
-guint i;
+	GtkTreeIter *iter;
+	GSList *node;
+	TASK_NTF *a;
+	TASK_ITEM *t;
 
-	GUI *appGUI = (GUI *) user_data;
-
-	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
 
 		if (a->notify == n) {
-			iter = task_get_iter (a->id, appGUI);
+			iter = tsk_get_iter (a->id, appGUI);
 
 			if (iter != NULL) {
 
-				if (a->item->repeat == TRUE) {
-					tasks_repeat_done (iter, a->item, appGUI);
+				t = tsk_get_item (iter, appGUI);
+
+				if (t->repeat == TRUE) {
+					tasks_repeat_done (iter, t, appGUI);
 				} else if (config.delete_completed) {
 					gtk_list_store_remove (appGUI->tsk->tasks_list_store, iter);
 				} else {
 					gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
-					                    TA_COLUMN_COLOR, get_date_color (a->item->due_date_julian, a->item->due_time, TRUE, appGUI),
+					                    TA_COLUMN_COLOR, get_date_color (t->due_date_julian, t->due_time, TRUE, appGUI),
 					                    TA_COLUMN_DONE, TRUE, -1);
 				}
 
+				tsk_item_free (t);
+
 			} else {
 				tsk_show_info_dialog (appGUI);
 			}
 
+			tsk_status_icon_set_normal (appGUI);
+			notify_notification_close (a->notify, NULL);
+			appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
+			g_free (a);
+
 			break;
 		}
-
 	}
-
-	notify_notification_close (a->notify, NULL);
-	if (a->item != NULL) {
-		g_free (a->item);
-	}
-	appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
-
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-tsk_postpone_notify_cb (NotifyNotification *n, const char *action, gpointer user_data)
+tsk_postpone_notify_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 {
-GSList *tnode;
-TASK_NTF *a;
-guint i;
+	GSList *node;
+	TASK_NTF *a;
+	TASK_ITEM *t;
 
-	GUI *appGUI = (GUI *) user_data;
-
-	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
 
 		if (a->notify == n) {
 
-			a->time = get_seconds_for_today () + a->item->postpone_time * 60;
-			a->date = utl_get_current_julian ();
+			t = tsk_get_item_id (a->id, appGUI);
+			g_return_if_fail (t != NULL);
+
+			a->time = utl_time_get_current_seconds () + t->postpone_time * 60;
+			a->date = utl_date_get_current_julian ();
 
 			if (a->time >= 24 * 3600) {
 				a->time -= 24 * 3600;
 				a->date++;
 			}
 
+			tsk_item_free (t);
+			tsk_status_icon_set_normal (appGUI);
+			notify_notification_close (a->notify, NULL);
+			break;
 		}
-
 	}
-
-	notify_notification_close (a->notify, NULL);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-tsk_show_task_cb (NotifyNotification *n, const char *action, gpointer user_data)
+tsk_show_task_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 {
-GtkTreeIter iter;
-GSList *tnode;
-GtkTreePath *sort_path, *filter_path, *path;
-GtkTreeModel *model;
-TASK_NTF *a;
-guint i, id;
+	GtkTreeIter iter;
+	GSList *tnode;
+	GtkTreePath *sort_path, *filter_path, *path;
+	GtkTreeModel *model;
+	TASK_NTF *a;
+	TASK_ITEM *t;
+	guint id;
 
-	GUI *appGUI = (GUI *) user_data;
 	model = GTK_TREE_MODEL (appGUI->tsk->tasks_list_store);
 
-	/* deiconify main window */
-	gtk_window_deiconify (GTK_WINDOW (appGUI->main_window));
+    if (config.enable_systray == TRUE && appGUI->window_visible == FALSE) {
+		gtk_widget_show (appGUI->main_window);
+		appGUI->window_visible = TRUE;
+	} else {
+		gtk_window_deiconify (GTK_WINDOW (appGUI->main_window));
+	}
 
 	/* select task tab */
 	if (config.hide_tasks == FALSE) {
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_TASKS);
 	}
 
+	gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), 0);
+
 	/* select task on list */
-	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
+	for (tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next) {
+		a = (TASK_NTF *) tnode->data;
 
 		if (a->notify == n) {
 			tasks_selection_activate (FALSE, appGUI);
@@ -213,41 +249,119 @@ guint i, id;
 
 				gtk_tree_path_free (sort_path);
 			}
+
+			tsk_status_icon_set_normal (appGUI);
+
+			if (a->type == NOTIFY_WARNING)
+				break;
+
+			notify_notification_clear_actions (a->notify);
+
+			t = tsk_get_item_id (a->id, appGUI);
+			g_return_if_fail (t != NULL);
+
+			if (t->postpone_time > 0) {
+				notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
+				                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
+			}
+			notify_notification_add_action (a->notify, "done", _("Done"), (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
+		    notify_notification_show (a->notify, NULL);
+			tsk_item_free (t);
+			break;
 		}
 	}
-
-	/* FIXME: alarm warning bug */
-	notify_notification_clear_actions (a->notify);
-	if (a->item->postpone_time > 0) {
-		notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
-		                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
-	}
-	notify_notification_add_action (a->notify, "done", _("Done"), (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
-    notify_notification_show (a->notify, NULL);
 }
 
 /*------------------------------------------------------------------------------*/
 
+void
+show_postponed_notification (GUI *appGUI)
+{
+	guint32 current_date;
+	gint current_time;
+	GSList *node;
+	TASK_NTF *a;
+	TASK_ITEM *t;
+	gchar *datestr, *datestri, *title, *text = NULL;
+	gboolean sound_flag = TRUE;
+
+	current_date = utl_date_get_current_julian ();
+	current_time = utl_time_get_current_seconds ();
+
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
+
+		if (a->type == NOTIFY_WARNING) continue;
+
+		if ((g_date_valid_julian (a->date) && utl_time_valid_seconds (a->time)) == FALSE)
+			continue;
+
+		if (utl_date_time_compare_js (a->date, a->time, current_date, current_time) <= 0) {
+			a->date = 0;
+			a->time = -1;
+
+			t = tsk_get_item_id (a->id, appGUI);
+			g_return_if_fail (t != NULL);
+
+			datestr = utl_date_time_print_default (t->due_date_julian, t->due_time, FALSE);
+			datestri = g_strdup_printf ("<i>%s</i>", datestr);
+			g_free (datestr);
+
+			if (t->desc != NULL && strlen (t->desc))
+				text = g_strdup_printf ("%s\n%.100s", datestri, t->desc);
+
+			title = g_strdup_printf ("%s (%s)", t->summary, _("postponed"));
+
+			if (text != NULL)
+				notify_notification_update (a->notify, title, text, GTK_STOCK_DIALOG_WARNING);
+			else
+				notify_notification_update (a->notify, title, datestri, GTK_STOCK_DIALOG_WARNING);
+
+			g_free (title);
+			g_free (text);
+			g_free (datestri);
+
+			if (strlen (config.global_notification_command))
+				gui_save_data_and_run_command (config.global_notification_command, appGUI);
+
+			if (t->sound_enable && sound_flag) {
+				utl_play_alarm_sound (config.sound_alarm_repeat);
+				sound_flag = FALSE;
+			}
+
+			tsk_item_free (t);
+
+			notify_notification_show (a->notify, NULL);
+		}
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+#endif /* HAVE_LIBNOTIFY */
+
+/*------------------------------------------------------------------------------*/
+
 gboolean
 tsk_show_warning_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 {
 guint32 current_date, warning_date;
 gint current_time, warning_time;
 
-	if (item->active_warning == TRUE && (item->warning_days > 0 || item->warning_time > 0)) {
+	if (tsk_check_notification_id (item->id, NOTIFY_WARNING, appGUI))
+		return FALSE;
 
-		current_date = utl_get_current_julian ();
-		current_time = get_seconds_for_today ();
+	if (item->warning_days > 0 || item->warning_time > 0) {
+
+		current_date = utl_date_get_current_julian ();
+		current_time = utl_time_get_current_seconds ();
 		utl_subtract_from_date (item->due_date_julian, item->due_time,
-		                        item->warning_days, item->warning_time, &warning_date, &warning_time);
+		                        item->warning_days, item->warning_time * 60, &warning_date, &warning_time);
 
 		if (warning_date < current_date + (warning_time < current_time) ? 1 : 0) {
 
 			if (item->repeat == TRUE && item->offline_ignore == TRUE) {
 				if (warning_date < appGUI->run_date + (warning_time < appGUI->run_time) ? 1 : 0) {
-
-					gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
-					                    TA_COLUMN_ACTIVE_WARNING, FALSE, -1);
 					return FALSE;
 				}
 			}
@@ -261,62 +375,16 @@ gint current_time, warning_time;
 
 /*------------------------------------------------------------------------------*/
 
-void
-show_postponed_notification (GUI *appGUI)
-{
-	gchar tmpbuf[BUFFER_SIZE], tmpbuf2[BUFFER_SIZE];
-	guint32 current_date;
-	gint current_time;
-	GSList *tnode;
-	TASK_NTF *a;
-	gint i;
-
-	current_date = utl_get_current_julian ();
-	current_time = get_seconds_for_today ();
-
-	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
-
-		if (a->date > 0 && a->time >= 0) {
-			if (is_date_in_the_past (a->date, a->time, current_date, current_time)) {
-				a->date = 0;
-				a->time = -1;
-				g_snprintf (tmpbuf2, BUFFER_SIZE, "<i>%s</i>", get_date_time_full_str (a->item->due_date_julian, a->item->due_time));
-				g_strlcpy (tmpbuf, tmpbuf2, BUFFER_SIZE);
-				if (a->item->desc != NULL) {
-					if (strlen (a->item->desc)) {
-						g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%.100s", tmpbuf2, a->item->desc);
-					}
-				}
-				g_snprintf (tmpbuf2, BUFFER_SIZE, "%s (%s)", a->item->summary, _("postponed"));
-				notify_notification_update (a->notify, tmpbuf2, tmpbuf, GTK_STOCK_DIALOG_WARNING);
-
-				if (strlen (config.global_notification_command)) {
-					gui_save_data_and_run_command (config.global_notification_command, appGUI);
-				}
-
-				notify_notification_show (a->notify, NULL);
-			}
-		}
-
-	}
-
-}
-
-/*------------------------------------------------------------------------------*/
-
-#endif /* HAVE_LIBNOTIFY */
-
-/*------------------------------------------------------------------------------*/
-
 gboolean
 tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 {
+	if (item->due_date_julian == 0 || tsk_check_notification_id (item->id, NOTIFY_ALARM, appGUI))
+		return FALSE;
 
-	if (is_date_in_the_past (item->due_date_julian, item->due_time, utl_get_current_julian (), get_seconds_for_today ())) {
+	if (utl_date_time_in_the_past_js (item->due_date_julian, item->due_time)) {
 
 		if (item->repeat == TRUE && item->offline_ignore == TRUE) {
-			if (is_date_in_the_past (item->due_date_julian, item->due_time, appGUI->run_date, appGUI->run_time)) {
+			if (utl_date_time_compare_js (item->due_date_julian, item->due_time, appGUI->run_date, appGUI->run_time) < 0) {
 				tasks_repeat_done (iter, item, appGUI);
 				return FALSE;
 			}
@@ -333,29 +401,29 @@ tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 gboolean
 notify_tasks (GUI *appGUI)
 {
-gchar tmpbuf[BUFFER_SIZE];
-gchar tmpbuf2[BUFFER_SIZE];
 guint32 current_date;
 gint current_time;
 
 GtkTreeIter iter;
 TASK_ITEM *item;
 gint i;
+gboolean sound_flag = TRUE;
 
 #ifdef HAVE_LIBNOTIFY
-TASK_NTF *a;
+	TASK_NTF *a;
+	gchar *datestr, *text, *textdesc;
 
 	show_postponed_notification (appGUI);
 #endif /* HAVE_LIBNOTIFY */
 
-	current_date = utl_get_current_julian ();
-	current_time = get_seconds_for_today ();
+	current_date = utl_date_get_current_julian ();
+	current_time = utl_time_get_current_seconds ();
 
 	i = 0;
 
 	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
 
-		item = get_task_item (&iter, appGUI);
+		item = tsk_get_item (&iter, appGUI);
 		if (item != NULL) {
 
 			if (item->active == TRUE && item->done == FALSE) {
@@ -368,37 +436,44 @@ TASK_NTF *a;
 						}
 					}
 
-					g_snprintf (tmpbuf2, BUFFER_SIZE, "<i>%s</i>", get_date_time_full_str (item->due_date_julian, item->due_time));
-					g_strlcpy (tmpbuf, tmpbuf2, BUFFER_SIZE);
-					if (item->desc != NULL) {
-						if (strlen (item->desc)) {
-						    g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%.100s", tmpbuf2, item->desc);
-						}
-					}
-
 #ifdef HAVE_LIBNOTIFY
-					a = g_malloc (sizeof (TASK_NTF));
-					g_assert (a != NULL);
 
-					gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, TA_COLUMN_ID, &(a->id), -1);
-					a->item = get_task_item (&iter, appGUI);
+					datestr = utl_date_time_print_default (item->due_date_julian, item->due_time, FALSE);
+					text = g_strdup_printf ("<i>%s</i>", datestr);
+					g_free (datestr);
+
+					textdesc = NULL;
+					if (item->desc != NULL && strlen (item->desc))
+						textdesc = g_strdup_printf ("%s\n%.100s", text, item->desc);
+
+					a = g_malloc (sizeof (TASK_NTF));
+
+					a->id = item->id;
+					a->type = NOTIFY_ALARM;
 					a->time = -1;
 					a->date = 0;
-					a->notify = notify_notification_new (item->summary, tmpbuf, GTK_STOCK_DIALOG_WARNING, NULL);
+
+					if (textdesc != NULL)
+						a->notify = notify_notification_new (item->summary, textdesc, GTK_STOCK_DIALOG_WARNING, NULL);
+					else
+						a->notify = notify_notification_new (item->summary, text, GTK_STOCK_DIALOG_WARNING, NULL);
+
+					g_free (textdesc);
+					g_free (text);
 
 					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
-					switch (get_priority_index (item->priority)) {
+					switch (tsk_get_priority_index (item->priority)) {
 						case LOW_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_LOW); break;
 						case MEDIUM_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL); break;
 						case HIGH_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_CRITICAL); break;
 					}
 
-					if (a->item->postpone_time > 0) {
+					if (item->postpone_time > 0) {
 						notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
 						                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
 					}
 
-					if (tasks_category_get_state (item->category, STATE_TASKS, appGUI) == TRUE) {
+					if (tsk_get_category_state (item->category, STATE_TASKS, appGUI) == TRUE) {
 						notify_notification_add_action (a->notify, "show_task", _("Show task"),
 						                                (NotifyActionCallback) tsk_show_task_cb, appGUI, NULL);
 					}
@@ -422,64 +497,81 @@ TASK_NTF *a;
                         gui_save_data_and_run_command (config.global_notification_command, appGUI);
                     }
 
+					if (item->sound_enable && sound_flag) {
+						utl_play_alarm_sound (config.sound_alarm_repeat);
+						sound_flag = FALSE;
+					}
+
 #ifdef HAVE_LIBNOTIFY
+					/* Delete alarm warning */
+					tsk_delete_notify (item->id, appGUI);
+
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
 					}
 
-					appGUI->tsk->notifications = g_slist_append (appGUI->tsk->notifications, a);
+					appGUI->tsk->notifications = g_slist_prepend (appGUI->tsk->notifications, a);
 #endif /* HAVE_LIBNOTIFY */
 
-					gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
-					                    TA_COLUMN_ACTIVE, FALSE,
-					                    TA_COLUMN_ACTIVE_WARNING, FALSE, -1);
+				} else if (tsk_show_warning_notification (item, &iter, appGUI)) {
 
-				}
 #ifdef HAVE_LIBNOTIFY
-				else if (tsk_show_warning_notification (item, &iter, appGUI)) {
+					datestr = utl_date_time_print_default (item->due_date_julian, item->due_time, FALSE);
+					text = g_strdup_printf ("<b>%s</b>\n<i>%s</i>", item->summary, datestr);
+					g_free (datestr);
 
-					g_snprintf (tmpbuf2, BUFFER_SIZE, "<b>%s</b>\n<i>%s</i>",
-					            item->summary, get_date_time_full_str (item->due_date_julian, item->due_time));
-					g_strlcpy (tmpbuf, tmpbuf2, BUFFER_SIZE);
-					if (item->desc != NULL) {
-						if (strlen (item->desc)) {
-						    g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%.100s", tmpbuf2, item->desc);
-						}
-					}
+					textdesc = NULL;
+					if (item->desc != NULL && strlen (item->desc))
+						textdesc = g_strdup_printf ("%s\n%.100s", text, item->desc);
 
 					a = g_malloc (sizeof (TASK_NTF));
-					g_assert (a != NULL);
 
-					gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, TA_COLUMN_ID, &(a->id), -1);
-					a->item = get_task_item (&iter, appGUI);
+					a->id = item->id;
+					a->type = NOTIFY_WARNING;
 					a->time = -1;
 					a->date = 0;
-					a->notify = notify_notification_new (_("Alarm warning!"), tmpbuf, GTK_STOCK_DIALOG_INFO, NULL);
+					if (textdesc != NULL)
+						a->notify = notify_notification_new (_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO, NULL);
+					else
+						a->notify = notify_notification_new (_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO, NULL);
 
 					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
 					notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL);
-					notify_notification_add_action (a->notify, "show_task", _("Show task"),
-					                                (NotifyActionCallback)tsk_show_task_cb, appGUI, NULL);
+					if (tsk_get_category_state (item->category, STATE_TASKS, appGUI) == TRUE)
+						notify_notification_add_action (a->notify, "show_task", _("Show task"),
+						                                (NotifyActionCallback)tsk_show_task_cb, appGUI, NULL);
+
+#endif /* HAVE_LIBNOTIFY */
 
 					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
+#ifdef HAVE_LIBNOTIFY
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+#endif /* HAVE_LIBNOTIFY */
+				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
+
+						if (config.blink_on_events) {
+							gtk_status_icon_set_blinking (appGUI->osmo_trayicon, TRUE);
+						}
 					}
 
+					if (item->sound_enable && sound_flag) {
+						utl_play_alarm_sound (config.sound_alarm_repeat);
+						sound_flag = FALSE;
+					}
+
+#ifdef HAVE_LIBNOTIFY
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
 					}
 
-					appGUI->tsk->notifications = g_slist_append (appGUI->tsk->notifications, a);
-
-					gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
-					                    TA_COLUMN_ACTIVE_WARNING, FALSE, -1);
-				}
+					appGUI->tsk->notifications = g_slist_prepend (appGUI->tsk->notifications, a);
 #endif /* HAVE_LIBNOTIFY */
+				}
 
 			}
-			task_item_free (item);
+			tsk_item_free (item);
 		}
 	}
 
@@ -504,7 +596,7 @@ guint32 date;
                                 TA_COLUMN_DUE_DATE_JULIAN, &date, TA_COLUMN_CATEGORY, &category, -1);
 
             if (calendar == TRUE) {
-                if (date == julian_day && tasks_category_get_state (category, STATE_CALENDAR, appGUI) == TRUE) {
+                if (date == julian_day && tsk_get_category_state (category, STATE_CALENDAR, appGUI) == TRUE) {
                     return TRUE;
                 }
             } else if (date == julian_day) {
@@ -553,6 +645,9 @@ gint current_minute;
 
 				/* update systray status */
 				gui_systray_update_icon (appGUI);
+
+				/* set calendar cursor */
+				calendar_set_today (appGUI);
 			}
 
 		gui_systray_tooltip_update (appGUI);
@@ -591,51 +686,56 @@ check_tasks_contacts (guint32 julian_day, GUI *appGUI) {
 #ifdef CONTACTS_ENABLED
 
 gboolean
-check_contacts (guint32 julian_day, GUI *appGUI) {
+check_contacts (guint32 julian_day, GUI *appGUI)
+{
+	GtkTreeModel *model;
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	GDate *date = NULL;
+	guint32 julian;
+	gint age, year, flag;
 
-GtkTreePath *path;
-GtkTreeIter iter;
-GDate *new_cdate;
-guint32 date, age;
+	model = GTK_TREE_MODEL (appGUI->cnt->contacts_list_store);
+	g_return_val_if_fail (model != NULL, FALSE);
 
+	date = g_date_new ();
+	g_return_val_if_fail (date != NULL, FALSE);
 
-    if (appGUI->cnt->contacts_list_store != NULL) {
+	year = julian_to_year (julian_day);
+	flag = FALSE;
+	path = gtk_tree_path_new_first ();
 
-        path = gtk_tree_path_new_first();
+	while (gtk_tree_model_get_iter (model, &iter, path) == TRUE) {
+		gtk_tree_model_get (model, &iter, COLUMN_BIRTH_DAY_DATE, &julian, -1);
 
-        while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, path) == TRUE) {
-            gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, COLUMN_BIRTH_DAY_DATE, &date, -1);
-            if (date != 0) {
+		if (g_date_valid_julian (julian) == TRUE) {
 
-                new_cdate = g_date_new_julian (date);
+			g_date_set_julian (date, julian);
+			age = year - g_date_get_year (date);
 
-                if (new_cdate != NULL) {
+			if (age >= 0) {
+				if (g_date_valid_dmy (g_date_get_day (date), g_date_get_month (date), year) == FALSE) {
+					g_date_subtract_days (date, 1);
+				}
 
-                    age = g_date_get_year (appGUI->cal->date) - g_date_get_year (new_cdate);
+				g_date_set_year (date, year);
+				julian = g_date_get_julian (date);
 
-                    if (age >= 0) {
-						if (g_date_valid_dmy (g_date_get_day (new_cdate), g_date_get_month (new_cdate),
-						                      g_date_get_year (appGUI->cal->date)) == FALSE) {
-							g_date_subtract_days (new_cdate, 1);
-						}
+				if (julian_day == julian) {
+					flag = TRUE;
+					break;
+				}
+			}
 
-                        g_date_set_year (new_cdate, julian_to_year(julian_day));
-                        date = g_date_get_julian (new_cdate);
+		}
 
-                        if (date != 0 && julian_day == date) {
-                            return TRUE;
-                        }
-                    }
+		gtk_tree_path_next (path);
+	}
 
-                    g_date_free(new_cdate);
-                }
-            }
-            gtk_tree_path_next(path);
-        }
-        gtk_tree_path_free(path);
-    }
+	gtk_tree_path_free (path);
+	g_date_free (date);
 
-    return FALSE;
+	return flag;
 }
 
 #endif  /* CONTACTS_ENABLED */
@@ -651,7 +751,7 @@ button_event_checker_window_close_cb (GtkButton *button, gpointer user_data) {
     GUI *appGUI = (GUI *)user_data;
 
     gtk_widget_destroy (appGUI->event_checker_window);
-    gui_quit_osmo (TRUE, appGUI);
+    gui_quit_osmo (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -733,6 +833,35 @@ event_checker_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data
 
 /*------------------------------------------------------------------------------*/
 
+static gboolean
+add_note_to_event_window (struct note *n, GUI *appGUI)
+{
+	GtkTreeIter iter;
+	gchar *note_str, *date_str, *stripped;
+
+	note_str = cal_note_remove_empty_lines (n->note);
+	stripped = utl_gui_text_strip_tags (note_str);
+	g_free (note_str);
+	
+	date_str = g_strdup_printf ("%s\n(%s)",
+	                            julian_to_str (n->date, config.date_format, config.override_locale_settings),
+	                            utl_get_julian_day_name (n->date));
+
+	gtk_list_store_append (appGUI->event_checker_list_store, &iter);
+	gtk_list_store_set (appGUI->event_checker_list_store, &iter,
+	                    CE_COLUMN_DATE, date_str,
+	                    CE_COLUMN_DATE_JULIAN, n->date,
+	                    CE_COLUMN_EVENT_TYPE, _("Day note"),
+	                    CE_COLUMN_EVENT_LINE, stripped, -1);
+
+	g_free (stripped);
+	g_free (date_str);
+
+	return TRUE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gboolean
 create_event_checker_window (GUI *appGUI) {
 
@@ -744,21 +873,20 @@ GtkWidget           *close_button;
 GtkWidget           *show_osmo_button;
 GtkTreeViewColumn   *column, *julian_day_column;
 GtkCellRenderer     *renderer;
-GtkTreeIter         iter;
 
 #if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED)
 GtkTreePath         *path;
+GtkTreeIter         iter;
+gchar               date_str[BUFFER_SIZE];
+guint32             j;
 #endif
 
-guint32             i, j, start_date, current_date, julian_day;
-gboolean            day_notes_flag, tasks_flag;
-GSList              *lnode;
-struct note         *day_note;
-gchar               *tmp_note;
-gchar               date_str[BUFFER_SIZE];
+guint32             start_date, current_date;
+gboolean            day_notes_flag, tasks_flag = FALSE;
 
 #ifdef TASKS_ENABLED
 gchar               *summary, *category;
+guint32             julian_day;
 #endif  /* TASKS_ENABLED */
 
 #ifdef CONTACTS_ENABLED
@@ -771,32 +899,10 @@ gchar               *first_name, *last_name;
 
 
     start_date = config.lastrun_date;           /* - */
-    current_date = utl_get_current_julian () + appGUI->check_ndays_events;     /* + */
+    current_date = utl_date_get_current_julian () + appGUI->check_ndays_events;     /* + */
 
     /* check day notes */
-
-    day_notes_flag = FALSE;
-
-    if (appGUI->cal->notes_list != NULL) {
-
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-
-            day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-            julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
-
-            j = start_date;
-
-            while (j <= current_date) {
-                if (j == julian_day) {
-                    day_notes_flag = TRUE;
-                    break;
-                }
-                j++;
-            };
-
-            if (day_notes_flag == TRUE) break;
-        }
-    }
+	day_notes_flag = cal_check_notes (start_date, current_date, appGUI);
 
 
 #ifdef TASKS_ENABLED
@@ -814,8 +920,7 @@ gchar               *first_name, *last_name;
             j = start_date;
 
             while (j <= current_date) {
-                if (j == julian_day && (tasks_category_get_state (category, STATE_CALENDAR, appGUI) == TRUE ||
-                                        tasks_category_get_state (category, STATE_TASKS, appGUI) == TRUE)) {
+                if (j == julian_day && (tsk_get_category_state (category, STATE_EITHER, appGUI) == TRUE)) {
                     tasks_flag = TRUE;
                     break;
                 }
@@ -966,31 +1071,7 @@ gchar               *first_name, *last_name;
     /* insert day notes */
 
     if (day_notes_flag == TRUE) {
-
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
-
-            day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-            julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
-
-            j = start_date;
-
-            while (j <= current_date) {
-                if (j == julian_day) {                  
-                    tmp_note = cal_note_remove_empty_lines (day_note->note);
-                    gtk_list_store_append(appGUI->event_checker_list_store, &iter);
-                    sprintf(date_str, "%s\n(%s)", 
-                            julian_to_str (julian_day, config.date_format), utl_get_julian_day_name (julian_day));
-                    gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
-                                       CE_COLUMN_DATE, date_str,
-                                       CE_COLUMN_DATE_JULIAN, julian_day, 
-                                       CE_COLUMN_EVENT_TYPE, _("Day note"),
-                                       CE_COLUMN_EVENT_LINE, tmp_note, -1);
-                    g_free (tmp_note);
-                }
-                j++;
-            };
-        }
-
+		cal_notes_foreach (start_date, current_date, add_note_to_event_window, appGUI);
     }
 
 #ifdef TASKS_ENABLED
@@ -1010,11 +1091,11 @@ gchar               *first_name, *last_name;
             j = start_date;
 
             while (j <= current_date) {
-                if (j == julian_day && (tasks_category_get_state (category, STATE_CALENDAR, appGUI) == TRUE ||
-                                        tasks_category_get_state (category, STATE_TASKS, appGUI) == TRUE)) {
+                if (j == julian_day && (tsk_get_category_state (category, STATE_EITHER, appGUI) == TRUE)) {
                     gtk_list_store_append(appGUI->event_checker_list_store, &iter);
                     g_snprintf (date_str, BUFFER_SIZE, "%s\n(%s)", 
-                            julian_to_str (julian_day, config.date_format), utl_get_julian_day_name (julian_day));
+								julian_to_str (julian_day, config.date_format, config.override_locale_settings), 
+								utl_get_julian_day_name (julian_day));
                     gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
                                        CE_COLUMN_DATE, date_str,
                                        CE_COLUMN_DATE_JULIAN, julian_day, 
@@ -1072,8 +1153,9 @@ gchar               *first_name, *last_name;
                                     sprintf(tmpbuf, "%s %s", first_name, last_name);
                                 }
                                 gtk_list_store_append(appGUI->event_checker_list_store, &iter);
-                                sprintf(date_str, "%s\n(%s)", 
-                                        julian_to_str (j, config.date_format), utl_get_julian_day_name (j));
+                                sprintf (date_str, "%s\n(%s)", 
+                                         julian_to_str (j, config.date_format, config.override_locale_settings), 
+										 utl_get_julian_day_name (j));
                                 gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
                                                    CE_COLUMN_DATE, date_str,
                                                    CE_COLUMN_DATE_JULIAN, j, 
