@@ -25,7 +25,7 @@
 #include "gui.h"
 #include "tasks.h"
 
-enum {     
+enum {
     CE_COLUMN_DATE = 0,
     CE_COLUMN_DATE_JULIAN,
     CE_COLUMN_EVENT_TYPE,
@@ -33,14 +33,19 @@ enum {
     CHECK_EVENTS_NUM_COLUMNS
 };
 
+enum {
+	NOTIFY_WARNING = 0,
+	NOTIFY_ALARM
+};
+
 #ifdef HAVE_LIBNOTIFY
 #ifdef TASKS_ENABLED
 typedef struct {
-    guint id;
-    NotifyNotification *notify;
-    TASK_ITEM *item;
-    guint32 date;
-    gint time;
+	guint id;
+	gint type;
+	NotifyNotification *notify;
+	guint32 date;
+	gint time;
 } TASK_NTF;
 #endif  /* TASKS_ENABLED */
 #endif  /* HAVE_LIBNOTIFY */
