@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "contacts_items.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "utils_gui.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
@@ -201,9 +202,9 @@ guint32 date;
                             value = NULL;
                         } else {
                             if (i == COLUMN_BIRTH_DAY_DATE) {
-                                value = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                                value = g_strdup((const gchar *)julian_to_str(date, DATE_FULL, config.override_locale_settings));
                             } else {
-                                value = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                                value = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY, config.override_locale_settings));
                             }
                         }
                     } else {
@@ -414,9 +415,9 @@ gchar *fname, *sname, *lname;
                         text = NULL;
                     } else {
                         if (i == COLUMN_BIRTH_DAY_DATE) {
-                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL, config.override_locale_settings));
                         } else {
-                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY, config.override_locale_settings));
                         }
                     }
                 } else {
@@ -1005,6 +1006,8 @@ contacts_selection_activate (gboolean active, GUI *appGUI) {
 void
 store_contact_columns_info (GUI *appGUI) {
 
+	gint n;
+
 	config.contacts_column_idx_0 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_GROUP],
 																GTK_TREE_VIEW(appGUI->cnt->contacts_list), MAX_VISIBLE_CONTACT_COLUMNS, appGUI);
 	config.contacts_column_idx_1 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_FIRST_NAME], 
@@ -1012,9 +1015,40 @@ store_contact_columns_info (GUI *appGUI) {
 	config.contacts_column_idx_2 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_LAST_NAME], 
 																GTK_TREE_VIEW(appGUI->cnt->contacts_list), MAX_VISIBLE_CONTACT_COLUMNS, appGUI);
 
-	config.contacts_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 0));
-	config.contacts_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 1));
-	config.contacts_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 2));
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 0));
+	if (n > 1) {
+		config.contacts_column_idx_0_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 1));
+	if (n > 1) {
+		config.contacts_column_idx_1_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 2));
+	if (n > 1) {
+		config.contacts_column_idx_2_width = n;
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+set_contacts_columns_width (GUI *appGUI) {
+
+	GtkTreeViewColumn   *col;
+
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_GROUP);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.contacts_column_idx_0_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_FIRST_NAME);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.contacts_column_idx_1_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_LAST_NAME);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.contacts_column_idx_2_width - 
+											  2 * utl_gui_get_sw_vscrollbar_width (appGUI->cnt->scrolled_win));
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1022,22 +1056,21 @@ store_contact_columns_info (GUI *appGUI) {
 void
 gui_create_contacts(GUI *appGUI) {
 
-GtkWidget       *vbox1;
-GtkWidget       *vbox2;
-GtkWidget       *hbox2;
-GtkWidget       *hseparator;
-GtkWidget       *label;
-GtkWidget       *top_scrolledwindow;
-GtkWidget       *top_viewport;
-GtkWidget       *bottom_viewport;
-GtkWidget       *close_button;
-GtkCellRenderer *renderer[CONTACTS_NUM_COLUMNS];
-GType           contact_columns_types[CONTACTS_NUM_COLUMNS];
-GtkTextBuffer   *text_buffer;
-gint            i, n;
-GError          *error = NULL;
-GtkActionGroup  *action_group = NULL;
-GtkAdjustment   *adjustment;
+GtkWidget           *vbox1;
+GtkWidget           *vbox2;
+GtkWidget           *hbox2;
+GtkWidget           *hseparator;
+GtkWidget           *label;
+GtkWidget           *top_viewport;
+GtkWidget           *bottom_viewport;
+GtkWidget           *close_button;
+GtkCellRenderer     *renderer[CONTACTS_NUM_COLUMNS];
+GType               contact_columns_types[CONTACTS_NUM_COLUMNS];
+GtkTextBuffer       *text_buffer;
+gint                i, n;
+GError              *error = NULL;
+GtkActionGroup      *action_group = NULL;
+GtkAdjustment       *adjustment;
 gchar tmpbuf[BUFFER_SIZE];
 
 gint columns_order[MAX_VISIBLE_CONTACT_COLUMNS];
@@ -1217,12 +1250,12 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_viewport_set_shadow_type (GTK_VIEWPORT (top_viewport), GTK_SHADOW_NONE);
     gtk_paned_pack1 (GTK_PANED (appGUI->cnt->contacts_paned), top_viewport, FALSE, TRUE);
 
-    top_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_show (top_scrolledwindow);
-    gtk_container_add (GTK_CONTAINER (top_viewport), top_scrolledwindow);
+    appGUI->cnt->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_show (appGUI->cnt->scrolled_win);
+    gtk_container_add (GTK_CONTAINER (top_viewport), appGUI->cnt->scrolled_win);
 
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (top_scrolledwindow), GTK_SHADOW_IN);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (top_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (appGUI->cnt->scrolled_win), GTK_SHADOW_IN);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->cnt->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
     for(i=0; i< CONTACTS_NUM_COLUMNS; i++) {
         if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE || i == COLUMN_ID) {
@@ -1242,7 +1275,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->cnt->contacts_sort = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(appGUI->cnt->contacts_filter));
 
     appGUI->cnt->contacts_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->cnt->contacts_sort));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->cnt->contacts_list), config.contacts_rules_hint);
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(appGUI->cnt->contacts_list), config.rules_hint);
     gtk_widget_show (appGUI->cnt->contacts_list);
     GTK_WIDGET_SET_FLAGS (appGUI->cnt->contacts_list, GTK_CAN_DEFAULT);
     gtk_widget_modify_fg(GTK_WIDGET(appGUI->cnt->contacts_list), GTK_STATE_SELECTED,
@@ -1277,7 +1310,7 @@ guint n_entries = G_N_ELEMENTS (entries);
         }
     }
 
-    gtk_container_add (GTK_CONTAINER (top_scrolledwindow), appGUI->cnt->contacts_list);
+    gtk_container_add (GTK_CONTAINER (appGUI->cnt->scrolled_win), appGUI->cnt->contacts_list);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->cnt->contacts_list), FALSE);
 
 	/* restore columns order */
@@ -1298,12 +1331,7 @@ guint n_entries = G_N_ELEMENTS (entries);
 		}
 	}
 
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_GROUP),
-										  config.contacts_column_idx_0_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_FIRST_NAME),
-										  config.contacts_column_idx_1_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_LAST_NAME),
-										  config.contacts_column_idx_2_width - 2 * utl_gui_get_sw_vscrollbar_width (top_scrolledwindow));
+	set_contacts_columns_width (appGUI);
 
     /* configure sorting */
 
