@@ -29,6 +29,7 @@
 #include "calendar_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "utils_date.h"
 
 #ifdef CONTACTS_ENABLED
 
@@ -206,7 +207,7 @@ gboolean flag, leap;
 	                                                        G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
 
 	appGUI->cnt->birthdays_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (appGUI->cnt->birthdays_list_store));
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), config.contacts_rules_hint);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), config.rules_hint);
 	gtk_widget_show (appGUI->cnt->birthdays_list);
 	GTK_WIDGET_SET_FLAGS (appGUI->cnt->birthdays_list, GTK_CAN_DEFAULT);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), appGUI->cnt->birthdays_list);
@@ -262,7 +263,7 @@ gboolean flag, leap;
 
 	i = 0;
 
-	g_date_set_julian (cdate_current, utl_get_current_julian ());
+	g_date_set_julian (cdate_current, utl_date_get_current_julian ());
 	c_day = g_date_get_day (cdate_current);
 	c_month = g_date_get_month (cdate_current);
 	c_year = g_date_get_year (cdate_current);
@@ -336,7 +337,7 @@ gboolean flag, leap;
 			}
 
 			g_date_strftime (buff, BUFFER_SIZE, "%A, ", cdate_birthday);
-			g_strlcat (buff, julian_to_str (g_date_get_julian (cdate_birthday), config.date_format), BUFFER_SIZE);
+			g_strlcat (buff, julian_to_str (g_date_get_julian (cdate_birthday), config.date_format, config.override_locale_settings), BUFFER_SIZE);
 
 			gtk_list_store_set (appGUI->cnt->birthdays_list_store, &n_iter,
 			                    B_COLUMN_DAYS_NUM, date, B_COLUMN_DAYS, buffer,
