@@ -22,6 +22,7 @@
 #include "contacts_export.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "utils_gui.h"
 #include "contacts.h"
 #include "calendar_utils.h"
@@ -246,9 +247,9 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
                                         text = NULL;
                                     } else {
                                         if (i == COLUMN_BIRTH_DAY_DATE) {
-                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL, config.override_locale_settings));
                                         } else {
-                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY, config.override_locale_settings));
                                         }
                                     }
                                 } else {
