@@ -24,6 +24,7 @@
 #include "contacts_import_syncml.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "utils_gui.h"
 #include "contacts.h"
 #include "calendar_utils.h"
@@ -68,7 +69,7 @@ import_contacts_select_file_cb (GtkWidget *widget, gpointer user_data) {
 GtkWidget *dialog;
 GtkFileFilter *filter_1, *filter_2;
 #ifndef HAVE_LIBSYNCML
-gboolean ret;
+gboolean ret = FALSE;
 #endif
 
 #ifdef HAVE_LIBSYNCML
@@ -681,9 +682,10 @@ gint i, k, n;
 void
 start_import_cb (GtkWidget *widget, gpointer data) {
 
-gint i, j, k, n, m, p;
+gint i, j, k, n, m, p, w;
 guint n_records;
 gchar *str, *field_str, *item, *text;
+gchar ch[2] = { 0, 0 };
 GtkTreeIter iter, g_iter;
 gboolean g_flag;
 gchar tmpbuf[BUFFER_SIZE];
@@ -723,6 +725,11 @@ gchar tmpbuf[BUFFER_SIZE];
 
                         p = strlen(field_str);
 
+						for (w = 0; w < p; w++) {      /* remove control chars */
+							ch[0] = field_str[w];
+							if (g_unichar_iscntrl(g_utf8_get_char(ch))) field_str[w] = ' ';
+						}
+
                         if (appGUI->cnt->field_type[i]-1 == COLUMN_FIRST_NAME){
                             if (p) {
                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_FIRST_NAME, field_str, -1);
