@@ -28,6 +28,7 @@
 #include "calendar_widget.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "utils_gui.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
@@ -150,6 +151,7 @@ const gchar *text;
         }
     }
 
+	appGUI->cnt->write_flag = TRUE;
     contacts_add_edit_window_close_cb (NULL, NULL, appGUI);
    
     pango_font_description_free(appGUI->cnt->fd_ai_font);
@@ -332,14 +334,14 @@ guint32 julian_day;
     gui_calendar_get_date (s_calendar, &year, &month, &day);
     gtk_widget_destroy(msg->appGUI->cnt->select_date_window);
 
-    julian_day = utl_dmy_to_julian (day, month + 1, year);
+    julian_day = utl_date_dmy_to_julian (day, month + 1, year);
 
     if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
-        temp = julian_to_str (julian_day, DATE_FULL);
+        temp = julian_to_str (julian_day, DATE_FULL, config.override_locale_settings);
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_BIRTH_DAY_DATE]), temp);
         msg->appGUI->cnt->birthday_date = julian_day;
     } else if (msg->data == (gpointer)COLUMN_NAME_DAY_DATE) {
-        temp = julian_to_str (julian_day, DATE_NAME_DAY);
+        temp = julian_to_str (julian_day, DATE_NAME_DAY, config.override_locale_settings);
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_NAME_DAY_DATE]), temp);
         msg->appGUI->cnt->nameday_date = julian_day;
     }
@@ -434,14 +436,10 @@ static MESSAGE msg_selected;
 
     msg->appGUI->cnt->select_date_calendar = gui_calendar_new();
     gui_calendar_set_cursor_type (GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar), CURSOR_BLOCK);
-    gui_calendar_set_selector_alpha (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                             config.selector_alpha);
-    gui_calendar_set_today_marker_type (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                             config.today_marker_type);
-    gui_calendar_set_today_marker_color (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                             config.mark_current_day_color);
-    gui_calendar_set_today_marker_alpha (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                             config.mark_current_day_alpha);
+    gui_calendar_set_color (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), config.selection_color, config.selector_alpha, SELECTOR_COLOR);
+    gui_calendar_set_marker (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), config.today_marker_type, TODAY_MARKER);
+    gui_calendar_set_color (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                config.mark_current_day_color, config.mark_current_day_alpha, TODAY_MARKER_COLOR);
     gtk_widget_show(msg->appGUI->cnt->select_date_calendar);
     msg_selected.data = msg->data;
     msg_selected.appGUI = msg->appGUI;
@@ -1146,10 +1144,10 @@ gchar *contact_replace_tags[] = {
                         } else {
                             if (i == COLUMN_BIRTH_DAY_DATE) {
                                 appGUI->cnt->birthday_date = date;
-                                text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                                text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL, config.override_locale_settings));
                             } else {
                                 appGUI->cnt->nameday_date = date;
-                                text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                                text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY, config.override_locale_settings));
                             }
                         }
                     } else {
@@ -1231,15 +1229,16 @@ gchar tmpbuf[BUFFER_SIZE];
                 while (group_node != NULL) {
 
                     if ((!xmlStrcmp(group_node->name, (const xmlChar *) "name"))) {
-                        key = xmlNodeGetContent(group_node->xmlChildrenNode);
-                        context = xmlCreateDocParserCtxt(key);
-	                    out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
-                	    xmlFreeParserCtxt (context);
+                        key = xmlNodeGetContent (group_node->xmlChildrenNode);
+                        context = xmlCreateDocParserCtxt (key);
+                        out = (xmlChar*) xmlStringDecodeEntities (context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                        xmlFreeParserCtxt (context);
                         if (out != NULL) {
                             gtk_list_store_append(appGUI->opt->contacts_group_store, &iter);
                             gtk_list_store_set(appGUI->opt->contacts_group_store, &iter, 0, (gchar *) out, -1);
                         }
-                        xmlFree(out);
+                        xmlFree (out);
+                        xmlFree (key);
                     }
 
                     group_node = group_node->next;
@@ -1275,22 +1274,24 @@ gchar tmpbuf[BUFFER_SIZE];
                                         if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
                                             key = xmlNodeGetContent(cnode->xmlChildrenNode);
                                             context = xmlCreateDocParserCtxt(key);
-	                                        out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
-                	                        xmlFreeParserCtxt (context);
+                                            out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                                            xmlFreeParserCtxt (context);
                                             if (out != NULL) {
                                                 sscanf((gchar *) out, "%d", &date);
                                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, date, -1);
                                                 xmlFree(out);
                                             }
+                                            xmlFree (key);
                                         } else {
                                             key = xmlNodeGetContent(cnode->xmlChildrenNode);
                                             context = xmlCreateDocParserCtxt(key);
-	                                        out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
-                	                        xmlFreeParserCtxt (context);
+                                            out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                                            xmlFreeParserCtxt (context);
                                             if (out != NULL) {
                                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, out, -1);
                                                 xmlFree(out);
                                             }
+                                            xmlFree (key);
                                         }
                                     }
                                 }
@@ -1313,9 +1314,21 @@ gchar tmpbuf[BUFFER_SIZE];
 
         xmlFree(node);
         xmlFreeDoc(doc);
-    }
 
-    contacts_fill_ids (appGUI);
+		appGUI->cnt->write_flag = TRUE;
+
+		contacts_fill_ids (appGUI);
+
+	} else {
+
+		appGUI->cnt->write_flag = FALSE;
+
+		/* FIXME: add translation here */
+        sprintf (tmpbuf, "Contacts file is malformed. Please edit\n<b>%s</b>\nfile manually to fix its structure and restart the Osmo.", 
+				 prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI));
+		utl_gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, NULL);
+	}
+
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1332,7 +1345,7 @@ gchar *item;
 guint32 date;
 gchar temp[BUFFER_SIZE];
 
-    if ((appGUI->save_status & WRT_CONTACTS) != 0) return;
+    if (((appGUI->save_status & WRT_CONTACTS) != 0) || appGUI->cnt->write_flag == FALSE) return;
 
     appGUI->save_status |= WRT_CONTACTS;
 
@@ -1387,6 +1400,7 @@ gchar temp[BUFFER_SIZE];
     }
 
     xmlSaveFormatFileEnc (prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+    xmlFree (attr);
     xmlFreeDoc (doc);
 
     appGUI->save_status &= ~WRT_CONTACTS;
