@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "utils_date.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_fullyear.h"
@@ -56,7 +57,7 @@
 void
 gui_save_data_and_run_command (gchar *command, GUI *appGUI) {
     gui_save_all_data (appGUI);
-    utl_run_command (command);
+    utl_run_command (command, FALSE);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -96,11 +97,17 @@ gui_toggle_window_visibility (GUI *appGUI) {
 
         if (appGUI->window_visible == TRUE) {
             gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+            gtk_window_set_default_size (GTK_WINDOW(appGUI->main_window), 
+										 config.window_size_x, config.window_size_y);
             gtk_window_move (GTK_WINDOW (appGUI->main_window), config.window_x, config.window_y);
             gtk_widget_show (appGUI->main_window);
         } else {
             if (appGUI->calendar_only == FALSE) {
                 gui_save_all_data (appGUI);
+				gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
+									&config.window_size_x, &config.window_size_y);
+				gdk_window_get_root_origin (GDK_WINDOW(appGUI->main_window->window),
+									&config.window_x, &config.window_y);
             }
             gtk_widget_hide (appGUI->main_window);
         }
@@ -110,16 +117,16 @@ gui_toggle_window_visibility (GUI *appGUI) {
 /*------------------------------------------------------------------------------*/
 
 void
-gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
+gui_quit_osmo (GUI *appGUI) {
 
 #ifdef NOTES_ENABLED
     if (appGUI->nte->editor_active == TRUE) {
-        g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+        g_signal_emit_by_name (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
     }
 #endif  /* NOTES_ENABLED */
 
     if (appGUI->osmo_trayicon != NULL) {
-        gtk_status_icon_set_visible(appGUI->osmo_trayicon, FALSE);
+        gtk_status_icon_set_visible (appGUI->osmo_trayicon, FALSE);
     }
 
     if (appGUI->calendar_only == FALSE) {
@@ -151,13 +158,13 @@ gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
 
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(appGUI->cal->notes_button), FALSE);
 
-        if (ignore_geometry == FALSE) {
+        if (appGUI->window_visible == TRUE) {
             gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
                                 &config.window_size_x, &config.window_size_y);
         }
     } 
 
-    if (ignore_geometry == FALSE) {
+    if (appGUI->window_visible == TRUE) {
         gdk_window_get_root_origin (GDK_WINDOW(appGUI->main_window->window),
                             &config.window_x, &config.window_y);
     }
@@ -171,8 +178,8 @@ gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
 #endif  /* NOTES_ENABLED */
 
     if (appGUI->calendar_only == FALSE) {
-        config.lastrun_date = utl_get_current_julian ();
-        config.lastrun_time = get_seconds_for_today();
+        config.lastrun_date = utl_date_get_current_julian ();
+        config.lastrun_time = utl_time_get_current_seconds ();
         gui_save_all_data (appGUI);
 #ifdef HAVE_LIBNOTIFY
 #ifdef TASKS_ENABLED
@@ -200,7 +207,7 @@ gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
     if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
         gui_toggle_window_visibility (appGUI);
     } else {
-        gui_quit_osmo(FALSE, appGUI);
+        gui_quit_osmo (appGUI);
     }
 }
 
@@ -339,7 +346,9 @@ gchar tmpbuff[BUFFER_SIZE];
         gtk_widget_show (dialog);
         gtk_dialog_run(GTK_DIALOG(dialog));
         gtk_widget_destroy(dialog);
-    }
+    } else if (appGUI->key_counter == 41) {
+		appGUI->cal->datecal_bio = TRUE;
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -436,6 +445,13 @@ gint page;
                     if (appGUI->calendar_only == FALSE) {
                         cal_notes_browser (appGUI);
                     }
+                    key_counter_add (11, appGUI);
+                    return TRUE;
+                case GDK_i:
+                    key_counter_add (9, appGUI);
+                    return TRUE;
+                case GDK_o:
+                    key_counter_add (21, appGUI);
                     return TRUE;
             }
 
@@ -478,6 +494,40 @@ gint page;
                     return TRUE;
                 }
                 return FALSE;
+			case GDK_b:
+				if (event->state & GDK_CONTROL_MASK) {  /* CTRL + b */
+					g_signal_emit_by_name(G_OBJECT(appGUI->cal->ta_bold_button), "clicked");
+					return TRUE;
+				}
+				return FALSE;
+
+			case GDK_i:
+				if (event->state & GDK_CONTROL_MASK) {  /* CTRL + i */
+					g_signal_emit_by_name(G_OBJECT(appGUI->cal->ta_italic_button), "clicked");
+					return TRUE;
+				}
+				return FALSE;
+
+			case GDK_m:
+				if (event->state & GDK_CONTROL_MASK) {  /* CTRL + m */
+					g_signal_emit_by_name(G_OBJECT(appGUI->cal->ta_highlight_button), "clicked");
+					return TRUE;
+				}
+				return FALSE;
+
+			case GDK_u:
+				if (event->state & GDK_CONTROL_MASK) {  /* CTRL + u */
+					g_signal_emit_by_name(G_OBJECT(appGUI->cal->ta_underline_button), "clicked");
+					return TRUE;
+				}
+				return FALSE;
+
+			case GDK_t:
+				if (event->state & GDK_CONTROL_MASK) {  /* CTRL + t */
+					g_signal_emit_by_name(G_OBJECT(appGUI->cal->ta_strikethrough_button), "clicked");
+					return TRUE;
+				}
+				return FALSE;
         }
 
     }
@@ -504,7 +554,7 @@ gint page;
                 case GDK_Return:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Enter */
                         if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, NULL, NULL)) {
-                            tasks_add_edit_dialog_show (TRUE, 0, get_seconds_for_today(), appGUI);
+                            tasks_add_edit_dialog_show (TRUE, 0, utl_time_get_current_seconds (), appGUI);
                             return TRUE;
                         }
                     }
@@ -527,7 +577,7 @@ gint page;
                     tasks_remove_dialog_show(appGUI->tsk->tasks_list, appGUI->tsk->tasks_list_store, appGUI);
                     return TRUE;
                 case GDK_Insert:
-                    tasks_add_edit_dialog_show (FALSE, 0, get_seconds_for_today(), appGUI);
+                    tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
                     return TRUE;
                 case GDK_Left:
                     if (appGUI->tsk->filter_index > 0) {
@@ -695,8 +745,11 @@ gint page;
                     return FALSE;
 
                 case GDK_Escape:
-                    g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
-                    return TRUE;
+					if (appGUI->nte->find_hbox_visible == FALSE) {
+	                    g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+                        return TRUE;
+					}
+                    return FALSE;
 
                 case GDK_b:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + b */
@@ -814,7 +867,7 @@ gint page;
 
         case GDK_q:
             if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Q */
-                gui_quit_osmo(FALSE, appGUI);
+                gui_quit_osmo (appGUI);
             }
             return FALSE;
 
@@ -1029,17 +1082,12 @@ trayicon_popup_cb (GtkStatusIcon *status_icon, guint button, guint activate_time
 
     gtk_menu_popup(GTK_MENU(appGUI->trayicon_popup_menu), NULL, NULL, NULL, NULL, 
                    button, activate_time);
-
 }
 
 void
 systray_popup_menu_quit_selected_cb (gpointer user_data) {
     GUI *appGUI = (GUI *)user_data;
-    if (appGUI->window_visible == FALSE) {
-        gtk_widget_show (appGUI->main_window);
-        appGUI->window_visible = TRUE;
-    }
-    gui_quit_osmo(FALSE, appGUI);
+    gui_quit_osmo (appGUI);
 }
 
 void
@@ -1051,6 +1099,7 @@ systray_popup_menu_show_calendar_selected_cb (gpointer user_data) {
     }
     gtk_window_deiconify (GTK_WINDOW(appGUI->main_window));
     gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CALENDAR);
 }
 
@@ -1064,6 +1113,7 @@ systray_popup_menu_show_tasks_selected_cb (gpointer user_data) {
     }
     gtk_window_deiconify (GTK_WINDOW(appGUI->main_window));
     gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_TASKS);
 }
 #endif  /* TASKS_ENABLED */
@@ -1078,6 +1128,7 @@ systray_popup_menu_show_contacts_selected_cb (gpointer user_data) {
     }
     gtk_window_deiconify (GTK_WINDOW(appGUI->main_window));
     gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CONTACTS);
 }
 #endif  /* CONTACTS_ENABLED */
@@ -1092,6 +1143,7 @@ systray_popup_menu_show_notes_selected_cb (gpointer user_data) {
     }
     gtk_window_deiconify (GTK_WINDOW(appGUI->main_window));
     gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_NOTES);
 }
 #endif  /* NOTES_ENABLED */
@@ -1105,6 +1157,7 @@ systray_popup_menu_show_options_selected_cb (gpointer user_data) {
     }
     gtk_window_deiconify (GTK_WINDOW(appGUI->main_window));
     gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+	gtk_status_icon_set_blinking (appGUI->osmo_trayicon, FALSE);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_OPTIONS);
 }
 
@@ -1113,25 +1166,21 @@ systray_popup_menu_show_options_selected_cb (gpointer user_data) {
 void
 gui_systray_tooltip_update (GUI *appGUI)
 {
-gchar desc[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
-guint32 julian;
-gboolean flag;
+	gchar *tstr, *dstr, *text;
 
-	flag = FALSE;
-	julian = utl_get_current_julian ();
+	if (appGUI->osmo_trayicon == NULL) return;
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%s", julian_to_str (julian, DATE_FULL));
-	desc[0] = '\0';
-	g_strlcat (desc, tmpbuf, BUFFER_SIZE);
+	dstr = utl_date_print_j (utl_date_get_current_julian (), DATE_FULL,
+	                         config.override_locale_settings);
 
-	if (config.time_format == TIME_24) {
-        g_snprintf (tmpbuf, BUFFER_SIZE, ", %s", current_time_to_str(TIME_HH_MM));
-    } else {
-        g_snprintf (tmpbuf, BUFFER_SIZE, ", %s", current_time_to_str(TIME_HH_MM_AMPM));
-    }
-	g_strlcat (desc, tmpbuf, BUFFER_SIZE);
+	tstr = utl_time_print_default (utl_time_get_current_seconds (), FALSE);
 
-	gtk_status_icon_set_tooltip (appGUI->osmo_trayicon, desc);
+	text = g_strdup_printf ("%s, %s", dstr, tstr);
+	gtk_status_icon_set_tooltip (appGUI->osmo_trayicon, text);
+
+	g_free (tstr);
+	g_free (dstr);
+	g_free (text);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1144,10 +1193,10 @@ gboolean flag = FALSE;
         
 	if (appGUI->window_visible == TRUE) return;
 
-    julian_day = utl_get_current_julian ();
+    julian_day = utl_date_get_current_julian ();
 
 	if (config.ignore_day_note_events == FALSE) {
-		if (check_note (utl_get_current_day (), utl_get_current_month (), utl_get_current_year (), appGUI) == TRUE) {
+		if (cal_check_note (julian_day, appGUI) == TRUE) {
 			gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NOTE);
 			flag = TRUE;
 		}
@@ -1283,7 +1332,7 @@ GtkWidget   *systray_menu_separator;
             appGUI->no_tray = FALSE;
             gtk_status_icon_set_visible (appGUI->osmo_trayicon, TRUE);
             if (config.start_minimised_in_systray) {
-                gui_toggle_window_visibility (appGUI);
+                appGUI->window_visible = FALSE;
             } else {
                 gtk_widget_show (appGUI->main_window);
             }
@@ -1303,6 +1352,7 @@ gboolean
 gui_create_window (GUI *appGUI) {
 
 GdkPixbuf   *icon;
+gchar tmpbuf[BUFFER_SIZE];
 
 #ifdef CONTACTS_ENABLED
     appGUI->cnt->contacts_filter_disabled = TRUE;
@@ -1318,7 +1368,9 @@ GdkPixbuf   *icon;
 #endif  /* NOTES_ENABLED */
 
     appGUI->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title (GTK_WINDOW (appGUI->main_window), _(APPLICATION_NAME));
+
+	g_snprintf (tmpbuf, BUFFER_SIZE, "Osmo %d.%d.%d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
+    gtk_window_set_title (GTK_WINDOW (appGUI->main_window), tmpbuf);
 
    	gtk_widget_set_events(appGUI->main_window, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
@@ -1493,7 +1545,6 @@ const gchar *calendar_keys_text[] = {
     "<Space>",                  N_("select current date"),
     "<Ctrl+Space>",             N_("toggle personal data visibility"),
     "<Arrows>",                 N_("change day"),
-    "<Alt+Arrows>",             N_("change day while note editing"),
     "<Ctrl+Up/Down>",           N_("scroll the contents in the day info panel"),
     "<PageUp/PageDn>",          N_("change month"),
     "<Home/End>",               N_("change year"),
@@ -1503,8 +1554,25 @@ const gchar *calendar_keys_text[] = {
     "<d>",                      N_("date calculator"),
     "<f>",                      N_("show full-year calendar"),
     "<g>",                      N_("jump to date"),
-    "<Delete>",                 N_("remove day note"),
-    "<Esc>",                    N_("close day note panel")
+    "<Delete>",                 N_("remove day note")
+};
+
+const gchar *calendar_editor_keys_text[] = {
+    "<Alt+Arrows>",             N_("change day"),
+    "<Esc>",                    N_("close editor"),
+    "<Ctrl+b>",                 N_("toggle bold"),
+    "<Ctrl+i>",                 N_("toggle italic"),
+    "<Ctrl+u>",                 N_("toggle underline"),
+    "<Ctrl+t>",                 N_("toggle strikethrough"),
+    "<Ctrl+m>",                 N_("toggle highlight")
+};
+
+const gchar *calendar_fy_keys_text[] = {
+	"<Arrows Up/Down>",         N_("change year"),
+	"<F1>",                     N_("toggle alternative view"),
+	"<F2>",                     N_("year info"),
+	"<F3>",                     N_("set current year"),
+    "<Esc>",                    N_("close full-year calendar")
 };
 
 #ifdef TASKS_ENABLED
@@ -1542,11 +1610,11 @@ const gchar *notes_editor_keys_text[] = {
     "<Ctrl+w>",                 N_("close note editor"),
     "<Ctrl+s>",                 N_("save note"),
     "<Ctrl+f>",                 N_("find text"),
-    "<Ctrl+b>",                 N_("mark selection in bold"),
-    "<Ctrl+i>",                 N_("mark selection in italic"),
-    "<Ctrl+m>",                 N_("mark selection in background color"),
-    "<Ctrl+u>",                 N_("underline selection"),
-    "<Ctrl+t>",                 N_("strikethrough selection"),
+    "<Ctrl+b>",                 N_("toggle bold"),
+    "<Ctrl+i>",                 N_("toggle italic"),
+    "<Ctrl+u>",                 N_("toggle underline"),
+    "<Ctrl+t>",                 N_("toggle strikethrough"),
+    "<Ctrl+m>",                 N_("toggle highlight"),
     "<Ctrl+n>",                 N_("clear selection attributes")
 };
 #endif  /* NOTES_ENABLED */
@@ -1575,7 +1643,24 @@ gint i;
         sprintf(tmpbuf, "\t%s - %s\n", calendar_keys_text[i*2], gettext(calendar_keys_text[i*2+1]));
         gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
     }
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
+
+	snprintf(tmpbuf, BUFFER_SIZE-1, "\t%s:\n", _("Note editor"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
+
+    for (i=0; i < G_N_ELEMENTS(calendar_editor_keys_text)/2; i++) {    
+        sprintf(tmpbuf, "\t%s - %s\n", calendar_editor_keys_text[i*2], gettext(calendar_editor_keys_text[i*2+1]));
+        gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
+    }
+
+	snprintf(tmpbuf, BUFFER_SIZE-1, "\t%s:\n", _("Full-year calendar"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
+
+    for (i=0; i < G_N_ELEMENTS(calendar_fy_keys_text)/2; i++) {    
+        sprintf(tmpbuf, "\t%s - %s\n", calendar_fy_keys_text[i*2], gettext(calendar_fy_keys_text[i*2+1]));
+        gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
+    }
+
+	gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
 
 #ifdef TASKS_ENABLED
     snprintf(tmpbuf, BUFFER_SIZE-1, "* %s\n", _("Tasks"));
@@ -1680,33 +1765,66 @@ gchar tmpbuf[BUFFER_SIZE];
     utl_gui_clear_text_buffer (appGUI->about_entry_buffer, &appGUI->about_entry_iter);
 
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
-    sprintf(tmpbuf, "%s\n", _("A handy personal organizer"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
+    sprintf (tmpbuf, "%s\n", _("A handy personal organizer"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
                                               &appGUI->about_entry_iter, tmpbuf, -1, "big", "center", NULL);
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
 
-    utl_gui_url_insert_link (&appGUI->about_links_list, &appGUI->about_link_index, 
-							 appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-							 NULL, "http://clay.ll.pl/osmo", TRUE, appGUI);
+    utl_gui_url_insert_link (&appGUI->about_links_list, &appGUI->about_link_index,
+							 appGUI->about_textview, &appGUI->about_entry_iter, NULL,
+							 NULL, "http://clayo.org/osmo", TRUE, appGUI);
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
 
     sprintf(tmpbuf, "\n(%s %s, %s)\n\n", _("compiled on"), __DATE__, __TIME__);
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
                                               &appGUI->about_entry_iter, tmpbuf, -1, "center", "italic", NULL);
 
-	add_credits_section (appGUI, _("Programming"), credits_programming, 
+	add_credits_section (appGUI, _("Programming"), credits_programming,
 						 G_N_ELEMENTS(credits_programming));
-	add_credits_section (appGUI, _("Graphics"), credits_graphics, 
+	add_credits_section (appGUI, _("Graphics"), credits_graphics,
 						 G_N_ELEMENTS(credits_graphics));
-	add_credits_section (appGUI, _("Contributors"), credits_contributors, 
+	add_credits_section (appGUI, _("Contributors"), credits_contributors,
 						 G_N_ELEMENTS(credits_contributors));
-	add_credits_section (appGUI, _("Translators"), credits_translators, 
+	add_credits_section (appGUI, _("Translators"), credits_translators,
 						 G_N_ELEMENTS(credits_translators));
 
-    /* Available modules */
+    /* Links */
+
+	sprintf(tmpbuf, "\n %s:\n", _("Mailing lists"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
+                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
+
+	gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\t      ", -1);
+	utl_gui_url_insert_link (&appGUI->about_links_list, &appGUI->about_link_index,
+							 appGUI->about_textview, &appGUI->about_entry_iter, NULL,
+							 NULL, "http://sourceforge.net/mail/?group_id=206587", FALSE, appGUI);
+    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
+
+	sprintf(tmpbuf, "\n %s:\n", _("Bug tracker"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
+                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
+
+	gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\t      ", -1);
+	utl_gui_url_insert_link (&appGUI->about_links_list, &appGUI->about_link_index,
+							 appGUI->about_textview, &appGUI->about_entry_iter, NULL,
+							 NULL, "http://sourceforge.net/tracker/?group_id=206587&atid=998196", FALSE, appGUI);
+    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
+
+	sprintf(tmpbuf, "\n %s:\n", _("Feature requests"));
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
+                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
+
+	gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\t      ", -1);
+	utl_gui_url_insert_link (&appGUI->about_links_list, &appGUI->about_link_index,
+							 appGUI->about_textview, &appGUI->about_entry_iter, NULL,
+							 NULL, "http://sourceforge.net/tracker/?group_id=206587&atid=998199", FALSE, appGUI);
+    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
+
+
+	/* Available modules */
 
     sprintf(tmpbuf, "\n %s:\n", _("Available modules"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
+    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
                                               &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
 
     sprintf(tmpbuf, "     [+]\t%s\n", _("Calendar"));
@@ -1761,6 +1879,13 @@ gchar tmpbuf[BUFFER_SIZE];
 #endif  /* HAVE_LIBSYNCML */
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
 
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+    sprintf(tmpbuf, "     [+]\t%s (libtar + libgringotts)\n", _("Backup support"));
+#else
+    sprintf(tmpbuf, "     [-]\t%s (libtar + libgringotts)\n", _("Backup support"));
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
+    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
+
 #ifdef PRINTING_SUPPORT
     sprintf(tmpbuf, "     [+]\t%s\n", _("Printing support"));
 #else
@@ -1839,13 +1964,13 @@ button_released_cb (GtkButton *button, gpointer user_data) {
 void 
 gui_create_about(GUI *appGUI) {
 
-GtkWidget *vbox1, *hbox;
+GtkWidget *vbox1, *hbox = NULL;
 GtkWidget *label;
 GtkWidget *hseparator;
 GtkWidget *logo_area;
 GdkPixbuf *logo, *logo_scaled = NULL;
 GtkWidget *viewport;
-GtkWidget *hbuttonbox;
+GtkWidget *hbuttonbox = NULL;
 GSList    *radiobutton_group = NULL;
 char tmpbuf[BUFFER_SIZE];
 
