@@ -54,9 +54,12 @@
 #include <libgringotts.h>
 #endif  /* HAVE_LIBGRINGOTTS */
 
-#define     APPLICATION_NAME        "Osmo (handy personal organizer)"
 #define     TRANSLATION_DOMAIN      "osmo"
 
+#define     VERSION_MAJOR           0
+#define     VERSION_MINOR           2
+#define     VERSION_MICRO           8
+
 #define     MAX_MONTHS              12
 #define     MAX_WEEKS               6
 #define     DAYS_PER_WEEK           7
@@ -97,8 +100,8 @@ enum {                  /* tasks columns */
     TA_COLUMN_COLOR,
     TA_COLUMN_BOLD,
 	TA_COLUMN_ACTIVE,
-	TA_COLUMN_ACTIVE_WARNING,
 	TA_COLUMN_OFFLINE_IGNORE,
+	TA_COLUMN_SOUND_ENABLE,
 	TA_COLUMN_REPEAT,
 	TA_COLUMN_REPEAT_DAY,
 	TA_COLUMN_REPEAT_MONTH_INTERVAL,
@@ -220,6 +223,11 @@ typedef struct {
     GtkTextBuffer *day_desc_text_buffer;
     GtkTextIter day_desc_iter;
     PangoFontDescription *fd_notes_font;
+	GtkWidget *ta_bold_button;
+	GtkWidget *ta_italic_button;
+	GtkWidget *ta_underline_button;
+	GtkWidget *ta_strikethrough_button;
+	GtkWidget *ta_highlight_button;
 
     /* calendar popup menu */
     GtkWidget *popup_menu;
@@ -254,10 +262,12 @@ typedef struct {
     GtkTreeSelection *colors_category_select;
 
     /* full year calendar */
+	gint last_selected_year;
     GtkWidget *fullyear_window;
     GtkWidget *fycal_table_1;
     GtkWidget *fycal_table_2;
     GtkWidget *fy_spinbutton;
+	GtkWidget *fy_alternative_view_checkbutton;
     GtkWidget *cyear_button;
     GtkWidget *fy_calendars[MAX_MONTHS];
     GtkWidget *calendar_buttons[MAX_MONTHS*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))];
@@ -314,6 +324,8 @@ typedef struct {
     GtkWidget *spinbutton2_end_second;
     GtkWidget *label2_result;
     GtkWidget *radiobutton_add;
+	GtkWidget *ignore_weekend_days_checkbutton;
+	gboolean datecal_bio;
 
     /* iCalendar */
     GtkWidget *events_window;
@@ -323,6 +335,7 @@ typedef struct {
     GtkWidget *ical_events_list;
     GtkTreeSelection *ical_events_list_selection;
     GtkListStore *ical_events_list_store;
+	GtkTreeModel *ical_events_sort;
     GtkWidget *ical_export_window;
     GtkWidget *output_file_entry;
     GtkWidget *ical_export_vpaned;
@@ -378,6 +391,7 @@ typedef struct {
     GtkWidget *tasks_list;
     GtkTreeSelection *tasks_list_selection;
 
+	GtkWidget *scrolled_win;
     gboolean tasks_panel_status;
     GtkListStore *tasks_list_store;
     GtkWidget *panel_hbox;
@@ -394,7 +408,7 @@ typedef struct {
     gint filter_index;
     gboolean tasks_filter_disabled;
     GtkUIManager *tasks_uim_widget;
-    guint id_counter;
+    guint next_id;
 
     /* tasks items */
     GtkWidget *td_calendar;
@@ -433,6 +447,7 @@ typedef struct {
     GtkWidget *rt_dp_day_spinbutton;
     GtkWidget *rt_dp_month_spinbutton;
     GtkWidget *repeat_counter_spinbutton;
+    GtkWidget *checkb_sound_enable;
     GSList *notifications;
 
 } TASKS;
@@ -455,6 +470,7 @@ typedef struct {
     GtkWidget *contacts_paned;
     GtkWidget *panel_hbox;
 
+	GtkWidget *scrolled_win;
     GtkWidget *contacts_list;
     GtkTreeSelection *contacts_list_selection;
     GtkListStore *contacts_list_store;
@@ -478,6 +494,7 @@ typedef struct {
     gint contacts_www_link_index;
     gint contacts_email_link_index;
     gint contacts_blog_link_index;
+    gboolean write_flag;
     gboolean contacts_panel_status;
     gboolean contacts_filter_disabled;
     GtkWidget *next_field_button[CONTACTS_NUM_COLUMNS];
@@ -558,6 +575,7 @@ typedef struct {
     GtkBox *vbox;
     GtkWidget *vbox_selector;
     GtkWidget *vbox_editor;
+	GtkWidget *scrolled_win;
 
     GtkUIManager *notes_uim_selector_widget;
     GtkUIManager *notes_uim_editor_widget;
@@ -606,6 +624,7 @@ typedef struct {
     gboolean changed;
     gboolean find_next_flag;
     gboolean buffer_check_modify_enable;
+    gboolean find_hbox_visible;
     GtkWidget *find_hbox;
     GtkWidget *find_entry;
     GtkWidget *find_case_checkbutton;
@@ -640,6 +659,7 @@ typedef struct {
     GtkWidget *selection_color_picker;
     GtkWidget *mark_color_picker;
     GtkWidget *mark_current_day_color_picker;
+    GtkWidget *birthday_mark_color_picker;
     GtkWidget *cft_hscale;
     GtkWidget *cft_label_1, *cft_label_2, *cft_label_3;
     GtkWidget *show_day_names_checkbutton;
@@ -713,12 +733,12 @@ typedef struct {
     GtkWidget *ct_hide_items_checkbutton;
     GtkWidget *ct_add_item_checkbutton;
     GtkWidget *ct_remember_category_checkbutton;
-    GtkWidget *tasks_enable_rules_hint_checkbutton;
     GtkWidget *vc_due_date_checkbutton;
     GtkWidget *vc_type_checkbutton;
     GtkWidget *vc_category_checkbutton;
     GtkWidget *vc_priority_checkbutton;
     GtkWidget *postpone_time_spinbutton;
+    GtkWidget *sound_alarm_repeat_spinbutton;
     GtkWidget *global_notification_cmd_entry;
     GtkWidget *global_notification_valid_image;
 #endif  /* TASKS_ENABLED */
@@ -726,7 +746,6 @@ typedef struct {
 #ifdef CONTACTS_ENABLED
     /* contacts */
     GtkWidget *contacts_vbox;
-    GtkWidget *contacts_enable_rules_hint_checkbutton;
     GtkWidget *contacts_select_first_entry_checkbutton;
     GtkWidget *contacts_hide_group_column_checkbutton;
     GtkWidget *contacts_group_entry;
@@ -755,7 +774,6 @@ typedef struct {
     GtkWidget *notes_enc_hashing_combobox;
     GtkWidget *notes_comp_algorithm_combobox;
     GtkWidget *notes_comp_ratio_combobox;
-    GtkWidget *notes_enable_rules_hint_checkbutton;
     GtkWidget *notes_category_entry;
     GtkListStore *notes_category_store;
     GtkWidget *notes_category_treeview;
@@ -774,14 +792,20 @@ typedef struct {
     /* general */
     GtkWidget *general_vbox;
     GtkWidget *tabs_position_combobox;
+    GtkWidget *override_locale_label_1;
+    GtkWidget *override_locale_label_2;
+    GtkWidget *override_locale_label_3;
     GtkWidget *date_format_combobox;
     GtkWidget *time_format_combobox;
     GtkWidget *entry_web_browser;
     GtkWidget *entry_email_client;
+    GtkWidget *entry_sound_player;
     GtkWidget *entry_spell_lang;
     GtkWidget *enable_tooltips_checkbutton;
+    GtkWidget *override_locale_checkbutton;
     GtkWidget *disable_underline_in_links_checkbutton;
     GtkWidget *default_stock_icons_checkbutton;
+    GtkWidget *enable_rules_hint_checkbutton;
     GtkWidget *remember_latest_tab_checkbutton;
     GtkWidget *save_data_checkbutton;
     GtkWidget *enable_systray_checkbutton;
@@ -828,6 +852,11 @@ typedef struct {
     gchar *config_path;
     gboolean tiny_gui;
 
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+	/* backup */
+	GSList *file_list;
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
+
     /* links handling */
     gboolean hovering_over_link;
     GdkCursor *hand_cursor;
@@ -858,6 +887,7 @@ typedef struct {
 	gint key_counter;
 	gint run_time;
     gint save_status;
+	gchar version[7];
 
     /* print */
     gint print_font_size;
@@ -891,7 +921,7 @@ void        gui_add_to_notebook             (GtkWidget *widget, gchar *text, GUI
 void        gui_create_about                (GUI *appGUI);
 void        gui_save_all_data               (GUI *appGUI);
 void        gui_save_data_and_run_command   (gchar *command, GUI *appGUI);
-void        gui_quit_osmo                   (gboolean ignore_geometry, GUI *appGUI);
+void        gui_quit_osmo                   (GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
 void        gui_systray_update_icon         (GUI *appGUI);
 void        gui_systray_tooltip_update      (GUI *appGUI);
