@@ -23,10 +23,15 @@
 #include "calendar.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "i18n.h"
 #include "check_events.h"
 #include "options_prefs.h"
 
+#ifdef BACKUP_SUPPORT
+#include "backup.h"
+#endif  /* BACKUP_SUPPORT */
+
 #define RUN_FLAG_FILE   "lock"
 
 /*------------------------------------------------------------------------------*/
@@ -52,8 +57,10 @@ OPTIONS *opt = NULL;
 GtkWidget *info_dialog;
 gchar tmpbuf[BUFFER_SIZE];
 gint response = -1;
+#ifndef WIN32
 struct flock *s_lock = NULL;
-int fhandle;
+#endif /* WIN32 */
+int fhandle = 0;
 
 GOptionContext *cmd_context;
 gboolean cmd_calendar = FALSE;
@@ -112,8 +119,8 @@ GOptionEntry cmd_options[] = {
 
     appGUI->opt = opt;
 
-    appGUI->run_date = utl_get_current_julian ();
-    appGUI->run_time = get_seconds_for_today ();
+    appGUI->run_date = utl_date_get_current_julian ();
+    appGUI->run_time = utl_time_get_current_seconds ();
     appGUI->key_counter = 0;
 
     /* default values */
@@ -124,17 +131,18 @@ GOptionEntry cmd_options[] = {
     appGUI->trayicon_popup_menu = NULL;
 
     appGUI->calendar_only = FALSE;
+	appGUI->cal->datecal_bio = FALSE;
     appGUI->check_events = FALSE;
     appGUI->tiny_gui = FALSE;
     appGUI->save_status = 0;
     appGUI->print_font_size = 10;
+    g_sprintf (appGUI->version, "%02d%02d%02d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
 
-	appGUI->cal->date = g_date_new ();
-	g_return_val_if_fail (appGUI->cal->date != NULL, -1);
-	g_date_set_time_t (appGUI->cal->date, time (NULL));
+	appGUI->cal->last_selected_year = -1;
+	appGUI->cal->date = utl_date_new_current ();
 
 #ifdef TASKS_ENABLED
-    appGUI->tsk->id_counter = 0;
+    appGUI->tsk->next_id = 1;
     appGUI->tsk->tasks_panel_status = FALSE;
     appGUI->tsk->tasks_filter_disabled = FALSE;
     appGUI->tsk->tasks_list_store = NULL;
@@ -148,6 +156,7 @@ GOptionEntry cmd_options[] = {
     appGUI->cnt->contacts_filter_disabled = TRUE;
     appGUI->cnt->export_button = NULL;
     appGUI->cnt->output_file_entry = NULL;
+	appGUI->cnt->write_flag = TRUE;
 #endif  /* CONTACTS_ENABLED */
 
     appGUI->opt->options_counter = 0;
@@ -158,7 +167,7 @@ GOptionEntry cmd_options[] = {
     textdomain (PACKAGE);
 
     if (argc == 2 && (!strncmp(argv[1], "--help", 6) || (argv[1][0] == '-' && argv[1][1] == '?'))) {
-        fprintf(stderr, "\nOSMO v%s - %s\n", VERSION, _("a handy personal organizer"));
+        fprintf(stderr, "\nOSMO v%s (%s)\n", VERSION, _("handy personal organizer"));
         fprintf(stderr, "Copyright (c) 2007-2008 Tomasz Maka <pasp@users.sourceforge.net>\n\n");
     }
 
@@ -178,14 +187,21 @@ GOptionEntry cmd_options[] = {
         goto finish;
     }
 
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+	backup_restore_run (appGUI);
+#endif  /* BACKUP_SUPPORT & HAVE_LIBGRINGOTTS */
+
+#ifndef WIN32
     s_lock = g_new0 (struct flock, 1);
 	s_lock->l_type = F_WRLCK;
 	s_lock->l_whence = SEEK_SET;
 	s_lock->l_start = 0;
 	s_lock->l_len = 0;
+#endif /* WIN32 */
 
     prefs_read_config (appGUI);
 
+  	g_thread_init (NULL);
     gtk_init (&argc, &argv);
 
 	if (appGUI->calendar_only == FALSE) {
@@ -193,7 +209,7 @@ GOptionEntry cmd_options[] = {
 		close(creat(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), S_IRUSR | S_IWUSR));     /* create lock file */
 
 		fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), O_RDWR);
-
+#ifndef WIN32
 		if (fhandle) {
 			if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
 				close (fhandle);
@@ -218,8 +234,10 @@ GOptionEntry cmd_options[] = {
 				}
 			}
 		}
+#endif /* WIN32 */
 	}
 
+
 #ifdef HAVE_LIBNOTIFY
 #ifdef TASKS_ENABLED
 	notify_init("Osmo notification");
@@ -227,24 +245,25 @@ GOptionEntry cmd_options[] = {
 #endif  /* HAVE_LIBNOTIFY */
 
     if (appGUI->calendar_only != TRUE) {
-
         /* setup timer at 1000ms (1s) interval */
 		g_timeout_add (1000, (GtkFunction) time_handler, appGUI);
-
     }
 
     config.run_counter++;
 
-	g_set_application_name (_(APPLICATION_NAME));
+	g_snprintf (tmpbuf, BUFFER_SIZE, "Osmo %d.%d.%d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
+	g_set_application_name (tmpbuf);
 	gtk_window_set_default_icon_name ("osmo");
 
     if (gui_create_window (appGUI) == TRUE) {
-        gtk_main ();
+		gdk_threads_enter ();
+		gtk_main ();
+		gdk_threads_leave ();
     }
 
     if (appGUI->calendar_only == FALSE) {
-        config.lastrun_date = utl_get_current_julian ();
-        config.lastrun_time = get_seconds_for_today();
+        config.lastrun_date = utl_date_get_current_julian ();
+        config.lastrun_time = utl_time_get_current_seconds ();
     }
 
     if (appGUI->check_events == FALSE) {
@@ -252,8 +271,10 @@ GOptionEntry cmd_options[] = {
     }
 
     if (fhandle && appGUI->calendar_only == FALSE) {
+ #ifndef WIN32
     	s_lock->l_type = F_UNLCK;
     	fcntl(fhandle, F_SETLK, s_lock);
+ #endif /* WIN32 */
         close (fhandle);
     }
 
@@ -275,7 +296,9 @@ finish:
 
 	g_free (cal);
 	g_free (appGUI);
+#ifndef WIN32
 	g_free (s_lock);
+#endif /* WIN32 */
 	return 0;
 }
 
