@@ -27,6 +27,8 @@
 #include "notes_items.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_date.h"
+#include "utils_date_time.h"
 #include "utils_gui.h"
 #include "stock_icons.h"
 
@@ -55,41 +57,41 @@ gint line;
 gboolean remember_cursor;
 gchar tmpbuf[BUFFER_SIZE];
 
-    if (mode == SELECTOR) { 
+	if (mode == SELECTOR) {
 
-        gtk_widget_show (appGUI->nte->vbox_selector);
-        gtk_widget_hide (appGUI->nte->vbox_editor);
-        gtk_widget_grab_focus (appGUI->nte->notes_list);
-        appGUI->nte->editor_active = FALSE;
+	gtk_widget_show (appGUI->nte->vbox_selector);
+		gtk_widget_hide (appGUI->nte->vbox_editor);
+		gtk_widget_grab_focus (appGUI->nte->notes_list);
+		appGUI->nte->editor_active = FALSE;
 
-    } else if (mode == EDITOR) {
+	} else if (mode == EDITOR) {
 
-        gtk_widget_hide (appGUI->nte->find_hbox);
-        gtk_widget_hide (appGUI->nte->vbox_selector);
-        gtk_widget_show (appGUI->nte->vbox_editor);
-        gtk_entry_set_text(GTK_ENTRY(appGUI->nte->find_entry), "");
-        gtk_widget_grab_focus (appGUI->nte->editor_textview);
-        appGUI->nte->editor_active = TRUE;
+		gtk_widget_hide (appGUI->nte->find_hbox);
+		gtk_widget_hide (appGUI->nte->vbox_selector);
+		gtk_widget_show (appGUI->nte->vbox_editor);
+		gtk_entry_set_text(GTK_ENTRY(appGUI->nte->find_entry), "");
+		gtk_widget_grab_focus (appGUI->nte->editor_textview);
+		appGUI->nte->editor_active = TRUE;
 
-        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+		gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
 
-        if (sort_path == NULL) return;
-        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
-        gtk_tree_path_free (sort_path);
+		if (sort_path == NULL) return;
+		filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+		gtk_tree_path_free (sort_path);
 
-        if (filter_path == NULL) return;
-        path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
-        gtk_tree_path_free (filter_path);
+		if (filter_path == NULL) return;
+		path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+		gtk_tree_path_free (filter_path);
 
-        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
-        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, 
-                            N_COLUMN_NAME, &name, 
-                            N_COLUMN_EDITOR_LINE, &line, 
+		gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
+		gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter,
+                            N_COLUMN_NAME, &name,
+                            N_COLUMN_EDITOR_LINE, &line,
 							N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor, -1);
-        sprintf (tmpbuf, "<i>%s</i>", name);
-        gtk_label_set_markup (GTK_LABEL (appGUI->nte->title_label), tmpbuf);
-        g_free(name);
-        gtk_tree_path_free (path);
+		sprintf (tmpbuf, "<i>%s</i>", name);
+		gtk_label_set_markup (GTK_LABEL (appGUI->nte->title_label), tmpbuf);
+		g_free(name);
+		gtk_tree_path_free (path);
 
 		/* restore cursor position */
 
@@ -110,7 +112,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
-void 
+void
 editor_save_buffer_cb (GtkWidget *widget, gpointer user_data) {
 
 GtkTextBuffer *buffer;
@@ -121,9 +123,9 @@ GtkTreeIter iter;
 GtkTreeIter sort_child_iter, filter_child_iter;
 GtkTreeModel *model;
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
 	text = (unsigned char*) utl_gui_text_buffer_get_text_with_tags (buffer);
 
@@ -150,8 +152,8 @@ GtkTreeModel *model;
 
 	if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
 
-		current_date = utl_get_current_julian ();
-		current_time = get_seconds_for_today ();
+		current_date = utl_date_get_current_julian ();
+		current_time = utl_time_get_current_seconds ();
 
 		gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
 														  &sort_child_iter, &iter);
@@ -167,33 +169,35 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
-void 
+void
 editor_find_text_show_cb (GtkWidget *widget, gpointer user_data) {
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    gtk_widget_show (appGUI->nte->find_hbox);
-    gtk_widget_grab_focus (appGUI->nte->find_entry);
+	gtk_widget_show (appGUI->nte->find_hbox);
+	gtk_widget_grab_focus (appGUI->nte->find_entry);
 
+	appGUI->nte->find_hbox_visible = TRUE;
 }
 
 /*------------------------------------------------------------------------------*/
 
-void 
+void
 editor_find_text_hide_cb (GtkWidget *widget, gpointer user_data) {
 
-    GUI *appGUI = (GUI *)user_data;
-        
-    utl_gui_change_bg_widget_state (appGUI->nte->find_entry, NULL, appGUI);
+	GUI *appGUI = (GUI *)user_data;
 
-    gtk_widget_hide (appGUI->nte->find_hbox);
-    gtk_widget_grab_focus (appGUI->nte->editor_textview);
+	utl_gui_change_bg_widget_state (appGUI->nte->find_entry, NULL, appGUI);
 
+	gtk_widget_hide (appGUI->nte->find_hbox);
+	gtk_widget_grab_focus (appGUI->nte->editor_textview);
+
+	appGUI->nte->find_hbox_visible = FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
 
-void 
+void
 editor_close_cb (GtkWidget *widget, gpointer user_data) {
 
 GtkTextBuffer *buffer;
@@ -204,83 +208,81 @@ gint response, line;
 GtkTextMark *cursor;
 gchar tmpbuf[BUFFER_SIZE];
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    if (appGUI->nte->changed == TRUE) {
+	if (appGUI->nte->changed == TRUE) {
 
-        sprintf (tmpbuf, "%s\n\n%s", _("The note has changed."), _("Do you want to save it?"));
+		sprintf (tmpbuf, "%s\n\n%s", _("The note has changed."), _("Do you want to save it?"));
 
-        response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
+		response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
 
-        if (response == GTK_RESPONSE_YES) {   
-            editor_save_buffer_cb (NULL, appGUI);
-        } else if (response != GTK_RESPONSE_NO) {
-            return;
-        }
-    }
+		if (response == GTK_RESPONSE_YES) {
+			editor_save_buffer_cb (NULL, appGUI);
+		} else if (response != GTK_RESPONSE_NO) {
+			return;
+		}
+	}
 
 #ifdef HAVE_GTKSPELL
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/spell_check")), FALSE);
 #endif /* HAVE_GTKSPELL */
 
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
 #ifdef HAVE_LIBGRINGOTTS
-    if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL) {
-        grg_key_free (appGUI->nte->context, appGUI->nte->keyholder);
-        appGUI->nte->keyholder = NULL;
-	    grg_context_free (appGUI->nte->context);
-        appGUI->nte->context = NULL;
-    }
+	if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL) {
+		grg_key_free (appGUI->nte->context, appGUI->nte->keyholder);
+		appGUI->nte->keyholder = NULL;
+		grg_context_free (appGUI->nte->context);
+		appGUI->nte->context = NULL;
+	}
 #endif /* HAVE_LIBGRINGOTTS */
 
-    if (appGUI->nte->filename != NULL) {
-        g_free(appGUI->nte->filename);
-        appGUI->nte->filename = NULL;
+	if (appGUI->nte->filename != NULL) {
+		g_free(appGUI->nte->filename);
+		appGUI->nte->filename = NULL;
 	}
 
-    cursor = gtk_text_buffer_get_mark (buffer, "insert");
-    gtk_text_buffer_get_iter_at_mark (buffer, &l_iter, cursor);
-    line = gtk_text_iter_get_line (&l_iter);
+	cursor = gtk_text_buffer_get_mark (buffer, "insert");
+	gtk_text_buffer_get_iter_at_mark (buffer, &l_iter, cursor);
+	line = gtk_text_iter_get_line (&l_iter);
 
-    gtk_text_buffer_get_bounds(buffer, &iter_s, &iter_e);
-    gtk_text_buffer_delete(buffer, &iter_s, &iter_e);  
-    appGUI->nte->buffer_check_modify_enable = FALSE;
+	gtk_text_buffer_get_bounds(buffer, &iter_s, &iter_e);
+	gtk_text_buffer_delete(buffer, &iter_s, &iter_e);
+	appGUI->nte->buffer_check_modify_enable = FALSE;
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+	gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
 
-    if (sort_path == NULL) return;
-    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
-    gtk_tree_path_free (sort_path);
+	if (sort_path == NULL) return;
+	filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+	gtk_tree_path_free (sort_path);
 
-    if (filter_path == NULL) return;
-    path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
-    gtk_tree_path_free (filter_path);
+	if (filter_path == NULL) return;
+	path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+	gtk_tree_path_free (filter_path);
 
-    gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
-    gtk_list_store_set (appGUI->nte->notes_list_store, &n_iter, 
-                        N_COLUMN_EDITOR_LINE, line, -1);
-    gtk_tree_path_free (path);
+	gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
+	gtk_list_store_set (appGUI->nte->notes_list_store, &n_iter,
+						N_COLUMN_EDITOR_LINE, line, -1);
+	gtk_tree_path_free (path);
 
-    notes_show_selector_editor (SELECTOR, appGUI);
+	notes_show_selector_editor (SELECTOR, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
 
-void 
+void
 set_text_attribute_cb (GtkWidget *widget, gpointer user_data) {
 
-GtkTextIter start, end;
 GtkTextBuffer *buffer;
 gchar *tagname;
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    tagname = (gchar*) g_object_get_data (G_OBJECT (widget), "tag");
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-    gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
-    gtk_text_buffer_apply_tag_by_name (buffer, tagname, &start, &end);
-    g_signal_emit_by_name(G_OBJECT(buffer), "changed");
+	tagname = (gchar*) g_object_get_data (G_OBJECT (widget), "tag");
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	utl_gui_text_buffer_toggle_tags (buffer, tagname);
+	g_signal_emit_by_name(G_OBJECT(buffer), "changed");
 }
 
 /*------------------------------------------------------------------------------*/
@@ -291,11 +293,11 @@ clear_text_attributes_cb (GtkButton *button, gpointer user_data) {
 GtkTextIter start, end;
 GtkTextBuffer *buffer;
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-    gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
-    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
+	gtk_text_buffer_remove_all_tags (buffer, &start, &end);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -382,23 +384,21 @@ notes_delete_item_cb (GtkWidget *widget, gpointer data) {
 /*------------------------------------------------------------------------------*/
 
 void
-insert_current_date_and_time_cb (GtkWidget *widget, gpointer data) {
+insert_current_date_and_time_cb (GtkWidget *widget, GUI *appGUI)
+{
+	time_t tmm;
+	gchar *datestr;
 
-gchar temp[BUFFER_SIZE];
-time_t tmm;
-
-    GUI *appGUI = (GUI *)data;
-
-    if (config.use_system_date_in_notes == TRUE) {
-        tmm = time(NULL);
-        gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
-                                          asctime (localtime (&tmm)), -1);
-    } else {
-        g_snprintf (temp, BUFFER_SIZE, "%s\n", 
-                    get_date_time_full_str (utl_get_current_julian(), get_seconds_for_today()));
-        gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
-                                          temp, -1);
-    }
+	if (config.use_system_date_in_notes == TRUE) {
+		tmm = time (NULL);
+		gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
+		                                  asctime (localtime (&tmm)), -1);
+	} else {
+		datestr = utl_date_time_print_default (utl_date_get_current_julian (), utl_time_get_current_seconds (), FALSE);
+		gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
+		                                  datestr, -1);
+		g_free (datestr);
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -445,30 +445,34 @@ GtkWidget *vscrollbar;
 /*------------------------------------------------------------------------------*/
 
 void
-text_info_cb (GtkWidget *widget, gpointer user_data)
+text_info_cb (GtkWidget *widget, GUI *appGUI)
 {
-GtkTreeIter n_iter;
-GtkTreePath *path, *sort_path, *filter_path;
-GtkTextIter start_iter, end_iter;
-gchar tmpbuf[BUFFER_SIZE], temp[BUFFER_SIZE];
-GtkTextBuffer *buffer;
-guint32 modified_date, created_date;
-gint modified_time, created_time;
-gchar *text;
-gchar *modified_date_str, *created_date_str;
-PangoLogAttr *attrs;
-gint i, words, lines, chars, white_chars, bytes;
+	GtkTreePath *path, *sort_path, *filter_path;
+	GtkTextIter start_iter, end_iter;
+	GtkTreeIter n_iter;
+	GtkTextBuffer *buffer;
+	PangoLogAttr *attrs;
 
-	GUI *appGUI = (GUI *) user_data;
+	guint32 modified_date, created_date;
+	gint modified_time, created_time;
+	gchar *modified_date_str, *created_date_str, *date_str, *day_str;
+	gchar *text;
+	gchar tmpbuf[BUFFER_SIZE];
+	gint i, words, lines, chars, white_chars, bytes;
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
-    if (gtk_text_buffer_get_has_selection (buffer) == TRUE) {
-        gtk_text_buffer_get_selection_bounds (buffer, &start_iter, &end_iter);
-    } else {
-        gtk_text_buffer_get_start_iter (buffer, &start_iter);
-        gtk_text_buffer_get_end_iter (buffer, &end_iter);
-    }
+	/* FIXME: temporarily disabled */
+    /*if (gtk_text_buffer_get_has_selection (buffer) == TRUE) {*/
+        /*gtk_text_buffer_get_selection_bounds (buffer, &start_iter, &end_iter);*/
+    /*} else {*/
+        /*gtk_text_buffer_get_start_iter (buffer, &start_iter);*/
+        /*gtk_text_buffer_get_end_iter (buffer, &end_iter);*/
+    /*}*/
+
+	/* info for whole buffer (temporary) */
+	gtk_text_buffer_get_start_iter (buffer, &start_iter);
+	gtk_text_buffer_get_end_iter (buffer, &end_iter);
 
     text = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start_iter, &end_iter, FALSE);
     if (text == NULL) return;
@@ -507,17 +511,17 @@ gint i, words, lines, chars, white_chars, bytes;
                         N_COLUMN_CREATE_TIME, &created_time,
                         -1);
 
-    g_snprintf (temp, BUFFER_SIZE, "%s", 
-                get_date_time_full_str (modified_date, modified_time));
-    g_snprintf (tmpbuf, BUFFER_SIZE, " (%s)", julian_to_str(modified_date, DATE_DAY_OF_WEEK_NAME));
-	g_strlcat (temp, tmpbuf, BUFFER_SIZE);
-    modified_date_str = g_strdup(temp);
+	date_str = utl_date_time_print_default (modified_date, modified_time, FALSE);
+	day_str = utl_date_print_j (modified_date, DATE_DAY_OF_WEEK_NAME, config.override_locale_settings);
+	modified_date_str = g_strdup_printf ("%s (%s)", date_str, day_str);
+	g_free (date_str);
+	g_free (day_str);
 
-    g_snprintf (temp, BUFFER_SIZE, "%s", 
-                get_date_time_full_str (created_date, created_time));
-    g_snprintf (tmpbuf, BUFFER_SIZE, " (%s)", julian_to_str(created_date, DATE_DAY_OF_WEEK_NAME));
-	g_strlcat (temp, tmpbuf, BUFFER_SIZE);
-    created_date_str = g_strdup(temp);
+	date_str = utl_date_time_print_default (created_date, created_time, FALSE);
+	day_str = utl_date_print_j (created_date, DATE_DAY_OF_WEEK_NAME, config.override_locale_settings);
+	created_date_str = g_strdup_printf ("%s (%s)", date_str, day_str);
+	g_free (date_str);
+	g_free (day_str);
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n\n<b>%s</b>: %s\n<b>%s</b>: %s\n",
                 _("Words"), words,
@@ -583,7 +587,7 @@ notes_item_selected (GtkTreeSelection *selection, gpointer data) {
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/edit"), state);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/delete"), state);
 
-}    
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -625,7 +629,7 @@ gint i;
             }
         }
     }
-    
+
 }
 
 /*------------------------------------------------------------------------------*/
@@ -637,7 +641,7 @@ GtkTextBuffer *buffer;
 GtkTextMark *last_pos;
 GtkTextIter iter;
 gchar *find_text;
-   
+
     find_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->find_entry)));
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
@@ -665,7 +669,7 @@ gchar *find_text;
 
 /*------------------------------------------------------------------------------*/
 
-gint 
+gint
 find_entry_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
@@ -704,7 +708,7 @@ notes_category_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gp
 /*------------------------------------------------------------------------------*/
 
 void
-update_notes_items(GUI *appGUI) {
+update_notes_items (GUI *appGUI) {
 
 GtkTreeIter iter;
 gint i;
@@ -727,6 +731,31 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
+void
+refresh_notes (GUI *appGUI) {
+
+GtkTreeIter iter;
+gint i;
+guint32 current_date;
+gint current_time;
+
+	i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+
+		gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
+							N_COLUMN_LAST_CHANGES_DATE_JULIAN, &current_date, 
+							N_COLUMN_LAST_CHANGES_TIME, &current_time, -1);
+
+		gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
+						    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time), -1);
+	}
+
+	update_notes_items (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 notes_category_filter_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -735,8 +764,8 @@ notes_category_filter_cb (GtkComboBox *widget, gpointer user_data) {
     appGUI->nte->filter_index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
     if (appGUI->nte->filter_index != -1) {
-        gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter));
-        update_notes_items(appGUI);
+        gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter));
+        update_notes_items (appGUI);
     }
 }
 
@@ -782,12 +811,12 @@ guint32 last_changes_date_s;
         return 0;
     }
 
-    gtk_tree_model_get (model, iter_a, N_COLUMN_NAME, &name_a, 
+    gtk_tree_model_get (model, iter_a, N_COLUMN_NAME, &name_a,
                         N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a, N_COLUMN_CATEGORY, &category_a, -1);
-    gtk_tree_model_get (model, iter_b, N_COLUMN_NAME, &name_b, 
+    gtk_tree_model_get (model, iter_b, N_COLUMN_NAME, &name_b,
                         N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b, N_COLUMN_CATEGORY, &category_b, -1);
 
-    
+
     if (name_a == NULL) {
         name_s = -1;
     } else if (name_b == NULL) {
@@ -904,18 +933,24 @@ notes_spell_check_cb (GtkToggleToolButton *toggle_tool_button, gpointer data) {
 
 	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (toggle_tool_button)) == TRUE) {
         edSpell = gtkspell_new_attach (GTK_TEXT_VIEW(appGUI->nte->editor_textview), NULL, NULL);
-        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+		if (config.override_locale_settings == TRUE) {
+	        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+		} else {
+	        gtkspell_set_language (edSpell, g_getenv ("LANG"), NULL);
+		}
     } else {
         gtkspell_detach (gtkspell_get_from_text_view (GTK_TEXT_VIEW(appGUI->nte->editor_textview)));
     }
 }
 #endif /* HAVE_GTKSPELL */
 
-/*------------------------------------------------------------------------------*/ 
+/*------------------------------------------------------------------------------*/
 
 void
 store_note_columns_info (GUI *appGUI) {
 
+	gint n;
+
 	config.notes_column_idx_0 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_TYPE], 
 															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
 	config.notes_column_idx_1 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_NAME], 
@@ -925,10 +960,48 @@ store_note_columns_info (GUI *appGUI) {
 	config.notes_column_idx_3 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE], 
 															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
 
-	config.notes_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0));
-	config.notes_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1));
-	config.notes_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2));
-	config.notes_column_idx_3_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3));
+	n = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0));
+	if (n > 1) {
+		config.notes_column_idx_0_width = n;
+	}
+	n = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1));
+	if (n > 1) {
+		config.notes_column_idx_1_width = n;
+	}
+	n = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2));
+	if (n > 1) {
+		config.notes_column_idx_2_width = n;
+	}
+	n = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3));
+	if (n > 1) {
+		config.notes_column_idx_3_width = n;
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+set_note_columns_width (GUI *appGUI) {
+
+GtkTreeViewColumn   *col;
+
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.notes_column_idx_0_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.notes_column_idx_1_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.notes_column_idx_2_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.notes_column_idx_3_width - 
+											  2 * utl_gui_get_sw_vscrollbar_width (appGUI->nte->scrolled_win));
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -937,7 +1010,6 @@ void
 gui_create_notes (GUI *appGUI) {
 
 GtkWidget           *vbox1;
-GtkWidget           *scrolled_win;
 GtkTextBuffer       *buffer;
 GtkWidget           *viewport;
 GError              *error = NULL;
@@ -1088,12 +1160,12 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 
     /*-------------------------------------------------------------------------------------*/
     /* assign callbacks */
-    
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/new")), 
+
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/new")),
                       "clicked", G_CALLBACK(notes_add_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/edit")), 
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/edit")),
                       "clicked", G_CALLBACK(notes_edit_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/delete")), 
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/delete")),
                       "clicked", G_CALLBACK(notes_delete_item_cb), appGUI);
 
     /*-------------------------------------------------------------------------------------*/
@@ -1105,7 +1177,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), hseparator, FALSE, TRUE, 4);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), hseparator, FALSE, TRUE, 6);
 
     table = gtk_table_new (1, 4, FALSE);
     gtk_widget_show (table);
@@ -1150,7 +1222,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), hseparator, FALSE, TRUE, 4);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), hseparator, FALSE, TRUE, 6);
 
     /*-------------------------------------------------------------------------------------*/
 
@@ -1158,13 +1230,13 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     gtk_widget_show (viewport);
     gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_IN);
     gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), viewport, TRUE, TRUE, 0);
-  
-    scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_show (scrolled_win);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add (GTK_CONTAINER (viewport), scrolled_win);
 
-    appGUI->nte->notes_list_store = gtk_list_store_new(NOTES_NUM_COLUMNS, 
+    appGUI->nte->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->scrolled_win);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (viewport), appGUI->nte->scrolled_win);
+
+    appGUI->nte->notes_list_store = gtk_list_store_new(NOTES_NUM_COLUMNS,
                                                        GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
@@ -1178,11 +1250,11 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     appGUI->nte->notes_sort = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(appGUI->nte->notes_filter));
 
     appGUI->nte->notes_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->nte->notes_sort));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->nte->notes_list), config.notes_rules_hint);
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(appGUI->nte->notes_list), config.rules_hint);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->nte->notes_list), FALSE);
     gtk_widget_show (appGUI->nte->notes_list);
     GTK_WIDGET_SET_FLAGS (appGUI->nte->notes_list, GTK_CAN_DEFAULT);
-    gtk_container_add (GTK_CONTAINER (scrolled_win), appGUI->nte->notes_list);
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->scrolled_win), appGUI->nte->notes_list);
 
     g_signal_connect(G_OBJECT(appGUI->nte->notes_list), "button_press_event",
                      G_CALLBACK(notes_list_dbclick_cb), appGUI);
@@ -1321,14 +1393,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 		}
 	}
 
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0),
-										  config.notes_column_idx_0_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1),
-										  config.notes_column_idx_1_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2),
-										  config.notes_column_idx_2_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3),
-										  config.notes_column_idx_3_width);
+	set_note_columns_width (appGUI);
 
     /* configure sorting */
 
@@ -1523,8 +1588,8 @@ GtkWidget *helper;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
 
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
-                           N_COLUMN_FILENAME, &filename, -1);
+        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
+                            N_COLUMN_FILENAME, &filename, -1);
 
 		if (check_if_encrypted (filename, appGUI) == TRUE) {
 			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_ENCRYPTED, GTK_ICON_SIZE_MENU, NULL);
@@ -1532,7 +1597,7 @@ GtkWidget *helper;
 			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_NORMAL, GTK_ICON_SIZE_MENU, NULL);
 		}
 
-		gtk_list_store_set(appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, -1);
+		gtk_list_store_set (appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, -1);
 		g_object_unref (image);
 	}
 }
