@@ -30,6 +30,7 @@
 #include "calendar_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "utils_date.h"
 #include "stock_icons.h"
 #include "options_gui_notes.h"
 
@@ -470,7 +471,7 @@ gint i, n;
 gboolean flag, remember_cursor;
 
 #ifdef HAVE_LIBGRINGOTTS
-gchar *pass, *spass;
+gchar *pass = NULL, *spass = NULL;
 GRG_CTX context;
 GRG_KEY keyholder;
 gint ret;
@@ -500,8 +501,8 @@ gint ret;
 
     notes_add_close_cb (NULL, NULL, appGUI);
 
-    current_date = utl_get_current_julian ();
-    current_time = get_seconds_for_today ();
+    current_date = utl_date_get_current_julian ();
+    current_time = utl_time_get_current_seconds ();
     current_filename = g_strdup (notes_get_new_filename (appGUI));
 
 #ifdef HAVE_LIBGRINGOTTS
@@ -525,7 +526,7 @@ gint ret;
 
 	} else {
 
-		g_file_set_contents (notes_get_full_filename(appGUI->nte->filename, appGUI), 
+		g_file_set_contents (notes_get_full_filename(current_filename, appGUI), 
 							 (gchar *) empty_str, strlen(empty_str), NULL);
 	}
 #endif /* HAVE_LIBGRINGOTTS */
@@ -914,10 +915,10 @@ GtkTreeModel *model;
 
 		appGUI->nte->filename = g_strdup (current_filename);
 
-		g_file_get_contents(notes_get_full_filename(current_filename, appGUI), &txtnote, NULL, NULL);
+		g_file_get_contents (notes_get_full_filename(current_filename, appGUI), &txtnote, NULL, NULL);
 
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-		utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote);
+		utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote, TRUE);
 		notes_show_selector_editor (EDITOR, appGUI);
 		appGUI->nte->buffer_check_modify_enable = TRUE;
 
@@ -976,7 +977,7 @@ gint ret;
             return;
         } else {
 			buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-            utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote);
+            utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote, TRUE);
             notes_show_selector_editor (EDITOR, appGUI);
             appGUI->nte->buffer_check_modify_enable = TRUE;
         }
@@ -1038,12 +1039,13 @@ gchar *current_filename;
 		if (check_if_encrypted (current_filename, appGUI) == TRUE) {
 
 			g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n\n(%s)", _("Cannot open the note."), _("encryption support is disabled"));
-			gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->main_window));
+			utl_gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->main_window));
 			g_free (current_filename);
 			return;
 
 		} else {
 			appGUI->nte->encrypted = FALSE;
+            appGUI->nte->changed = FALSE;
 			notes_enter_editor_action (appGUI);
 		}
 
@@ -1128,6 +1130,7 @@ gchar *current_filename;
 
 		} else {
 			appGUI->nte->encrypted = FALSE;
+            appGUI->nte->changed = FALSE;
 			notes_enter_editor_action (appGUI);
 		}
 
@@ -1239,28 +1242,26 @@ gboolean remember_editor_line;
 											fullpath = (gchar *) key;
 										}
 
-										if (g_file_test (fullpath, G_FILE_TEST_EXISTS) == TRUE) {
-											gtk_list_store_append (appGUI->nte->notes_list_store, &iter);
+										gtk_list_store_append (appGUI->nte->notes_list_store, &iter);
+										gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
+															N_COLUMN_NAME, name, 
+															N_COLUMN_CATEGORY, category, 
+															N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (last_changes_date_julian, last_changes_time),
+															N_COLUMN_LAST_CHANGES_DATE_JULIAN, last_changes_date_julian,
+															N_COLUMN_LAST_CHANGES_TIME, last_changes_time,
+															N_COLUMN_CREATE_DATE, get_date_time_str (create_date_julian, create_time),
+															N_COLUMN_CREATE_DATE_JULIAN, create_date_julian,
+															N_COLUMN_CREATE_TIME, create_time,
+															N_COLUMN_REMEMBER_EDITOR_LINE, remember_editor_line,
+															N_COLUMN_EDITOR_LINE, editor_line, -1);
+	
+										if (dir[0] == '.') {
 											gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
-															    N_COLUMN_NAME, name, 
-															    N_COLUMN_CATEGORY, category, 
-															    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (last_changes_date_julian, last_changes_time),
-															    N_COLUMN_LAST_CHANGES_DATE_JULIAN, last_changes_date_julian,
-															    N_COLUMN_LAST_CHANGES_TIME, last_changes_time,
-															    N_COLUMN_CREATE_DATE, get_date_time_str (create_date_julian, create_time),
-															    N_COLUMN_CREATE_DATE_JULIAN, create_date_julian,
-															    N_COLUMN_CREATE_TIME, create_time,
-															    N_COLUMN_REMEMBER_EDITOR_LINE, remember_editor_line,
-															    N_COLUMN_EDITOR_LINE, editor_line, -1);
-		
-											if (dir[0] == '.') {
-				   						        gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
- 															        N_COLUMN_FILENAME, (gchar *)key, -1);
-												g_free (fullpath);
-											} else {
-				   						        gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
- 															        N_COLUMN_FILENAME, str, -1);
-											}
+																N_COLUMN_FILENAME, (gchar *)key, -1);
+											g_free (fullpath);
+										} else {
+											gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
+																N_COLUMN_FILENAME, str, -1);
 										}
 
 										g_free (str);
@@ -1339,25 +1340,25 @@ xmlChar *escaped;
 
     i = 0;
 
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter, NULL, i++)) {
 
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
-                           N_COLUMN_NAME, &name, 
-                           N_COLUMN_CATEGORY, &category, 
-                           N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_julian,
-                           N_COLUMN_LAST_CHANGES_TIME, &last_changes_time,
-                           N_COLUMN_CREATE_DATE_JULIAN, &create_date_julian,
-                           N_COLUMN_CREATE_TIME, &create_time,
-						   N_COLUMN_REMEMBER_EDITOR_LINE, &remember_editor_line,
-                           N_COLUMN_EDITOR_LINE, &editor_line,
-                           N_COLUMN_FILENAME, &note_filename, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter,
+		                    N_COLUMN_NAME, &name,
+		                    N_COLUMN_CATEGORY, &category,
+		                    N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_julian,
+		                    N_COLUMN_LAST_CHANGES_TIME, &last_changes_time,
+		                    N_COLUMN_CREATE_DATE_JULIAN, &create_date_julian,
+		                    N_COLUMN_CREATE_TIME, &create_time,
+		                    N_COLUMN_REMEMBER_EDITOR_LINE, &remember_editor_line,
+		                    N_COLUMN_EDITOR_LINE, &editor_line,
+		                    N_COLUMN_FILENAME, &note_filename, -1);
 
-        note_node = xmlNewChild(node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
+		note_node = xmlNewChild (node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
 
 		utl_xml_put_str ("name", name, note_node, doc);
-        g_free (name);
+		g_free (name);
 		utl_xml_put_str ("category", category, note_node, doc);
-        g_free (category);
+		g_free (category);
 		utl_xml_put_uint ("last_changes_date", last_changes_date_julian, note_node);
 		utl_xml_put_int ("last_changes_time", last_changes_time, note_node);
 		utl_xml_put_uint ("create_date", create_date_julian, note_node);
@@ -1365,13 +1366,14 @@ xmlChar *escaped;
 		utl_xml_put_int ("remember_editor_line", remember_editor_line, note_node);
 		utl_xml_put_int ("editor_line", editor_line, note_node);
 		utl_xml_put_str ("filename", note_filename, note_node, doc);
-        g_free (note_filename);
-    }
+		g_free (note_filename);
+	}
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
-    xmlFreeDoc(doc);
+	xmlSaveFormatFileEnc (prefs_get_config_filename (NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+	xmlFree (attr);
+	xmlFreeDoc (doc);
 
-    appGUI->save_status &= ~WRT_NOTES;
+	appGUI->save_status &= ~WRT_NOTES;
 }
 
 /*------------------------------------------------------------------------------*/
