@@ -202,9 +202,9 @@ options_button_released_cb (GtkButton *button, gpointer user_data) {
 void
 gui_create_options(GUI *appGUI) {
 
-GtkWidget           *vbox1, *vbox2, *hbox;
+GtkWidget           *vbox1, *vbox2, *hbox = NULL;
 GtkWidget           *hseparator;
-GtkWidget           *hbuttonbox;
+GtkWidget           *hbuttonbox = NULL;
 GtkWidget           *scrolledwindow;
 GtkWidget           *viewport;
 GSList              *radiobutton_group = NULL;
@@ -405,7 +405,11 @@ GSList              *radiobutton_group = NULL;
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->spell_checker_in_day_notes_checkbutton), TRUE);
 
         GtkSpell *edSpell = gtkspell_new_attach (GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), NULL, NULL);
-        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+		if (config.override_locale_settings == TRUE) {
+	        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+		} else {
+	        gtkspell_set_language (edSpell, g_getenv ("LANG"), NULL);
+		}
     }
 #endif  /* HAVE_GTKSPELL */
 
@@ -444,8 +448,12 @@ GSList              *radiobutton_group = NULL;
                                   config.default_stock_icons);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->disable_underline_in_links_checkbutton), 
                                   config.disable_underline_links);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_rules_hint_checkbutton), 
+                                  config.rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_tooltips_checkbutton), 
                                   config.enable_tooltips);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->override_locale_checkbutton), 
+                                  config.override_locale_settings);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_systray_checkbutton), 
                                   config.enable_systray);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->start_minimised_checkbutton), 
@@ -460,8 +468,6 @@ GSList              *radiobutton_group = NULL;
                                   config.save_data_after_modification);
 
 #ifdef TASKS_ENABLED
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_enable_rules_hint_checkbutton), 
-                                  config.tasks_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_bold_items_checkbutton), 
                                   config.tasks_high_in_bold);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_hide_items_checkbutton), 
@@ -491,8 +497,6 @@ GSList              *radiobutton_group = NULL;
 #endif  /* CONTACTS_ENABLED */
 
 #ifdef CONTACTS_ENABLED
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_enable_rules_hint_checkbutton), 
-                                  config.contacts_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_select_first_entry_checkbutton), 
                                   config.show_after_search);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_hide_group_column_checkbutton), 
@@ -520,8 +524,6 @@ GSList              *radiobutton_group = NULL;
 #ifdef NOTES_ENABLED
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_notes_checkbutton), 
                                   config.hide_notes);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_enable_rules_hint_checkbutton), 
-                                  config.notes_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_remember_category_checkbutton), 
                                   config.remember_category_in_notes);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_use_system_date_checkbutton), 
@@ -542,6 +544,7 @@ GSList              *radiobutton_group = NULL;
 
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_web_browser), config.web_browser);
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_email_client), config.email_client);
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_sound_player), config.sound_player);
 
 #ifdef HAVE_GTKSPELL
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_spell_lang), config.spell_lang);
@@ -595,6 +598,7 @@ GSList              *radiobutton_group = NULL;
 
     gtk_widget_show (appGUI->opt->calendar_vbox);
 
+	override_locale_changed_cb (NULL, appGUI);
     options_button_released_cb (NULL, appGUI);
 }
 
