@@ -28,9 +28,9 @@ enum {
     OPT_PAGE_CALENDAR = 0,
     OPT_PAGE_TASKS,
     OPT_PAGE_CONTACTS,
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
     OPT_PAGE_NOTES,
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     OPT_PAGE_GENERAL,
     OPT_NUMBER_OF_PAGES
 };
