@@ -30,7 +30,9 @@ enum {
     ICAL_COLUMN_FILENAME,
     ICAL_COLUMN_VALID_FLAG,
     ICAL_COLUMN_ENABLE_DESC,
-    ICAL_COLUMN_USE_YEAR
+    ICAL_COLUMN_FULL_DATE,
+	ICAL_COLUMN_MARK,
+	ICAL_NUMBER_OF_COLUMNS      /* This must be last item */
 };
 
 void    gui_create_calendar_options_page            (GtkWidget *vbox, GUI *appGUI);
