@@ -220,20 +220,6 @@ GdkColor color;
 
 /*------------------------------------------------------------------------------*/
 
-void
-contacts_enable_rules_hint_changed_cb (GtkComboBox *widget, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (!appGUI->opt->callback_active) return;
-
-    config.contacts_rules_hint = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_enable_rules_hint_checkbutton));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->cnt->contacts_list), config.contacts_rules_hint);
-
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 contacts_select_first_entry_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -257,6 +243,7 @@ contacts_hide_group_column_changed_cb (GtkComboBox *widget, gpointer user_data)
     config.hide_group_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_hide_group_column_checkbutton));
     gtk_tree_view_column_set_visible (appGUI->cnt->contacts_columns[COLUMN_GROUP], !config.hide_group_column);
 
+	set_contacts_columns_width (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -549,14 +536,6 @@ gint i;
         gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->contacts_photo_size_combobox), 0);
     }
 
-    appGUI->opt->contacts_enable_rules_hint_checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->contacts_enable_rules_hint_checkbutton, GTK_CAN_FOCUS);
-    gtk_widget_show (appGUI->opt->contacts_enable_rules_hint_checkbutton);
-    g_signal_connect (G_OBJECT (appGUI->opt->contacts_enable_rules_hint_checkbutton), "toggled",
-                      G_CALLBACK (contacts_enable_rules_hint_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->contacts_enable_rules_hint_checkbutton, TRUE, TRUE, 4);
-
-
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (appGUI->opt->contacts_vbox), frame, FALSE, TRUE, 0);
