@@ -27,12 +27,14 @@
 #include "calendar_widget.h"
 #include "i18n.h"
 #include "tasks.h"
+#include "notes.h"
 #include "options_gui.h"
 #include "options_gui_calendar.h"
 #include "options_gui_tasks.h"
 #include "options_gui_contacts.h"
 #include "options_prefs.h"
 #include "contacts.h"
+#include "backup.h"
 #include "stock_icons.h"
 
 /*------------------------------------------------------------------------------*/
@@ -86,6 +88,41 @@ enable_tooltips_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+override_locale_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->override_locale_checkbutton)) == TRUE) {
+        config.override_locale_settings = TRUE;
+    } else {
+        config.override_locale_settings = FALSE;
+    }
+
+	gtk_widget_set_sensitive (appGUI->opt->override_locale_label_1, config.override_locale_settings);
+	gtk_widget_set_sensitive (appGUI->opt->override_locale_label_2, config.override_locale_settings);
+	gtk_widget_set_sensitive (appGUI->opt->date_format_combobox, config.override_locale_settings);
+	gtk_widget_set_sensitive (appGUI->opt->time_format_combobox, config.override_locale_settings);
+
+#ifdef HAVE_GTKSPELL
+	gtk_widget_set_sensitive (appGUI->opt->override_locale_label_3, config.override_locale_settings);
+	gtk_widget_set_sensitive (appGUI->opt->entry_spell_lang, config.override_locale_settings);
+#endif  /* HAVE_GTKSPELL */
+
+#ifdef TASKS_ENABLED
+	refresh_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
+
+#ifdef NOTES_ENABLED
+	refresh_notes (appGUI);
+#endif  /* NOTES_ENABLED */
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 gint
 get_visible_tabs (GUI *appGUI) {
 
@@ -342,14 +379,18 @@ helpers_entry_changed_cb (GtkEntry *entry, gpointer  user_data) {
     if (!appGUI->opt->callback_active) return;
 
     if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_web_browser)))) {
-        strncpy(config.web_browser, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_web_browser)), MAXHELPERCMD-1);
+        strncpy (config.web_browser, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_web_browser)), MAXHELPERCMD-1);
     }
     if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_email_client)))) {
-        strncpy(config.email_client, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_email_client)), MAXHELPERCMD-1);
+        strncpy (config.email_client, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_email_client)), MAXHELPERCMD-1);
+    }
+    if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_sound_player)))) {
+        strncpy (config.sound_player, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_sound_player)), MAXHELPERCMD-1);
     }
     
     utl_gui_change_bg_widget_state (appGUI->opt->entry_web_browser, NULL, appGUI);
     utl_gui_change_bg_widget_state (appGUI->opt->entry_email_client, NULL, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_sound_player, NULL, appGUI);
 
 }
 
@@ -406,6 +447,17 @@ helper_email_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 /*------------------------------------------------------------------------------*/
 
+gint 
+helper_sound_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_sound_player, COLOR_BG_OK, appGUI);
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 tabs_position_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -485,6 +537,45 @@ time_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+enable_rules_hint_changed_cb (GtkComboBox *widget, GUI *appGUI)
+{
+	if (!appGUI->opt->callback_active) return;
+
+	config.rules_hint = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->enable_rules_hint_checkbutton));
+#ifdef CONTACTS_ENABLED
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->cnt->contacts_list), config.rules_hint);
+#endif /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->nte->notes_list), config.rules_hint);
+#endif /* NOTES_ENABLED */
+#ifdef TASKS_ENABLED
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->tsk->tasks_list), config.rules_hint);
+#endif /* TASKS_ENABLED */
+}
+
+/*------------------------------------------------------------------------------*/
+
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+
+void
+button_create_backup_cb (GtkWidget *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+	backup_create (appGUI);
+}
+
+void
+button_restore_backup_cb (GtkWidget *widget, gpointer user_data) {
+
+	GUI *appGUI = (GUI *)user_data;
+	backup_restore (appGUI);
+}
+
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_general_options_page (GtkWidget *vbox, GUI *appGUI) {
 
@@ -495,6 +586,11 @@ GtkWidget   *frame;
 GtkWidget   *table;
 GtkWidget   *alignment;
 
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+GtkWidget   *hbuttonbox;
+GtkWidget   *create_button, *restore_button;
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
+
 #if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
 GtkWidget   *hide_vbox;
 #endif
@@ -568,6 +664,14 @@ gchar tmpbuf[BUFFER_SIZE];
                       G_CALLBACK (disable_underline_in_links_changed_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->disable_underline_in_links_checkbutton, FALSE, FALSE, 4);
 
+    appGUI->opt->enable_rules_hint_checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->enable_rules_hint_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->enable_rules_hint_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->enable_rules_hint_checkbutton), "toggled",
+                      G_CALLBACK (enable_rules_hint_changed_cb), appGUI);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->enable_rules_hint_checkbutton, FALSE, FALSE, 4);
+
+
 #if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
 
     frame = gtk_frame_new (NULL);
@@ -665,19 +769,32 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_table_set_col_spacings (GTK_TABLE (table), 16);
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
+	i = 0;
+
+    appGUI->opt->override_locale_checkbutton = gtk_check_button_new_with_mnemonic (_("Override locale settings"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->override_locale_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->override_locale_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->override_locale_checkbutton), "toggled",
+                      G_CALLBACK (override_locale_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_checkbutton, 0, 4, i, i+1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+
+	i++;
+
     sprintf(tmpbuf, "%s:", _("Date format"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+    appGUI->opt->override_locale_label_1 = gtk_label_new (tmpbuf);
+    gtk_widget_show (appGUI->opt->override_locale_label_1);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_1, 0, 1, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC (appGUI->opt->override_locale_label_1), 0, 0.5);
 
     appGUI->opt->date_format_combobox = gtk_combo_box_new_text ();
     gtk_widget_show (appGUI->opt->date_format_combobox);
     g_signal_connect (G_OBJECT (appGUI->opt->date_format_combobox), "changed",
                       G_CALLBACK(date_format_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->date_format_combobox, 1, 2, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->date_format_combobox, 1, 2, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
@@ -687,19 +804,21 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->date_format_combobox), _("YYYY-DD-MM"));
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->date_format_combobox), config.date_format);
 
+	i++;
+
     sprintf(tmpbuf, "%s:", _("Time format"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+    appGUI->opt->override_locale_label_2 = gtk_label_new (tmpbuf);
+    gtk_widget_show (appGUI->opt->override_locale_label_2);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_2, 0, 1, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC (appGUI->opt->override_locale_label_2), 0, 0.5);
 
     appGUI->opt->time_format_combobox = gtk_combo_box_new_text ();
     gtk_widget_show (appGUI->opt->time_format_combobox);
     g_signal_connect (G_OBJECT (appGUI->opt->time_format_combobox), "changed",
                       G_CALLBACK(time_format_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->time_format_combobox, 1, 2, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->time_format_combobox, 1, 2, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
@@ -709,15 +828,17 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->time_format_combobox), tmpbuf);
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->time_format_combobox), config.time_format);
 
+	i++;
+
 #ifdef HAVE_GTKSPELL
 
     sprintf (tmpbuf, "%s:", _("Spell checker language"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+    appGUI->opt->override_locale_label_3 = gtk_label_new (tmpbuf);
+    gtk_widget_show (appGUI->opt->override_locale_label_3);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_3, 0, 1, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC (appGUI->opt->override_locale_label_3), 0, 0.5);
 
     appGUI->opt->entry_spell_lang = gtk_entry_new ();
     gtk_widget_show (appGUI->opt->entry_spell_lang);
@@ -725,7 +846,7 @@ gchar tmpbuf[BUFFER_SIZE];
                       G_CALLBACK (spell_checker_entry_changed_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->opt->entry_spell_lang), "key_press_event",
                       G_CALLBACK (spell_checker_key_press_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->entry_spell_lang, 1, 2, 2, 3,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->entry_spell_lang, 1, 2, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_entry_set_max_length (GTK_ENTRY (appGUI->opt->entry_spell_lang), MAXNAME);
@@ -739,25 +860,29 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->enable_tooltips_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->enable_tooltips_checkbutton), "toggled",
                       G_CALLBACK (enable_tooltips_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->enable_tooltips_checkbutton, 0, 4, i+2, i+3,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->enable_tooltips_checkbutton, 0, 4, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
+	i++;
+
     appGUI->opt->remember_latest_tab_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember last selected page"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->remember_latest_tab_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->remember_latest_tab_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->remember_latest_tab_checkbutton), "toggled",
                       G_CALLBACK (remember_latest_tab_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->remember_latest_tab_checkbutton, 0, 4, i+3, i+4,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->remember_latest_tab_checkbutton, 0, 4, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
+	i++;
+
     appGUI->opt->save_data_checkbutton = gtk_check_button_new_with_mnemonic (_("Save data after every modification"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->save_data_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->save_data_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->save_data_checkbutton), "toggled",
                       G_CALLBACK (save_data_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->save_data_checkbutton, 0, 4, i+4, i+5,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->save_data_checkbutton, 0, 4, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -804,7 +929,18 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
+	sprintf (tmpbuf, "%s:", _("Sound player"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
     appGUI->opt->entry_web_browser = gtk_entry_new ();
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->entry_web_browser, _("The %s pattern will be replaced with web address"));
+	}
     gtk_widget_show (appGUI->opt->entry_web_browser);
     g_signal_connect (G_OBJECT (appGUI->opt->entry_web_browser), "activate",
                       G_CALLBACK (helpers_entry_changed_cb), appGUI);
@@ -816,6 +952,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_entry_set_max_length (GTK_ENTRY (appGUI->opt->entry_web_browser), MAXHELPERCMD);
 
     appGUI->opt->entry_email_client = gtk_entry_new ();
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->entry_email_client, _("The %s pattern will be replaced with e-mail address"));
+	}
     gtk_widget_show (appGUI->opt->entry_email_client);
     g_signal_connect (G_OBJECT (appGUI->opt->entry_email_client), "activate",
                       G_CALLBACK (helpers_entry_changed_cb), appGUI);
@@ -826,14 +965,57 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_entry_set_max_length (GTK_ENTRY (appGUI->opt->entry_email_client), MAXHELPERCMD);
 
-    sprintf(tmpbuf, "<small><b>%s</b>: %s</small>", _("Note"), _("The %s pattern will be replaced with www or e-mail address"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, 2, 3,
+	appGUI->opt->entry_sound_player = gtk_entry_new ();
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->entry_sound_player, _("The %s pattern will be replaced with sound filename"));
+	}
+    gtk_widget_show (appGUI->opt->entry_sound_player);
+    g_signal_connect (G_OBJECT (appGUI->opt->entry_sound_player), "activate",
+                      G_CALLBACK (helpers_entry_changed_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->opt->entry_sound_player), "key_press_event",
+                      G_CALLBACK (helper_sound_key_press_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->entry_sound_player, 1, 2, 2, 3,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
+    gtk_entry_set_max_length (GTK_ENTRY (appGUI->opt->entry_sound_player), MAXHELPERCMD);
+
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->general_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    sprintf(tmpbuf, "<b>%s</b>", _("Backup"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+	hbuttonbox = gtk_hbutton_box_new ();
+    gtk_widget_show (hbuttonbox);
+    gtk_container_add (GTK_CONTAINER (alignment), hbuttonbox);
+    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_START);
+    gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
+
+    create_button = gtk_button_new_with_label (_("Create"));
+    GTK_WIDGET_UNSET_FLAGS (create_button, GTK_CAN_FOCUS);
+    gtk_widget_show (create_button);
+    g_signal_connect (create_button, "clicked", G_CALLBACK(button_create_backup_cb), appGUI);
+    gtk_container_add (GTK_CONTAINER(hbuttonbox), create_button);
+
+    restore_button = gtk_button_new_with_label (_("Restore"));
+    GTK_WIDGET_UNSET_FLAGS (restore_button, GTK_CAN_FOCUS);
+    gtk_widget_show (restore_button);
+    g_signal_connect (restore_button, "clicked", G_CALLBACK(button_restore_backup_cb), appGUI);
+    gtk_container_add (GTK_CONTAINER(hbuttonbox), restore_button);
+
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
@@ -862,7 +1044,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
     appGUI->opt->enable_systray_checkbutton = gtk_check_button_new_with_mnemonic (_("Enable system tray"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->enable_systray_checkbutton, GTK_CAN_FOCUS);
+    GTK_WIDGET_UNSET_FLAGS (appGUI->opt->enable_systray_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->enable_systray_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->enable_systray_checkbutton), "toggled",
                       G_CALLBACK (enable_systray_changed_cb), appGUI);
