@@ -34,7 +34,6 @@
 #include "stock_icons.h"
 #include "utils_gui.h"
 
-#ifdef NOTES_ENABLED
 
 #ifdef HAVE_LIBGRINGOTTS
 #include <libgringotts.h>
@@ -87,18 +86,7 @@ gint ratio_table [4] = {
 
 /*------------------------------------------------------------------------------*/
 
-void
-notes_enable_rules_hint_checkbutton_cb (GtkComboBox *widget, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (!appGUI->opt->callback_active) return;
-
-    config.notes_rules_hint = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_enable_rules_hint_checkbutton));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->nte->notes_list), config.notes_rules_hint);
-}
-
-/*------------------------------------------------------------------------------*/
+#ifdef NOTES_ENABLED
 
 #ifdef HAVE_LIBGRINGOTTS
 void
@@ -144,7 +132,7 @@ notes_comp_ratio_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     if (!appGUI->opt->callback_active) return;
 
-    config.notes_comp_ratio = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox));
+    config.notes_comp_ratio = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox)) + 1;
 }
 #endif  /* HAVE_LIBGRINGOTTS */
 
@@ -343,6 +331,7 @@ notes_visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
     config.nte_visible_last_changes_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->nvc_last_changes_checkbutton));
     gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE], config.nte_visible_last_changes_column);
 
+	set_note_columns_width (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -392,7 +381,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appearance_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
-    table = gtk_table_new (2, 4, FALSE);
+    table = gtk_table_new (1, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
@@ -433,15 +422,6 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    appGUI->opt->notes_enable_rules_hint_checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->notes_enable_rules_hint_checkbutton, GTK_CAN_FOCUS);
-    gtk_widget_show (appGUI->opt->notes_enable_rules_hint_checkbutton);
-    g_signal_connect (G_OBJECT (appGUI->opt->notes_enable_rules_hint_checkbutton), "toggled",
-                      G_CALLBACK (notes_enable_rules_hint_checkbutton_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_enable_rules_hint_checkbutton, 0, 3, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-
 #ifdef HAVE_LIBGRINGOTTS
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
@@ -547,11 +527,10 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_comp_ratio_combobox, 3, 4, 1, 2,
                       (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                       (GtkAttachOptions) (0), 0, 0);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("None"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("Fast"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("Good"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("Best"));
-    gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox), config.notes_comp_ratio);
+    gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox), config.notes_comp_ratio - 1);
 #endif /* HAVE_LIBGRINGOTTS */
 
     frame = gtk_frame_new (NULL);
