@@ -19,15 +19,16 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "utils.h"
-#include "utils_gui.h"
 #include "calendar.h"
 #include "i18n.h"
-#include "tasks.h"
 #include "options_gui.h"
 #include "options_gui_tasks.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
+#include "tasks.h"
+#include "tasks_utils.h"
+#include "utils.h"
+#include "utils_gui.h"
 
 #ifdef TASKS_ENABLED
 
@@ -117,37 +118,6 @@ remember_category_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
-gboolean
-tasks_category_get_state (gchar *category_name, gint type, GUI *appGUI) {
-
-GtkTreeIter iter;
-gboolean state = TRUE;
-gchar *item;
-gint i;
-
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, NULL, i++)) {
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_NAME, &item, -1);
-        if (item != NULL && category_name != NULL) {
-            if (!strcmp(category_name, item)) {
-                if (type == STATE_CALENDAR) {
-                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_CALENDAR, &state, -1);
-                } else if (type == STATE_TASKS) {
-                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_TASKS, &state, -1);
-                }
-                g_free(item);
-                break;
-            }
-        }
-        g_free(item);
-    }
-
-    return state;
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 tasks_category_add_cb (GtkWidget *widget, gpointer data) {
 
@@ -293,19 +263,6 @@ GdkColor color;
 
 /*------------------------------------------------------------------------------*/
 
-void
-tasks_enable_rules_hint_checkbutton_cb (GtkComboBox *widget, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (!appGUI->opt->callback_active) return;
-
-    config.tasks_rules_hint = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_enable_rules_hint_checkbutton));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->tsk->tasks_list), config.tasks_rules_hint);
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -322,6 +279,7 @@ visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
     config.tsk_visible_priority_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_priority_checkbutton));
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.tsk_visible_priority_column);
 
+	set_tasks_columns_width (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -431,6 +389,19 @@ postpone_time_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+sound_alarm_repeat_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.sound_alarm_repeat = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->sound_alarm_repeat_spinbutton));
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 tsk_show_in_calendar_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data) {
 
@@ -513,7 +484,9 @@ GtkCellRenderer     *renderer;
 GtkTreeViewColumn   *column;
 GdkColor            color;
 GtkObject           *postpone_time_spinbutton_adj;
+GtkObject           *sound_alarm_repeat_spinbutton_adj;
 
+gint i;
 gchar tmpbuf[BUFFER_SIZE];
 
 
@@ -621,15 +594,6 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    appGUI->opt->tasks_enable_rules_hint_checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->tasks_enable_rules_hint_checkbutton, GTK_CAN_FOCUS);
-    gtk_widget_show (appGUI->opt->tasks_enable_rules_hint_checkbutton);
-    g_signal_connect (G_OBJECT (appGUI->opt->tasks_enable_rules_hint_checkbutton), "toggled",
-                      G_CALLBACK (tasks_enable_rules_hint_checkbutton_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->tasks_enable_rules_hint_checkbutton, 0, 3, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-
     appGUI->opt->ct_bold_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Show in bold tasks with high priority"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_bold_items_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->ct_bold_items_checkbutton);
@@ -949,17 +913,19 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    table = gtk_table_new (2, 4, FALSE);
+    table = gtk_table_new (3, 4, FALSE);
     gtk_widget_show (table);
     gtk_container_add (GTK_CONTAINER (alignment), table);
     gtk_container_set_border_width (GTK_CONTAINER (table), 4);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
+	i = 0;
+
     g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Postpone time"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
@@ -969,7 +935,7 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_connect (G_OBJECT (appGUI->opt->postpone_time_spinbutton), "value-changed",
                       G_CALLBACK (postpone_time_changed_cb), appGUI);
     gtk_widget_show (appGUI->opt->postpone_time_spinbutton);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->postpone_time_spinbutton, 1, 2, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->postpone_time_spinbutton, 1, 2, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->opt->postpone_time_spinbutton), TRUE);
@@ -979,22 +945,54 @@ gchar tmpbuf[BUFFER_SIZE];
     g_snprintf (tmpbuf, BUFFER_SIZE, "%s (%s)", _("minutes"), _("0 for disable"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), label, 2, 3, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
+	i++;
+
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Repeat sound alarm"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    sound_alarm_repeat_spinbutton_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
+    appGUI->opt->sound_alarm_repeat_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (sound_alarm_repeat_spinbutton_adj), 1, 0);
+    g_signal_connect (G_OBJECT (appGUI->opt->sound_alarm_repeat_spinbutton), "value-changed",
+                      G_CALLBACK (sound_alarm_repeat_changed_cb), appGUI);
+    gtk_widget_show (appGUI->opt->sound_alarm_repeat_spinbutton);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->sound_alarm_repeat_spinbutton, 1, 2, i, i+1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->opt->sound_alarm_repeat_spinbutton), TRUE);
+
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON(appGUI->opt->sound_alarm_repeat_spinbutton), config.sound_alarm_repeat);
+
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s (%s)", _("times"), _("0 for disable"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 2, 3, i, i+1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+	i++;
+
     g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Global notification command"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     valid_hbox = gtk_hbox_new (FALSE, 2);
     gtk_widget_show (valid_hbox);
-    gtk_table_attach (GTK_TABLE (table), valid_hbox, 1, 3, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), valid_hbox, 1, 3, i, i+1,
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
