@@ -22,6 +22,7 @@
 #include "options_prefs.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_date.h"
 #include "contacts.h"
 #include "contacts_import.h"
 #include "contacts_export.h"
@@ -33,25 +34,39 @@
 /*------------------------------------------------------------------------------*/
 
 gchar* 
-prefs_get_config_filename (gchar *config_filename, GUI *appGUI) {
+prefs_get_config_dir (GUI *appGUI) {
 
-static gchar dirname[PATH_MAX], filename[PATH_MAX];
-struct stat cfg;
+static gchar dirname[PATH_MAX];
 
     if (appGUI->config_path == NULL) {
 #if defined(CONFIG_PATH) && defined(CONFIG_DIR)
-        g_snprintf(dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIR);
+        g_snprintf (dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIR);
 #elif defined(CONFIG_DIR)
-        g_snprintf(dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIR);
+        g_snprintf (dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIR);
 #elif defined(CONFIG_PATH)
-        g_snprintf(dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIRNAME);
+        g_snprintf (dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIRNAME);
 #else
-        g_snprintf(dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIRNAME);
+        g_snprintf (dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIRNAME);
 #endif
     } else {
         g_strlcpy (dirname, appGUI->config_path, PATH_MAX);
     }
 
+	return dirname;
+}
+
+/*------------------------------------------------------------------------------*/
+
+gchar* 
+prefs_get_config_filename (gchar *config_filename, GUI *appGUI) {
+
+static gchar filename[PATH_MAX];
+gchar *dirname = NULL;
+struct stat cfg;
+
+	dirname = g_strdup (prefs_get_config_dir(appGUI));
+	g_return_val_if_fail (dirname != NULL, NULL);
+
     if(g_stat (dirname, &cfg) < 0)
         g_mkdir (dirname, S_IRUSR | S_IWUSR | S_IXUSR);
 
@@ -59,7 +74,8 @@ struct stat cfg;
         return NULL;
     }
 
-    g_snprintf(filename, PATH_MAX, "%s%c%s", dirname, G_DIR_SEPARATOR, config_filename);
+    g_snprintf (filename, PATH_MAX, "%s%c%s", dirname, G_DIR_SEPARATOR, config_filename);
+	g_free (dirname);
 
     return filename;
 }
@@ -83,6 +99,7 @@ gint i;
     config.save_data_after_modification = TRUE;
     config.default_stock_icons = FALSE;
     config.disable_underline_links = FALSE;
+    config.rules_hint = FALSE;
     config.date_format = DATE_YYYY_MM_DD;
     config.time_format = TIME_24;
     config.enable_systray = TRUE;
@@ -90,15 +107,18 @@ gint i;
     config.blink_on_events = FALSE;
     config.ignore_day_note_events = FALSE;
     config.run_counter = 0;
-    config.lastrun_date = utl_get_current_julian ();
-    config.lastrun_time = get_seconds_for_today();
+    config.lastrun_date = utl_date_get_current_julian ();
+    config.lastrun_time = utl_time_get_current_seconds ();
     config.hide_calendar = FALSE;
     config.hide_tasks = FALSE;
     config.hide_contacts = FALSE;
     config.hide_notes = FALSE;
-    g_strlcpy (config.spell_lang, "en", MAXNAME);
-	g_strlcpy (config.web_browser, "firefox %s", MAXHELPERCMD);
-	g_strlcpy (config.email_client, "claws-mail --compose %s", MAXHELPERCMD);
+    config.override_locale_settings = FALSE;
+    config.sound_alarm_repeat = 1;
+    g_strlcpy (config.spell_lang, g_getenv("LANG"), MAXNAME);
+	g_strlcpy (config.web_browser, "xdg-open %s", MAXHELPERCMD);
+	g_strlcpy (config.email_client, "xdg-email %s", MAXHELPERCMD);
+	g_strlcpy (config.sound_player, "play %s", MAXHELPERCMD);
 
     /* calendar */
     config.fy_window_size_x = 750;
@@ -132,7 +152,7 @@ gint i;
     config.ascending_sorting_in_day_notes_browser = FALSE;
     config.auxilary_calendars_state = FALSE;
     config.day_note_spell_checker = FALSE;
-    config.day_note_marker = '\'';
+    g_strlcpy (config.day_note_marker, "\'", MAXNAME);
     config.event_marker_type = EVENT_MARKER_CIRCLE;
     config.today_marker_type = TODAY_MARKER_FREEHAND_CIRCLE;
     config.day_notes_browser_filter = DN_FILTER_CURRENT_MONTH;
@@ -142,6 +162,7 @@ gint i;
 	g_strlcpy (config.selection_color, "#526565", MAXCOLORNAME);
 	g_strlcpy (config.mark_color, "#dddddd", MAXCOLORNAME);
 	g_strlcpy (config.mark_current_day_color, "#34A434", MAXCOLORNAME);
+	g_strlcpy (config.birthday_mark_color, "#FFA500", MAXCOLORNAME);
     config.mark_current_day_alpha = 32768;
     config.selector_alpha = 32768;
 	g_strlcpy (config.day_name_font, "Sans Bold 20", MAXFONTNAME);
@@ -161,7 +182,6 @@ gint i;
 	config.cal_print_ical = TRUE;
 
     /* tasks */
-    config.tasks_rules_hint = TRUE;
     config.tasks_high_in_bold = TRUE;
     config.hide_completed = FALSE;
     config.delete_completed = FALSE;
@@ -203,7 +223,6 @@ gint i;
     config.show_after_search = TRUE;
     config.hide_group_column = FALSE;
     config.contacts_pane_pos = 275;
-    config.contacts_rules_hint = TRUE;
     config.photo_width = 80;
     config.cnt_visible_age_column = TRUE;
     config.cnt_visible_birthday_date_column = TRUE;
@@ -255,11 +274,10 @@ gint i;
     config.export_fields[COLUMN_NICK_NAME] = '+';
 
     /* notes */
-    config.notes_rules_hint = TRUE;
-    config.notes_enc_algorithm = 1;     /* Serpent */
-    config.notes_enc_hashing = 1;       /* RIPEMD-160 */
-    config.notes_comp_algorithm = 0;    /* ZLib */
-    config.notes_comp_ratio = 3;        /* BEST */
+    config.notes_enc_algorithm = 1;         /* Serpent */
+    config.notes_enc_hashing = 1;           /* RIPEMD-160 */
+    config.notes_comp_algorithm = 0;        /* ZLib */
+    config.notes_comp_ratio = 3;            /* BEST */
     config.notes_sorting_order = GTK_SORT_ASCENDING;
     config.notes_sorting_mode = 0;
     config.nte_visible_type_column = TRUE;
@@ -329,6 +347,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("save_data_after_modification", &config.save_data_after_modification, general_node);
 					utl_xml_get_int ("default_stock_icons", &config.default_stock_icons, general_node);
 					utl_xml_get_int ("disable_underline_links", &config.disable_underline_links, general_node);
+					utl_xml_get_int ("rules_hint", &config.rules_hint, general_node);
 					utl_xml_get_int ("date_format", &config.date_format, general_node);
 					utl_xml_get_int ("time_format", &config.time_format, general_node);
 					utl_xml_get_int ("enable_systray", &config.enable_systray, general_node);
@@ -342,9 +361,12 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("hide_tasks", &config.hide_tasks, general_node);
 					utl_xml_get_int ("hide_contacts", &config.hide_contacts, general_node);
 					utl_xml_get_int ("hide_notes", &config.hide_notes, general_node);
+					utl_xml_get_int ("override_locale_settings", &config.override_locale_settings, general_node);
+					utl_xml_get_int ("sound_alarm_repeat", &config.sound_alarm_repeat, general_node);
 					utl_xml_get_strn ("spell_lang", config.spell_lang, MAXNAME, general_node);
 					utl_xml_get_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node);
 					utl_xml_get_strn ("email_client", config.email_client, MAXHELPERCMD, general_node);
+					utl_xml_get_strn ("sound_player", config.sound_player, MAXHELPERCMD, general_node);
 
 					general_node = general_node->next;
 				}
@@ -389,7 +411,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("ascending_sorting_in_day_notes_browser", &config.ascending_sorting_in_day_notes_browser, calendar_node);
 					utl_xml_get_int ("auxilary_calendars_state", &config.auxilary_calendars_state, calendar_node);
 					utl_xml_get_int ("day_note_spell_checker", &config.day_note_spell_checker, calendar_node);
-					utl_xml_get_char ("day_note_marker", &config.day_note_marker, calendar_node);
+					utl_xml_get_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node);
 					utl_xml_get_int ("event_marker_type", &config.event_marker_type, calendar_node);
 					utl_xml_get_int ("today_marker_type", &config.today_marker_type, calendar_node);
 					utl_xml_get_int ("day_notes_browser_filter", &config.day_notes_browser_filter, calendar_node);
@@ -400,6 +422,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_strn ("mark_color", config.mark_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_strn ("mark_current_day_color", config.mark_current_day_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_int ("mark_current_day_alpha", &config.mark_current_day_alpha, calendar_node);
+					utl_xml_get_strn ("birthday_mark_color", config.birthday_mark_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_int ("selector_alpha", &config.selector_alpha, calendar_node);
 					utl_xml_get_strn ("day_name_font", config.day_name_font, MAXFONTNAME, calendar_node);
 					utl_xml_get_strn ("calendar_font", config.calendar_font, MAXFONTNAME, calendar_node);
@@ -428,7 +451,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 				tasks_node = node->xmlChildrenNode;
 
 				while (tasks_node != NULL) {
-					utl_xml_get_int ("rules_hint", &config.tasks_rules_hint, tasks_node);
 					utl_xml_get_int ("high_priority_in_bold", &config.tasks_high_in_bold, tasks_node);
 					utl_xml_get_int ("hide_completed", &config.hide_completed, tasks_node);
 					utl_xml_get_int ("delete_completed", &config.delete_completed, tasks_node);
@@ -480,7 +502,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("show_after_search", &config.show_after_search, contacts_node);
 					utl_xml_get_int ("hide_group_column", &config.hide_group_column, contacts_node);
 					utl_xml_get_int ("pane_pos", &config.contacts_pane_pos, contacts_node);
-					utl_xml_get_int ("rules_hint", &config.contacts_rules_hint, contacts_node);
 					utl_xml_get_int ("photo_width", &config.photo_width, contacts_node);
 					utl_xml_get_int ("visible_age_column", &config.cnt_visible_age_column, contacts_node);
 					utl_xml_get_int ("visible_birthday_date_column", &config.cnt_visible_birthday_date_column, contacts_node);
@@ -533,7 +554,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 				notes_node = node->xmlChildrenNode;
 
 				while (notes_node != NULL) {
-					utl_xml_get_int ("rules_hint", &config.notes_rules_hint, notes_node);
 					utl_xml_get_int ("enc_algorithm", &config.notes_enc_algorithm, notes_node);
 					utl_xml_get_int ("enc_hashing", &config.notes_enc_hashing, notes_node);
 					utl_xml_get_int ("comp_algorithm", &config.notes_comp_algorithm, notes_node);
@@ -559,6 +579,10 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 
 					notes_node = notes_node->next;
 				}
+				
+				if (config.notes_comp_ratio == 0 /* GRG_LVL_NONE */) {      /* ignore 'None' option */
+					config.notes_comp_ratio = 1 /* GRG_LVL_FAST */;
+				}
 			}
 
 			/*---------------------------------------------------------------------------------------*/
@@ -604,6 +628,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("save_data_after_modification", config.save_data_after_modification, general_node);
 	utl_xml_put_int ("default_stock_icons", config.default_stock_icons, general_node);
 	utl_xml_put_int ("disable_underline_links", config.disable_underline_links, general_node);
+	utl_xml_put_int ("rules_hint", config.rules_hint, general_node);
 	utl_xml_put_int ("date_format", config.date_format, general_node);
 	utl_xml_put_int ("time_format", config.time_format, general_node);
 	utl_xml_put_int ("enable_systray", config.enable_systray, general_node);
@@ -617,9 +642,12 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("hide_tasks", config.hide_tasks, general_node);
 	utl_xml_put_int ("hide_contacts", config.hide_contacts, general_node);
 	utl_xml_put_int ("hide_notes", config.hide_notes, general_node);
+	utl_xml_put_int ("override_locale_settings", config.override_locale_settings, general_node);
+	utl_xml_put_int ("sound_alarm_repeat", config.sound_alarm_repeat, general_node);
 	utl_xml_put_strn ("spell_lang", config.spell_lang, MAXNAME, general_node, doc);
 	utl_xml_put_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node, doc);
 	utl_xml_put_strn ("email_client", config.email_client, MAXHELPERCMD, general_node, doc);
+	utl_xml_put_strn ("sound_player", config.sound_player, MAXHELPERCMD, general_node, doc);
 
 	/*---------------------------------------------------------------------------------------*/
 	/* calendar */
@@ -658,7 +686,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("ascending_sorting_in_day_notes_browser", config.ascending_sorting_in_day_notes_browser, calendar_node);
 	utl_xml_put_int ("auxilary_calendars_state", config.auxilary_calendars_state, calendar_node);
 	utl_xml_put_int ("day_note_spell_checker", config.day_note_spell_checker, calendar_node);
-	utl_xml_put_char ("day_note_marker", config.day_note_marker, calendar_node, doc);
+	utl_xml_put_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node, doc);
 	utl_xml_put_int ("event_marker_type", config.event_marker_type, calendar_node);
 	utl_xml_put_int ("today_marker_type", config.today_marker_type, calendar_node);
 	utl_xml_put_int ("day_notes_browser_filter", config.day_notes_browser_filter, calendar_node);
@@ -669,6 +697,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_strn ("mark_color", config.mark_color, MAXCOLORNAME, calendar_node, doc);
 	utl_xml_put_strn ("mark_current_day_color", config.mark_current_day_color, MAXCOLORNAME, calendar_node, doc);
 	utl_xml_put_int ("mark_current_day_alpha", config.mark_current_day_alpha, calendar_node);
+	utl_xml_put_strn ("birthday_mark_color", config.birthday_mark_color, MAXCOLORNAME, calendar_node, doc);
 	utl_xml_put_int ("selector_alpha", config.selector_alpha, calendar_node);
 	utl_xml_put_strn ("day_name_font", config.day_name_font, MAXFONTNAME, calendar_node, doc);
 	utl_xml_put_strn ("calendar_font", config.calendar_font, MAXFONTNAME, calendar_node, doc);
@@ -692,7 +721,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	tasks_node = xmlNewNode (NULL, (const xmlChar *) "tasks");
 	xmlAddChild (node, tasks_node);
 
-	utl_xml_put_int ("rules_hint", config.tasks_rules_hint, tasks_node);
 	utl_xml_put_int ("high_priority_in_bold", config.tasks_high_in_bold, tasks_node);
 	utl_xml_put_int ("hide_completed", config.hide_completed, tasks_node);
 	utl_xml_put_int ("delete_completed", config.delete_completed, tasks_node);
@@ -739,7 +767,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("show_after_search", config.show_after_search, contacts_node);
 	utl_xml_put_int ("hide_group_column", config.hide_group_column, contacts_node);
 	utl_xml_put_int ("pane_pos", config.contacts_pane_pos, contacts_node);
-	utl_xml_put_int ("rules_hint", config.contacts_rules_hint, contacts_node);
 	utl_xml_put_int ("photo_width", config.photo_width, contacts_node);
 	utl_xml_put_int ("visible_age_column", config.cnt_visible_age_column, contacts_node);
 	utl_xml_put_int ("visible_birthday_date_column", config.cnt_visible_birthday_date_column, contacts_node);
@@ -787,7 +814,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	notes_node = xmlNewNode (NULL, (const xmlChar *) "notes");
 	xmlAddChild (node, notes_node);
 
-	utl_xml_put_int ("rules_hint", config.notes_rules_hint, notes_node);
 	utl_xml_put_int ("enc_algorithm", config.notes_enc_algorithm, notes_node);
 	utl_xml_put_int ("enc_hashing", config.notes_enc_hashing, notes_node);
 	utl_xml_put_int ("comp_algorithm", config.notes_comp_algorithm, notes_node);
