@@ -49,6 +49,7 @@ struct osmo_prefs
     gint        save_data_after_modification;
     gint        default_stock_icons;
     gint        disable_underline_links;
+    gint        rules_hint;
     gint        date_format;
     gint        time_format;
     gint        enable_systray;
@@ -62,9 +63,12 @@ struct osmo_prefs
     gint        hide_tasks;
     gint        hide_contacts;
     gint        hide_notes;
+	gint        override_locale_settings;
+	gint        sound_alarm_repeat;
     gchar       spell_lang[MAXNAME];
     gchar       web_browser[MAXHELPERCMD];
     gchar       email_client[MAXHELPERCMD];
+    gchar       sound_player[MAXHELPERCMD];
 
     /* CALENDAR */
     gint        fy_window_size_x;
@@ -98,7 +102,7 @@ struct osmo_prefs
     gint        ascending_sorting_in_day_notes_browser;
     gint        auxilary_calendars_state;
     gint        day_note_spell_checker;
-    gchar       day_note_marker;
+    gchar       day_note_marker[MAXNAME];
     gint        event_marker_type;
     gint        today_marker_type;
     gint        day_notes_browser_filter;
@@ -110,6 +114,7 @@ struct osmo_prefs
     gchar       mark_color[MAXCOLORNAME];
     gchar       mark_current_day_color[MAXCOLORNAME];
     gint        mark_current_day_alpha;
+    gchar       birthday_mark_color[MAXCOLORNAME];
     gchar       day_name_font[MAXFONTNAME];
     gchar       calendar_font[MAXFONTNAME];
     gchar       notes_font[MAXFONTNAME];
@@ -127,7 +132,6 @@ struct osmo_prefs
 	gint        cal_print_ical;
 
     /* TASKS */
-    gint        tasks_rules_hint;
     gint        tasks_high_in_bold;
     gint        hide_completed;
     gint        delete_completed;
@@ -169,7 +173,6 @@ struct osmo_prefs
     gint        show_after_search;
     gint        hide_group_column;
     gint        contacts_pane_pos;
-    gint        contacts_rules_hint;
     gint        photo_width;
     gint        cnt_visible_age_column;
     gint        cnt_visible_birthday_date_column;
@@ -212,7 +215,6 @@ struct osmo_prefs
     gchar       export_fields[MAXCONTACTFIELDS];
 
     /* NOTES */
-    gint        notes_rules_hint;
     gint        notes_enc_algorithm;
     gint        notes_enc_hashing;
     gint        notes_comp_algorithm;
@@ -239,6 +241,7 @@ struct osmo_prefs
 
 extern  struct osmo_prefs     config;
 
+gchar*  prefs_get_config_dir        (GUI *appGUI);
 gchar*  prefs_get_config_filename   (gchar *config_filename, GUI *appGUI);
 void    prefs_read_config           (GUI *appGUI);
 void    prefs_write_config          (GUI *appGUI);
