@@ -1,8 +1,8 @@
-
 /*
  * Osmo - a handy personal organizer
  *
- * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
+ * Copyright (C) 2007-2009 Tomasz Mąka <pasp@users.sourceforge.net>
+ *           (C) 2007-2009 Piotr Mąka <silloz@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,103 +19,24 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "tasks.h"
-#include "i18n.h"
-#include "tasks_items.h"
-#include "tasks_print.h"
 #include "calendar.h"
-#include "calendar_widget.h"
 #include "calendar_utils.h"
+#include "calendar_widget.h"
+#include "i18n.h"
+#include "options_gui_tasks.h"
+#include "options_prefs.h"
+#include "stock_icons.h"
+#include "tasks.h"
+#include "tasks_items.h"
+#include "tasks_export.h"
+#include "tasks_print.h"
+#include "tasks_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
-#include "options_prefs.h"
-#include "options_gui_tasks.h"
-#include "stock_icons.h"
 
 #ifdef TASKS_ENABLED
 
-/*------------------------------------------------------------------------------*/
-
-gint
-get_priority_index (gchar *text) {
-
-gchar *priority_table[] = {
-    N_("Low"), N_("Medium"), N_("High")
-};
-
-gint i;
-
-    if (text != NULL) {
-        for(i=0; i < 3; i++) {
-            if (!strcmp(gettext(priority_table[i]), text)) 
-                break;
-        }
-    }
-
-    if (i == 3) {
-        return -1;
-    } else {
-        return i;
-    }
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar* 
-get_priority_text (gint index)
-{
-gchar *priority_table[] = {
-    N_("Low"), N_("Medium"), N_("High")
-};
-
-	g_return_val_if_fail (index >= LOW_PRIORITY && index <= HIGH_PRIORITY, NULL);
-	return gettext (priority_table[index]);
-}
-
-/*------------------------------------------------------------------------------*/
-
-void
-search_nearest_day (TASK_ITEM *item, GDate *cdate, gboolean month_mode)
-{
-gint day, start_day, days_in_month;
-gint i, j;
-
-	day = g_date_get_weekday (cdate) - 1;
-
-	if (month_mode == TRUE) {
-
-		days_in_month = utl_get_days_in_month (cdate);
-		start_day = g_date_get_day (cdate);
-
-		for (i = 0; i < 7; i++) {
-			if (item->repeat_day & (1 << ((day + i) % 7))) break;
-		}
-
-		for (j = 0; j < 7; j++) {
-			if (item->repeat_day & (1 << ((day + 7 - j) % 7))) break;
-		}
-
-		if (start_day + i > days_in_month) i = 7;
-		if (start_day - j < 1) j = 7;
-
-		if (i <= j) {
-			if (i > 0) g_date_add_days (cdate, i);
-		} else {
-			if (j > 0) g_date_subtract_days (cdate, j);
-		}
-
-	} else {
-
-		for (i = 0; i < 7; i++) {
-			if (item->repeat_day & (1 << ((day + i) % 7))) break;
-		}
-		if (i > 0) g_date_add_days (cdate, i);
-
-	}
-
-}
-
-/*------------------------------------------------------------------------------*/
+/*============================================================================*/
 
 gint
 task_calculate_new_date (TASK_ITEM *item, GUI *appGUI, guint32 *new_date, gint *new_time)
@@ -124,15 +45,16 @@ GDate *cdate;
 guint32 current_julian;
 gint current_time;
 gint i, cycles;
-guint days_in_month;
 gboolean repeat_time, repeat_date, set_start_time;
 
+	gboolean month_mode_flag = item->repeat_month_interval > 0 && item->repeat_day_interval == 0;
+
 	repeat_time = repeat_date = FALSE;
 	set_start_time = TRUE;
 
 	cycles = 0;
-	current_julian = utl_get_current_julian ();
-	current_time = get_seconds_for_today ();
+	current_julian = utl_date_get_current_julian ();
+	current_time = utl_time_get_current_seconds ();
 	*new_date = item->due_date_julian;
 	*new_time = item->due_time;
 
@@ -158,28 +80,16 @@ gboolean repeat_time, repeat_date, set_start_time;
 
 	if (item->due_date_julian < current_julian && repeat_date) {
 		cdate = g_date_new_julian (item->due_date_julian);
-		g_return_val_if_fail (cdate != NULL, 0);
-		g_return_val_if_fail (item->repeat_day > 0 && item->repeat_day <= WHOLE_WEEK, 0);
 
 		while (*new_date < current_julian) {
 			g_date_add_months (cdate, item->repeat_month_interval);
 			g_date_add_days (cdate, item->repeat_day_interval);
 
-			if (item->repeat_month_interval > 0 && item->repeat_day_interval == 0) {
-				days_in_month = utl_get_days_in_month (cdate);
-
-				if (item->repeat_start_day > days_in_month) {
-					g_date_set_day (cdate, days_in_month);
-				} else {
-					g_date_set_day (cdate, item->repeat_start_day);
-				}
-
-				if (item->repeat_day != WHOLE_WEEK)
-					search_nearest_day (item, cdate, TRUE);
-
-			} else if (item->repeat_day != WHOLE_WEEK) {
-				search_nearest_day (item, cdate, FALSE);
-			}
+			if (month_mode_flag) {
+				utl_date_set_valid_day (cdate, item->repeat_start_day);
+				utl_date_set_nearest_weekday (cdate, item->repeat_day, TRUE);
+			} else
+				utl_date_set_nearest_weekday (cdate, item->repeat_day, FALSE);
 
 			*new_date = g_date_get_julian (cdate);
 			cycles++;
@@ -233,8 +143,6 @@ gint cycles;
 			                    TA_COLUMN_DUE_DATE_JULIAN, new_date,
 			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (new_date, new_time),
 			                    TA_COLUMN_DUE_TIME, new_time,
-			                    TA_COLUMN_ACTIVE, TRUE,
-			                    TA_COLUMN_ACTIVE_WARNING, TRUE,
 			                    TA_COLUMN_DONE, FALSE, -1);
 		}
 
@@ -348,17 +256,16 @@ gboolean repeat, prev_state, next_state;
 
 		if (repeat == TRUE) {
 			prev_state = FALSE;
-			next_state = is_date_in_the_past (due_date_julian, due_time, 
-											  utl_get_current_julian (), get_seconds_for_today ());
+			next_state = utl_date_time_in_the_past_js (due_date_julian, due_time);
 		} else {
 			prev_state = next_state = (due_date_julian != 0) ? TRUE : FALSE;
 		}
 
-        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), prev_state);
-        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), next_state);
+        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date"), prev_state);
+        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date"), next_state);
 
         g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s: %s\n", 
-                    _("Started"), julian_to_str (start_date_julian, DATE_FULL));
+                    _("Started"), julian_to_str (start_date_julian, DATE_FULL, config.override_locale_settings));
 
         if (text != NULL) {
             gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1,
@@ -373,7 +280,7 @@ gboolean repeat, prev_state, next_state;
                                                       "italic", NULL);
             if (done_date_julian != 0) {
                 g_snprintf (tmpbuf, BUFFER_SIZE, "%s: %s\n", 
-                            _("Finished"), julian_to_str (done_date_julian, DATE_FULL));
+                            _("Finished"), julian_to_str (done_date_julian, DATE_FULL, config.override_locale_settings));
                 gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, 
                                                           "italic", NULL);
             }
@@ -390,18 +297,18 @@ gboolean repeat, prev_state, next_state;
     } else {
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), FALSE);
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), FALSE);
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), FALSE);
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), FALSE);
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date"), FALSE);
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date"), FALSE);
     }
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-tasks_add_item_cb (GtkWidget *widget, gpointer data) {
-
-    GUI *appGUI = (GUI *)data;
-    tasks_add_edit_dialog_show (FALSE, 0, get_seconds_for_today(), appGUI);
+tasks_add_item_cb (GtkWidget *widget, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+	tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -440,10 +347,10 @@ TASK_ITEM *item;
 		gtk_tree_model_get (model, &iter, TA_COLUMN_DUE_DATE_JULIAN, &due_date,
 		                    TA_COLUMN_DUE_TIME, &due_time, TA_COLUMN_ID, &id, -1);
 
-		e_iter = task_get_iter (id, appGUI);
+		e_iter = tsk_get_iter (id, appGUI);
 		g_return_if_fail (e_iter != NULL);
 
-		item = get_task_item (e_iter, appGUI);
+		item = tsk_get_item (e_iter, appGUI);
 		g_return_if_fail (item != NULL);
 
 		if (item->repeat == TRUE) {
@@ -456,7 +363,7 @@ TASK_ITEM *item;
 			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (due_date, due_time), -1);
 		}
 
-		g_free (item);
+		tsk_item_free (item);
 	}
 
 }
@@ -464,7 +371,7 @@ TASK_ITEM *item;
 /*------------------------------------------------------------------------------*/
 
 void
-tasks_change_due_date_to_prev_day_cb (GtkWidget *widget, gpointer data) {
+tasks_change_due_date_to_prev_date_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
     task_modify_due_date (-1, appGUI);
@@ -473,7 +380,7 @@ tasks_change_due_date_to_prev_day_cb (GtkWidget *widget, gpointer data) {
 /*------------------------------------------------------------------------------*/
 
 void
-tasks_change_due_date_to_next_day_cb (GtkWidget *widget, gpointer data) {
+tasks_change_due_date_to_next_date_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
     task_modify_due_date (1, appGUI);
@@ -481,6 +388,17 @@ tasks_change_due_date_to_next_day_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef HAVE_LIBICAL
+void
+tasks_export_visible_items_cb (GtkWidget *widget, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+	export_tasks_to_file (appGUI);
+}
+#endif /* HAVE_LIBICAL */
+
+/*------------------------------------------------------------------------------*/
+
 #ifdef PRINTING_SUPPORT
 void
 tasks_print_visible_items_cb (GtkWidget *widget, gpointer data) {
@@ -498,12 +416,14 @@ done_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
 GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter  iter;
 gboolean done_status;
-guint32 done_date;
+guint32 done_date, category;
 GtkTreeModel *model;
 
     GUI *appGUI = (GUI *) user_data;
     model = GTK_TREE_MODEL (appGUI->tsk->tasks_list_store);
 
+	category = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox));
+
     sort_path = gtk_tree_path_new_from_string (path_str);
 
     if (sort_path != NULL) {
@@ -517,7 +437,7 @@ GtkTreeModel *model;
                 gtk_tree_model_get (model, &iter, TA_COLUMN_DONE, &done_status, -1);
 
                 if (done_status == FALSE) {
-                    done_date = utl_get_current_julian ();
+                    done_date = utl_date_get_current_julian ();
                 } else {
                     done_date = 0;
                 }
@@ -543,6 +463,8 @@ GtkTreeModel *model;
     cal_set_day_info (appGUI);
 	refresh_tasks (appGUI);
 
+	gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox), category);
+
     if (config.save_data_after_modification) {
         write_tasks_entries (appGUI);
     }
@@ -553,20 +475,20 @@ GtkTreeModel *model;
 gchar *
 get_date_color (guint32 julian_day, gint time, gboolean done, GUI *appGUI)
 {
-static gchar due_date_color[MAXCOLORNAME];
-gint current_time;
-gint32 r;
-GdkColor *color;
+	static gchar due_date_color[MAXCOLORNAME];
+	GdkColor *color;
+	gint current_time;
+	gint32 r;
 
-	current_time = get_seconds_for_today ();
+	current_time = utl_time_get_current_seconds ();
 
-  	color = &appGUI->main_window->style->text[GTK_STATE_NORMAL];
-    g_snprintf (due_date_color, MAXCOLORNAME, "#%02X%02X%02X", color->red * 256 / 65536,
-                color->green * 256 / 65536, color->blue * 256 / 65536);
+	color = &appGUI->main_window->style->text[GTK_STATE_NORMAL];
+	g_snprintf (due_date_color, MAXCOLORNAME, "#%02X%02X%02X", color->red * 256 / 65536,
+	            color->green * 256 / 65536, color->blue * 256 / 65536);
 
 	if (julian_day != 0 && done == FALSE) {
 
-		r = julian_day - utl_get_current_julian ();
+		r = julian_day - utl_date_get_current_julian ();
 
 		if (r == 0) {
 			if (time >= 0 && current_time > time) {
@@ -605,7 +527,7 @@ gint time;
                            TA_COLUMN_DONE, &done, TA_COLUMN_DUE_DATE_JULIAN, &julian_day, 
                            TA_COLUMN_DUE_TIME, &time, TA_COLUMN_PRIORITY, &priority, -1);
 
-        if (get_priority_index (priority) == HIGH_PRIORITY && config.tasks_high_in_bold == TRUE) {    /* high priority ? */
+        if (tsk_get_priority_index (priority) == HIGH_PRIORITY && config.tasks_high_in_bold == TRUE) {    /* high priority ? */
             gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, 
                                TA_COLUMN_COLOR, get_date_color (julian_day, time, done, appGUI), 
                                TA_COLUMN_BOLD, PANGO_WEIGHT_BOLD,-1);
@@ -693,11 +615,17 @@ gchar tmpbuf[BUFFER_SIZE];
 #ifdef PRINTING_SUPPORT
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), TRUE);
 #endif /* PRINTING_SUPPORT */
+#ifdef HAVE_LIBICAL
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/export"), TRUE);
+#endif /* HAVE_LIBICAL */
 	} else {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
 #ifdef PRINTING_SUPPORT
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
 #endif /* PRINTING_SUPPORT */
+#ifdef HAVE_LIBICAL
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/export"), FALSE);
+#endif /* HAVE_LIBICAL */
 	}
 
 	gtk_label_set_markup (GTK_LABEL (appGUI->tsk->n_items_label), tmpbuf);
@@ -706,13 +634,50 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
-void
-add_item_to_list (TASK_ITEM *item, GUI *appGUI) {
-
+guint
+get_number_of_visible_tasks_with_date (GUI *appGUI)
+{
+guint32 date, n;
+GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter iter;
-GdkPixbuf *image;
-GtkWidget *helper;
-const gchar *stock_id;
+
+	sort_path = gtk_tree_path_new_first ();
+	n = 0;
+
+	while (gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, sort_path) == TRUE) {
+
+		if (sort_path != NULL) {
+			filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->tsk->tasks_sort), sort_path);
+
+			if (filter_path != NULL) {
+				path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter), filter_path);
+
+				if (path != NULL) {
+					gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, path);
+					gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
+										TA_COLUMN_DUE_DATE_JULIAN, &date, -1);
+					if (date != 0) n++;
+					gtk_tree_path_free (path);
+				}
+				gtk_tree_path_free (filter_path);
+			}
+		}
+		gtk_tree_path_next (sort_path);
+	}
+
+	return n;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+add_item_to_list (TASK_ITEM *item, GUI *appGUI)
+{
+	GtkTreeIter iter;
+	GdkPixbuf *image;
+	GtkWidget *helper;
+	const gchar *stock_id;
+	gchar *date_time_str;
 
 	gtk_list_store_append (appGUI->tsk->tasks_list_store, &iter);
 
@@ -726,10 +691,10 @@ const gchar *stock_id;
 	                    TA_COLUMN_CATEGORY, item->category,
 	                    TA_COLUMN_SUMMARY, item->summary,
 	                    TA_COLUMN_DESCRIPTION, item->desc,
+	                    TA_COLUMN_SOUND_ENABLE, item->sound_enable,
 	                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, item->done, appGUI),
 	                    TA_COLUMN_ACTIVE, item->active,
 	                    TA_COLUMN_OFFLINE_IGNORE, item->offline_ignore,
-	                    TA_COLUMN_ACTIVE_WARNING, item->active_warning,
 	                    TA_COLUMN_REPEAT, item->repeat,
 	                    TA_COLUMN_REPEAT_DAY, item->repeat_day,
 	                    TA_COLUMN_REPEAT_MONTH_INTERVAL, item->repeat_month_interval,
@@ -743,7 +708,7 @@ const gchar *stock_id;
 	                    TA_COLUMN_WARNING_DAYS, item->warning_days,
 	                    TA_COLUMN_WARNING_TIME, item->warning_time,
 	                    TA_COLUMN_POSTPONE_TIME, item->postpone_time,
-	                    TA_COLUMN_ID, appGUI->tsk->id_counter++,
+	                    TA_COLUMN_ID, item->id,
 	                    -1);
 
     helper = gtk_image_new ();
@@ -752,12 +717,9 @@ const gchar *stock_id;
     gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_TYPE, image, -1);
     g_object_unref (image);
 
-	if (item->due_date_julian == 0) {   /* use 'No date' text when due date is 0 */
-		gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DUE_DATE, _("No date"), -1);
-	} else {
-		gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
-		                    TA_COLUMN_DUE_DATE, get_date_time_full_str (item->due_date_julian, item->due_time));
-	}
+	date_time_str = utl_date_time_print_default (item->due_date_julian, item->due_time, FALSE);
+	gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DUE_DATE, date_time_str, -1);
+	g_free (date_time_str);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -773,7 +735,7 @@ list_dbclick_cb(GtkWidget * widget, GdkEventButton * event, gpointer func_data)
             if (config.add_edit == FALSE) {
                 tasks_edit_item_cb (NULL, appGUI);
             } else {
-                tasks_add_edit_dialog_show (FALSE, 0, get_seconds_for_today(), appGUI);
+				tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
             }
         } else {
             show_tasks_desc_panel(TRUE, appGUI);
@@ -799,7 +761,7 @@ gchar *category, *category_cf;
 
     gtk_tree_model_get(model, iter, TA_COLUMN_DONE, &done, TA_COLUMN_CATEGORY, &category, -1);
     
-    if (tasks_category_get_state (category, STATE_TASKS, appGUI) == FALSE) {
+    if (tsk_get_category_state (category, STATE_TASKS, appGUI) == FALSE) {
         g_free (category);
         return FALSE;
     }
@@ -874,7 +836,7 @@ gint due_time_a, due_time_b, due_time_s;
     if (!due_date_b) due_date_b = 1 << 31;
     due_date_s = due_date_b - due_date_a;
     due_time_s = due_time_b - due_time_a;
-    priority_s = get_priority_index (priority_a) - get_priority_index (priority_b);
+    priority_s = tsk_get_priority_index (priority_a) - tsk_get_priority_index (priority_b);
     g_free (priority_a);
     g_free (priority_b);
 
@@ -1029,6 +991,8 @@ tasks_selection_activate (gboolean active, GUI *appGUI) {
 void
 store_task_columns_info (GUI *appGUI) {
 
+	gint n;
+
 	config.tasks_column_idx_0 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_DONE], 
 															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
 	config.tasks_column_idx_1 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_TYPE], 
@@ -1042,12 +1006,64 @@ store_task_columns_info (GUI *appGUI) {
 	config.tasks_column_idx_5 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY], 
 															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
 
-	config.tasks_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0));
-	config.tasks_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1));
-	config.tasks_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2));
-	config.tasks_column_idx_3_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3));
-	config.tasks_column_idx_4_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4));
-	config.tasks_column_idx_5_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5));
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0));
+	if (n > 1) {
+		config.tasks_column_idx_0_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1));
+	if (n > 1) {
+		config.tasks_column_idx_1_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2));
+	if (n > 1) {
+		config.tasks_column_idx_2_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3));
+	if (n > 1) {
+		config.tasks_column_idx_3_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4));
+	if (n > 1) {
+		config.tasks_column_idx_4_width = n;
+	}
+	n = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5));
+	if (n > 1) {
+		config.tasks_column_idx_5_width = n;
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+set_tasks_columns_width (GUI *appGUI) {
+
+GtkTreeViewColumn   *col;
+
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_0_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_1_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_2_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_3_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_4_width);
+	}
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5);
+	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_5_width - 
+											  2 * utl_gui_get_sw_vscrollbar_width (appGUI->tsk->scrolled_win));
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1059,7 +1075,6 @@ GtkWidget           *vbox1;
 GtkWidget           *vbox2;
 GtkWidget           *table;
 GtkWidget           *label;
-GtkWidget           *top_scrolledwindow;
 GtkWidget           *hseparator;
 GtkWidget           *close_button;
 GtkCellRenderer     *renderer;
@@ -1078,10 +1093,17 @@ gint i, n;
 "    <separator name=\"sep1\" />\n"
 "    <toolitem name=\"delete\" action=\"delete\" />\n"
 "    <separator name=\"sep2\" />\n"
-"    <toolitem name=\"prev_day\" action=\"prev_day\" />\n"
-"    <toolitem name=\"next_day\" action=\"next_day\" />\n"
-#ifdef PRINTING_SUPPORT
+"    <toolitem name=\"prev_date\" action=\"prev_date\" />\n"
+"    <toolitem name=\"next_date\" action=\"next_date\" />\n"
 "    <separator name=\"sep3\" />\n"
+#if 0
+"    <toolitem name=\"import\" action=\"import\" />\n"
+#endif
+#ifdef HAVE_LIBICAL
+"    <toolitem name=\"export\" action=\"export\" />\n"
+#endif
+#ifdef PRINTING_SUPPORT
+"    <separator name=\"sep4\" />\n"
 "    <toolitem name=\"print\" action=\"print\" />\n"
 #endif /* PRINTING_SUPPORT */
 "  </toolbar>\n";
@@ -1090,8 +1112,14 @@ GtkActionEntry entries[] = {
   { "add", OSMO_STOCK_TASKS_ADD, _("New task"), NULL, _("New task"), NULL },
   { "edit", OSMO_STOCK_TASKS_EDIT, _("Edit task"), NULL, _("Edit task"), NULL },
   { "delete", OSMO_STOCK_TASKS_REMOVE, _("Remove task"), NULL, _("Remove task"), NULL },
-  { "prev_day", OSMO_STOCK_TASKS_PREV_DAY, _("Change due date to previous day"), NULL, _("Change due date to previous day"), NULL },
-  { "next_day", OSMO_STOCK_TASKS_NEXT_DAY, _("Change due date to next day"), NULL, _("Change due date to next day"), NULL },
+  { "prev_date", OSMO_STOCK_TASKS_PREV_DATE, _("Change due date to previous date"), NULL, _("Change due date to previous date"), NULL },
+  { "next_date", OSMO_STOCK_TASKS_NEXT_DATE, _("Change due date to next date"), NULL, _("Change due date to next date"), NULL },
+#if 0
+  { "import", OSMO_STOCK_TASKS_IMPORT, _("Import tasks"), NULL, _("Import tasks"), NULL },
+#endif
+#ifdef HAVE_LIBICAL
+  { "export", OSMO_STOCK_TASKS_EXPORT, _("Export tasks"), NULL, _("Export tasks"), NULL },
+#endif
 #ifdef PRINTING_SUPPORT
   { "print", OSMO_STOCK_PRINT, _("Print visible tasks list"), NULL, _("Print visible tasks list"), NULL },
 #endif /* PRINTING_SUPPORT */
@@ -1148,10 +1176,14 @@ guint n_entries = G_N_ELEMENTS (entries);
                       G_CALLBACK(tasks_edit_item_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete")), "clicked", 
                       G_CALLBACK(tasks_remove_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day")), "clicked", 
-                      G_CALLBACK(tasks_change_due_date_to_prev_day_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day")), "clicked", 
-                      G_CALLBACK(tasks_change_due_date_to_next_day_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date")), "clicked", 
+                      G_CALLBACK(tasks_change_due_date_to_prev_date_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date")), "clicked", 
+                      G_CALLBACK(tasks_change_due_date_to_next_date_cb), appGUI);
+#ifdef HAVE_LIBICAL
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/export")), "clicked", 
+                      G_CALLBACK(tasks_export_visible_items_cb), appGUI);
+#endif /* HAVE_LIBICAL */
 #ifdef PRINTING_SUPPORT
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print")), "clicked", 
                       G_CALLBACK(tasks_print_visible_items_cb), appGUI);
@@ -1161,8 +1193,8 @@ guint n_entries = G_N_ELEMENTS (entries);
 
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), FALSE);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), FALSE);
-    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), FALSE);
-    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), FALSE);
+    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date"), FALSE);
+    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date"), FALSE);
 #ifdef PRINTING_SUPPORT
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
 #endif /* PRINTING_SUPPORT */
@@ -1228,12 +1260,12 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_viewport_set_shadow_type (GTK_VIEWPORT (top_viewport), GTK_SHADOW_NONE);
     gtk_paned_pack1 (GTK_PANED (appGUI->tsk->tasks_paned), top_viewport, FALSE, TRUE);
 
-    top_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_show (top_scrolledwindow);
-    gtk_container_add (GTK_CONTAINER (top_viewport), top_scrolledwindow);
+    appGUI->tsk->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_show (appGUI->tsk->scrolled_win);
+    gtk_container_add (GTK_CONTAINER (top_viewport), appGUI->tsk->scrolled_win);
 
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (top_scrolledwindow), GTK_SHADOW_IN);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (top_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_SHADOW_IN);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
 	appGUI->tsk->tasks_list_store = gtk_list_store_new (TASKS_NUM_COLUMNS,
 	                                    G_TYPE_BOOLEAN, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INT,
@@ -1251,7 +1283,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->tsk->tasks_sort = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(appGUI->tsk->tasks_filter));
 
     appGUI->tsk->tasks_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->tsk->tasks_sort));
-    gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->tsk->tasks_list), config.tasks_rules_hint);
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(appGUI->tsk->tasks_list), config.rules_hint);
     gtk_widget_show (appGUI->tsk->tasks_list);
     GTK_WIDGET_SET_FLAGS (appGUI->tsk->tasks_list, GTK_CAN_DEFAULT);
     gtk_widget_modify_fg(GTK_WIDGET(appGUI->tsk->tasks_list), GTK_STATE_SELECTED,
@@ -1430,6 +1462,14 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_OFFLINE_IGNORE], FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_OFFLINE_IGNORE]);
 
+    renderer = gtk_cell_renderer_toggle_new();
+    appGUI->tsk->tasks_columns[TA_COLUMN_SOUND_ENABLE] = gtk_tree_view_column_new_with_attributes (NULL,
+                             renderer,
+                             "active", TA_COLUMN_SOUND_ENABLE,
+                             NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_SOUND_ENABLE], FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SOUND_ENABLE]);
+
     renderer = gtk_cell_renderer_toggle_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT] = gtk_tree_view_column_new_with_attributes (NULL,
                              renderer,
@@ -1563,22 +1603,11 @@ guint n_entries = G_N_ELEMENTS (entries);
 		}
 	}
 
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0),
-										  config.tasks_column_idx_0_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1),
-										  config.tasks_column_idx_1_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2),
-										  config.tasks_column_idx_2_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3),
-										  config.tasks_column_idx_3_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4),
-										  config.tasks_column_idx_4_width);
-	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5),
-										  config.tasks_column_idx_5_width - 2 * utl_gui_get_sw_vscrollbar_width (top_scrolledwindow));
+	set_tasks_columns_width (appGUI);
 
     /* configure list options */
 
-    gtk_container_add (GTK_CONTAINER (top_scrolledwindow), appGUI->tsk->tasks_list);
+    gtk_container_add (GTK_CONTAINER (appGUI->tsk->scrolled_win), appGUI->tsk->tasks_list);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->tsk->tasks_list), FALSE);
 
     /* configure sorting */
