@@ -35,6 +35,7 @@
 #define WHOLE_WEEK                  127
 
 typedef struct {
+	guint id;
     gboolean done;
     guint32 due_date_julian;
     gint due_time;
@@ -45,8 +46,8 @@ typedef struct {
     gchar *summary;
     gchar *desc;
 	gboolean active;
-	gboolean active_warning;
 	gboolean offline_ignore;
+	gboolean sound_enable;
 	gboolean repeat;
 	gint repeat_day;
 	gint repeat_month_interval;
@@ -79,9 +80,11 @@ void    tasks_select_first_position_in_list     (GUI *appGUI);
 void    apply_task_attributes                   (GUI *appGUI);
 void    refresh_tasks                           (GUI *appGUI);
 void    store_task_columns_info                 (GUI *appGUI);
+void    set_tasks_columns_width                 (GUI *appGUI);
 void    add_item_to_list                        (TASK_ITEM *item, GUI *appGUI);
 gchar*  get_date_color                          (guint32 julian_day, gint time, gboolean done, GUI *appGUI);
 void    tasks_selection_activate                (gboolean active, GUI *appGUI);
+guint   get_number_of_visible_tasks_with_date   (GUI *appGUI);
 
 #endif /* _TASKS_H */
 
