@@ -1,4 +1,3 @@
-
 /*
  * Osmo - a handy personal organizer
  *
@@ -19,122 +18,44 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "tasks_items.h"
-#include "i18n.h"
-#include "utils.h"
-#include "utils_gui.h"
-#include "options_gui.h"
-#include "options_prefs.h"
-#include "tasks.h"
 #include "calendar.h"
 #include "calendar_notes.h"
-#include "calendar_widget.h"
 #include "calendar_utils.h"
+#include "calendar_widget.h"
+#include "check_events.h"
+#include "i18n.h"
+#include "options_gui.h"
 #include "options_gui_tasks.h"
+#include "options_prefs.h"
 #include "stock_icons.h"
+#include "tasks.h"
+#include "tasks_items.h"
+#include "tasks_utils.h"
+#include "utils.h"
+#include "utils_gui.h"
+#include "utils_time.h"
 
 #ifdef TASKS_ENABLED
 
 /*------------------------------------------------------------------------------*/
 
-GtkTreeIter *
-task_get_iter (gint id, GUI *appGUI) {
-
-static GtkTreeIter iter;
-gint i, n;
-
-    i = 0;
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, TA_COLUMN_ID, &n, -1);
-        if (n == id) break;
-    }
-
-    if (n == id) {
-        return &iter;
-    } else {
-        return NULL;
-    }
-}
-
-/*------------------------------------------------------------------------------*/
-
-TASK_ITEM *
-get_task_item (GtkTreeIter *iter, GUI *appGUI) {
-
-TASK_ITEM *item;
-gchar *temp;
-
-	item = g_new0 (TASK_ITEM, 1);
-
-	if (item != NULL) {
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_DONE, &(item->done),
-		                    TA_COLUMN_DUE_DATE_JULIAN, &(item->due_date_julian),
-		                    TA_COLUMN_DUE_TIME, &(item->due_time),
-		                    TA_COLUMN_START_DATE_JULIAN, &(item->start_date_julian),
-		                    TA_COLUMN_DONE_DATE_JULIAN, &(item->done_date_julian),
-		                    TA_COLUMN_ACTIVE, &(item->active),
-		                    TA_COLUMN_ACTIVE_WARNING, &(item->active_warning),
-		                    TA_COLUMN_OFFLINE_IGNORE, &(item->offline_ignore),
-		                    TA_COLUMN_REPEAT, &(item->repeat),
-		                    TA_COLUMN_REPEAT_DAY, &(item->repeat_day),
-		                    TA_COLUMN_REPEAT_MONTH_INTERVAL, &(item->repeat_month_interval),
-		                    TA_COLUMN_REPEAT_DAY_INTERVAL, &(item->repeat_day_interval),
-		                    TA_COLUMN_REPEAT_START_DAY, &(item->repeat_start_day),
-		                    TA_COLUMN_REPEAT_TIME_START, &(item->repeat_time_start),
-		                    TA_COLUMN_REPEAT_TIME_END, &(item->repeat_time_end),
-		                    TA_COLUMN_REPEAT_TIME_INTERVAL, &(item->repeat_time_interval),
-		                    TA_COLUMN_REPEAT_COUNTER, &(item->repeat_counter),
-		                    TA_COLUMN_WARNING_DAYS, &(item->warning_days),
-		                    TA_COLUMN_WARNING_TIME, &(item->warning_time),
-		                    TA_COLUMN_POSTPONE_TIME, &(item->postpone_time),
-		                    -1);
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_PRIORITY, &temp, -1);
-		item->priority = g_strdup(temp);
-		g_free (temp);
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_ALARM_COMMAND, &temp, -1);
-		item->alarm_command = g_strdup(temp);
-		g_free (temp);
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_CATEGORY, &temp, -1);
-		item->category = g_strdup(temp);
-		g_free (temp);
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_SUMMARY, &temp, -1);
-		item->summary = g_strdup(temp);
-		g_free (temp);
-
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), iter,
-		                    TA_COLUMN_DESCRIPTION, &temp, -1);
-		item->desc = g_strdup(temp);
-		g_free (temp);
-
-	}
-
-	return item;
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
-task_item_free (TASK_ITEM *item)
+tsk_delete_notify (guint id, GUI *appGUI)
 {
-	if (item != NULL) {
-		if (item->alarm_command != NULL) g_free (item->alarm_command);
-		if (item->priority != NULL) g_free (item->priority);
-		if (item->category != NULL) g_free (item->category);
-		if (item->summary != NULL) g_free (item->summary);
-		if (item->desc != NULL) g_free (item->desc);
+#ifdef HAVE_LIBNOTIFY
+	GSList *node;
+	TASK_NTF *a;
 
-		g_free (item);
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
+		if (a->id == id) {
+			notify_notification_close (a->notify, NULL);
+			appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
+			g_free (a);
+			break;
+		}
 	}
+#endif /* HAVE_LIBNOTIFY */
 }
 
 /*------------------------------------------------------------------------------*/
@@ -147,6 +68,7 @@ GtkTextIter iter_a, iter_b;
 GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter iter;
 guint32 fstartdate;
+guint id;
 TASK_ITEM *item;
 GDate *cdate;
 gchar tmpbuf[BUFFER_SIZE];
@@ -154,7 +76,6 @@ gchar tmpbuf[BUFFER_SIZE];
     GUI *appGUI = (GUI *)data;
 
     item = g_new0 (TASK_ITEM, 1);
-    if (item == NULL) return;
 
     if (appGUI->tsk->tasks_edit_state == TRUE) {
 
@@ -171,7 +92,9 @@ gchar tmpbuf[BUFFER_SIZE];
                 if (path != NULL) {
                     gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path);
                     gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter,
+                               TA_COLUMN_ID, &id,
                                TA_COLUMN_START_DATE_JULIAN, &fstartdate, -1);
+                    /* FIXME */
                     gtk_list_store_remove(appGUI->tsk->tasks_list_store, &iter);
                     gtk_tree_path_free(path);
                 }
@@ -193,17 +116,14 @@ gchar tmpbuf[BUFFER_SIZE];
 
     if(appGUI->tsk->tasks_edit_state == TRUE) {
         item->start_date_julian = fstartdate;
+        item->id = id;
     } else {
-        item->start_date_julian = utl_get_current_julian ();
+        item->start_date_julian = utl_date_get_current_julian ();
+        item->id = appGUI->tsk->next_id++;
     }
 
-	if (is_date_in_the_past (item->due_date_julian, item->due_time, utl_get_current_julian (), get_seconds_for_today())) {
-		item->active = FALSE;
-		item->active_warning = FALSE;
-	} else {
-		item->active = TRUE;
-		item->active_warning = TRUE;
-	}
+	item->active = TRUE;
+	item->sound_enable = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable));
 
     item->repeat = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->rt_enable_checkbutton));
     item->offline_ignore = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->ignore_alarm_checkbutton));
@@ -232,12 +152,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	if (g_date_valid_julian (item->due_date_julian)) {
 		cdate = g_date_new_julian (item->due_date_julian);
-		if (cdate != NULL) {
-			item->repeat_start_day = g_date_get_day (cdate);
-		} else {
-		    task_item_free (item);
-			return;
-		}
+		item->repeat_start_day = g_date_get_day (cdate);
 		g_date_free (cdate);
 	} else {
 		item->repeat_start_day = 0;
@@ -253,7 +168,7 @@ gchar tmpbuf[BUFFER_SIZE];
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_7_checkbutton))) item->repeat_day |= 64;
 
     if (item->repeat == TRUE && item->repeat_day == 0) {
-        task_item_free (item);
+        tsk_item_free (item);
         g_snprintf (tmpbuf, BUFFER_SIZE, "%s", _("Please select at least one day when recurrency is enabled."));
         utl_gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW (appGUI->tsk->tasks_add_window));
         return;
@@ -261,6 +176,10 @@ gchar tmpbuf[BUFFER_SIZE];
 
     item->done_date_julian = 0;
 
+#ifdef HAVE_LIBNOTIFY
+	if (appGUI->tsk->tasks_edit_state)
+		tsk_delete_notify (id, appGUI);
+#endif /* HAVE_LIBNOTIFY */
     add_item_to_list (item, appGUI);
     gui_systray_tooltip_update(appGUI);
 
@@ -270,7 +189,7 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
     apply_task_attributes (appGUI);
 
-    task_item_free (item);
+    tsk_item_free (item);
     cal_refresh_marks (appGUI);
     update_aux_calendars (appGUI);
 
@@ -281,16 +200,17 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
-void
-tasks_date_related_set_state (gboolean state, GUI *appGUI) {
-
-    gtk_widget_set_sensitive (appGUI->tsk->aw_days_spinbutton, state);
-    gtk_widget_set_sensitive (appGUI->tsk->aw_hours_spinbutton, state);
-    gtk_widget_set_sensitive (appGUI->tsk->aw_minutes_spinbutton, state);
-    gtk_widget_set_sensitive (appGUI->tsk->postpone_spinbutton, state);
-    gtk_widget_set_sensitive (appGUI->tsk->alarm_cmd_entry, state);
-    gtk_widget_set_sensitive (appGUI->tsk->alarm_cmd_valid_image, state);
-    gtk_widget_set_sensitive (appGUI->tsk->rt_enable_checkbutton, state);
+static void
+tasks_date_related_set_state (gboolean state, GUI *appGUI)
+{
+	gtk_widget_set_sensitive (appGUI->tsk->checkb_sound_enable, state);
+	gtk_widget_set_sensitive (appGUI->tsk->aw_days_spinbutton, state);
+	gtk_widget_set_sensitive (appGUI->tsk->aw_hours_spinbutton, state);
+	gtk_widget_set_sensitive (appGUI->tsk->aw_minutes_spinbutton, state);
+	gtk_widget_set_sensitive (appGUI->tsk->postpone_spinbutton, state);
+	gtk_widget_set_sensitive (appGUI->tsk->alarm_cmd_entry, state);
+	gtk_widget_set_sensitive (appGUI->tsk->alarm_cmd_valid_image, state);
+	gtk_widget_set_sensitive (appGUI->tsk->rt_enable_checkbutton, state);
 	gtk_widget_set_sensitive (appGUI->tsk->rt_dp_day_spinbutton, state);
 	gtk_widget_set_sensitive (appGUI->tsk->repeat_counter_spinbutton, state);
 	gtk_widget_set_sensitive (appGUI->tsk->rt_dp_month_spinbutton, state);
@@ -322,23 +242,23 @@ tasks_time_related_set_state (gboolean state, GUI *appGUI) {
 /*------------------------------------------------------------------------------*/
 
 void
-day_selected_cb (GuiCalendar *calendar, gpointer user_data)
+day_selected_cb (GuiCalendar *calendar, GUI *appGUI)
 {
-guint day, month, year;
-TIME tm;
+	TIME *tm;
+	GDate *d = g_date_new ();
 
-	GUI *appGUI = (GUI *) user_data;
-
-	gui_calendar_get_date (calendar, &year, &month, &day);
-	appGUI->tsk->tasks_due_julian_day = utl_dmy_to_julian (day, month + 1, year);
+	gui_calendar_get_gdate (calendar, d);
+	appGUI->tsk->tasks_due_julian_day = g_date_get_julian (d);
+	g_date_free (d);
 
 	tasks_date_related_set_state (TRUE, appGUI);
 
 	if (gtk_expander_get_expanded (GTK_EXPANDER (appGUI->tsk->time_expander)) == TRUE) {
-		tm.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour));
-		tm.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute));
-		tm.second = 0;
-		appGUI->tsk->tasks_due_time = time_to_seconds (&tm);
+		tm = utl_time_new_hms (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour)),
+		                       gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute)),
+		                       0);
+		appGUI->tsk->tasks_due_time = utl_time_get_seconds (tm);
+		utl_time_free (tm);
 		tasks_time_related_set_state (TRUE, appGUI);
 	} else {
 		appGUI->tsk->tasks_due_time = -1;
@@ -353,9 +273,8 @@ TIME tm;
 /*------------------------------------------------------------------------------*/
 
 void
-close_calendar_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+close_calendar_cb (GtkWidget *widget, GdkEvent *event, GUI *appGUI)
 {
-	GUI *appGUI = (GUI *) user_data;
 	gtk_widget_destroy (appGUI->tsk->td_calendar_window);
 }
 
@@ -390,49 +309,35 @@ calendar_set_date (GDate *cdate, GUI *appGUI)
 /*------------------------------------------------------------------------------*/
 
 void
-set_today_calendar_cb (GtkWidget *widget, gpointer user_data)
+set_today_calendar_cb (GtkWidget *widget, GUI *appGUI)
 {
-GDate *cdate;
-
-	GUI *appGUI = (GUI *) user_data;
-	cdate = g_date_new ();
-	g_return_if_fail (cdate != NULL);
-
-	g_date_set_time_t (cdate, time (NULL));
-	calendar_set_date (cdate, appGUI);
-	g_date_free (cdate);
+	GDate *date = utl_date_new_current ();
+	calendar_set_date (date, appGUI);
+	g_date_free (date);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-set_tomorrow_calendar_cb (GtkWidget *widget, gpointer user_data)
+set_tomorrow_calendar_cb (GtkWidget *widget, GUI *appGUI)
 {
-GDate *cdate;
-
-	GUI *appGUI = (GUI *) user_data;
-	cdate = g_date_new ();
-	g_return_if_fail (cdate != NULL);
-
-	g_date_set_time_t (cdate, time (NULL));
-	g_date_add_days (cdate, 1);
-	calendar_set_date (cdate, appGUI);
-	g_date_free (cdate);
+	GDate *date = utl_date_new_current ();
+	g_date_add_days (date, 1);
+	calendar_set_date (date, appGUI);
+	g_date_free (date);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-nodate_calendar_cb (GtkWidget *widget, gpointer data) {
-
-    GUI *appGUI = (GUI *)data;
-
+nodate_calendar_cb (GtkWidget *widget, GUI *appGUI)
+{
     gtk_entry_set_text (GTK_ENTRY(appGUI->tsk->due_date_entry), _("No date"));
     appGUI->tsk->tasks_due_julian_day = 0;
     appGUI->tsk->tasks_due_time = -1;
     tasks_date_related_set_state (FALSE, appGUI);
     tasks_time_related_set_state (FALSE, appGUI);
-    close_calendar_cb (widget, NULL, data);
+    close_calendar_cb (widget, NULL, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -466,7 +371,7 @@ GtkWidget *ok_button;
 GtkWidget *table;
 GtkWidget *label;
 GtkObject *spinbutton_adjustment;
-DATE *dt;
+GDate *dt;
 TIME *tm;
 
     GUI *appGUI = (GUI *)data;
@@ -493,10 +398,9 @@ TIME *tm;
 
     appGUI->tsk->td_calendar = gui_calendar_new();
     gui_calendar_set_cursor_type (GUI_CALENDAR (appGUI->tsk->td_calendar), CURSOR_BLOCK);
-    gui_calendar_set_selector_alpha (GUI_CALENDAR (appGUI->tsk->td_calendar), config.selector_alpha);
-    gui_calendar_set_today_marker_type (GUI_CALENDAR (appGUI->tsk->td_calendar), config.today_marker_type);
-    gui_calendar_set_today_marker_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.mark_current_day_color);
-    gui_calendar_set_today_marker_alpha (GUI_CALENDAR (appGUI->tsk->td_calendar), config.mark_current_day_alpha);
+    gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.selection_color, config.selector_alpha, SELECTOR_COLOR);
+    gui_calendar_set_marker (GUI_CALENDAR (appGUI->tsk->td_calendar), config.today_marker_type, TODAY_MARKER);
+    gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.mark_current_day_color, config.mark_current_day_alpha, TODAY_MARKER_COLOR);
     gtk_widget_show (appGUI->tsk->td_calendar);
     g_signal_connect (GTK_OBJECT (appGUI->tsk->td_calendar), "day_selected_double_click",
                       G_CALLBACK (day_selected_cb), appGUI);
@@ -549,31 +453,20 @@ TIME *tm;
                       (GtkAttachOptions) (0), 0, 0);
 
     /* update status */
+	if (g_date_valid_julian (appGUI->tsk->tasks_due_julian_day)) {
+		dt = g_date_new_julian (appGUI->tsk->tasks_due_julian_day);
+		gui_calendar_select_month (GUI_CALENDAR (appGUI->tsk->td_calendar), g_date_get_month (dt) - 1, g_date_get_year (dt));
+		gui_calendar_select_day (GUI_CALENDAR (appGUI->tsk->td_calendar), g_date_get_day (dt));
+		g_date_free (dt);
 
-    if (appGUI->tsk->tasks_due_julian_day != 0) {
-
-        dt = julian_to_date(appGUI->tsk->tasks_due_julian_day);
-
-        if (dt != NULL) {
-
-            gui_calendar_select_month (GUI_CALENDAR (appGUI->tsk->td_calendar), dt->month-1, dt->year);
-            gui_calendar_select_day (GUI_CALENDAR (appGUI->tsk->td_calendar), dt->day);
-            g_free (dt);
-
-            if (appGUI->tsk->tasks_due_time >= 0) {
-
-                tm = seconds_to_time (appGUI->tsk->tasks_due_time);
-
-                if (tm != NULL) {
-                    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour), tm->hour);
-                    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute), tm->minute);
-
-                    gtk_expander_set_expanded (GTK_EXPANDER(appGUI->tsk->time_expander), TRUE);
-                    g_free (tm);
-                }
-            }
-        }
-    }
+		if (appGUI->tsk->tasks_due_time >= 0) {
+			tm = utl_time_new_seconds (appGUI->tsk->tasks_due_time);
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour), utl_time_get_hour (tm));
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute), utl_time_get_minute (tm));
+			gtk_expander_set_expanded (GTK_EXPANDER (appGUI->tsk->time_expander), TRUE);
+			utl_time_free (tm);
+		}
+	}
 
     /* auxilary buttons */
 
@@ -686,6 +579,7 @@ gint response;
 GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter iter;
 gchar tmpbuf[BUFFER_SIZE];
+guint id;
 
     gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
 
@@ -705,6 +599,11 @@ gchar tmpbuf[BUFFER_SIZE];
 
                 if (response == GTK_RESPONSE_YES) {
                     gtk_tree_model_get_iter (GTK_TREE_MODEL(list_store), &iter, path);
+                    gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
+                                        TA_COLUMN_ID, &id, -1);
+#ifdef HAVE_LIBNOTIFY
+                    tsk_delete_notify (id, appGUI);
+#endif /* HAVE_LIBNOTIFY */
                     gtk_list_store_remove (list_store, &iter);
                     gtk_tree_path_free (path);
                     tasks_select_first_position_in_list (appGUI);
@@ -963,6 +862,28 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->tsk->desc_textview);
     gtk_container_add (GTK_CONTAINER (scrolledwindow), appGUI->tsk->desc_textview);
 
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, TRUE, 2);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+
+    appGUI->tsk->checkb_sound_enable = gtk_check_button_new_with_mnemonic (_("Enable sound notification"));
+    gtk_widget_show (appGUI->tsk->checkb_sound_enable);
+    gtk_container_add (GTK_CONTAINER (alignment), appGUI->tsk->checkb_sound_enable);
+    gtk_widget_set_sensitive (appGUI->tsk->checkb_sound_enable, FALSE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable), TRUE);
+
+    g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Options"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
 	/* Second Tab */
 
     vbox5 = gtk_vbox_new (FALSE, 0);
@@ -1030,7 +951,7 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    aw_days_spinbutton_adj = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    aw_days_spinbutton_adj = gtk_adjustment_new (0, 0, 10000, 1, 10, 0);
     appGUI->tsk->aw_days_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (aw_days_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->aw_days_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->aw_days_spinbutton, 1, 2, 0, 1,
@@ -1252,14 +1173,14 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    rt_end_hour_spinbutton_adj = gtk_adjustment_new (0, 0, 23, 1, 10, 0);
+    rt_end_hour_spinbutton_adj = gtk_adjustment_new (23, 0, 23, 1, 10, 0);
     appGUI->tsk->rt_end_hour_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (rt_end_hour_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->rt_end_hour_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->rt_end_hour_spinbutton, 0, 1, 1, 2,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    rt_end_minute_spinbutton_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 0);
+    rt_end_minute_spinbutton_adj = gtk_adjustment_new (59, 0, 59, 1, 10, 0);
     appGUI->tsk->rt_end_minute_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (rt_end_minute_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->rt_end_minute_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->rt_end_minute_spinbutton, 1, 2, 1, 2,
@@ -1336,21 +1257,21 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_box_pack_start (GTK_BOX (vbox3), table, FALSE, TRUE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
-    rt_dp_day_spinbutton_adj = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    rt_dp_day_spinbutton_adj = gtk_adjustment_new (0, 0, 100000, 1, 10, 0);
     appGUI->tsk->rt_dp_day_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (rt_dp_day_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->rt_dp_day_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->rt_dp_day_spinbutton, 1, 2, 0, 1,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    rt_dp_month_spinbutton_adj = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    rt_dp_month_spinbutton_adj = gtk_adjustment_new (0, 0, 10000, 1, 10, 0);
     appGUI->tsk->rt_dp_month_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (rt_dp_month_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->rt_dp_month_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->rt_dp_month_spinbutton, 3, 4, 0, 1,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    repeat_counter_spinbutton_adj = gtk_adjustment_new (0, 0, 999999, 1, 10, 0);
+    repeat_counter_spinbutton_adj = gtk_adjustment_new (0, 0, 10000, 1, 10, 0);
     appGUI->tsk->repeat_counter_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (repeat_counter_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->tsk->repeat_counter_spinbutton);
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->repeat_counter_spinbutton, 5, 6, 0, 1,
@@ -1540,7 +1461,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
                     gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path);
 
-                    item = get_task_item (&iter, appGUI);
+                    item = tsk_get_item (&iter, appGUI);
 
                     if (item != NULL) {
 
@@ -1556,7 +1477,7 @@ gchar tmpbuf[BUFFER_SIZE];
 						                          utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, 
 																					 item->category));
 						gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->priority_combobox),
-						                          get_priority_index (item->priority));
+						                          tsk_get_priority_index (item->priority));
 
                         gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
 
@@ -1602,6 +1523,8 @@ gchar tmpbuf[BUFFER_SIZE];
 							                              item->repeat);
 							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->ignore_alarm_checkbutton),
 							                              item->offline_ignore);
+							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable),
+							                              item->sound_enable);
 
                             if (item->alarm_command) {
                                 gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->alarm_cmd_entry), item->alarm_command);
@@ -1633,7 +1556,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
                         }
 
-                        task_item_free (item);
+                        tsk_item_free (item);
 
                     }
 
@@ -1667,6 +1590,8 @@ gchar *calendar_prop, *tasks_prop;
 gboolean calendar_state, tasks_state;
 TASK_ITEM *item;
 gint priority_n;
+gchar *prop;
+gint tasks_version;
 
 	if (g_file_test (prefs_get_config_filename (TASKS_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE)
 		return;
@@ -1681,6 +1606,13 @@ gint priority_n;
 		if (xmlStrcmp (node->name, (const xmlChar *) TASKS_NAME)) {
 			xmlFreeDoc (doc);
 			return;
+		} else {
+			prop = (gchar *) xmlGetProp (node, (const xmlChar *) "version");
+			if (prop != NULL) {
+				tasks_version = atoi (prop);
+				xmlFree (prop);
+			} else
+				tasks_version = 0;
 		}
 
 		main_node = node->xmlChildrenNode;
@@ -1734,9 +1666,9 @@ gint priority_n;
 						item = g_new0 (TASK_ITEM, 1);
 						if (item == NULL) continue;
 
+						item->id = 0;
 						item->done = FALSE;
-						item->active = FALSE;
-						item->active_warning = FALSE;
+						item->active = TRUE;
 						item->offline_ignore = FALSE;
 						item->repeat = FALSE;
 						item->repeat_day = 127;
@@ -1759,16 +1691,17 @@ gint priority_n;
 						item->category = NULL;
 						item->summary = NULL;
 						item->desc = NULL;
+						item->sound_enable = TRUE;
 						priority_n = MEDIUM_PRIORITY;
 
 						while (cnode != NULL) {
+							utl_xml_get_uint ("id", &(item->id), cnode);
 							utl_xml_get_int ("status", &(item->done), cnode);
 							utl_xml_get_uint ("due_date", &(item->due_date_julian), cnode);
 							utl_xml_get_int ("due_time", &(item->due_time), cnode);
 							utl_xml_get_uint ("start_date", &(item->start_date_julian), cnode);
 							utl_xml_get_uint ("done_date", &(item->done_date_julian), cnode);
 							utl_xml_get_int ("active", &(item->active), cnode);
-							utl_xml_get_int ("active_warning", &(item->active_warning), cnode);
 							utl_xml_get_int ("offline_ignore", &(item->offline_ignore), cnode);
 							utl_xml_get_int ("repeat", &(item->repeat), cnode);
 							utl_xml_get_int ("repeat_day", &(item->repeat_day), cnode);
@@ -1782,6 +1715,7 @@ gint priority_n;
 							utl_xml_get_int ("warning_days", &(item->warning_days), cnode);
 							utl_xml_get_int ("warning_time", &(item->warning_time), cnode);
 							utl_xml_get_int ("postpone_time", &(item->postpone_time), cnode);
+							utl_xml_get_int ("sound_enable", &(item->sound_enable), cnode);
 							utl_xml_get_int ("priority", &priority_n, cnode);
 							utl_xml_get_str ("alarm_command", &(item->alarm_command), cnode);
 							utl_xml_get_str ("category", &(item->category), cnode);
@@ -1791,24 +1725,34 @@ gint priority_n;
 						}
 
 						if (item->summary != NULL) {
-							item->priority = g_strdup (get_priority_text (priority_n));
+							item->priority = g_strdup (tsk_get_priority_text (priority_n));
 
 							if (item->due_date_julian == 0) {
 								item->due_time = -1;
 								item->warning_days = 0;
 								item->warning_time = 0;
 								item->repeat = FALSE;
-								item->active = FALSE;
-								item->active_warning = FALSE;
+								item->active = TRUE;
 								item->postpone_time = 0;
 							} else if (item->due_time == -1){
 								item->warning_time = 0;
 							}
 
+							if (tasks_version < 208)
+								item->active = TRUE;
+
+							if (item->id == 0) {
+
+								g_return_if_fail (tasks_version < 208);
+								item->id = appGUI->tsk->next_id++;
+
+							} else if (item->id >= appGUI->tsk->next_id)
+								appGUI->tsk->next_id = item->id + 1;
+
 							add_item_to_list (item, appGUI);
 						}
 
-						task_item_free (item);
+						tsk_item_free (item);
 					}
 
 					node = node->next;
@@ -1848,8 +1792,10 @@ xmlChar *escaped;
 
 	doc = xmlNewDoc ((const xmlChar *) "1.0");
 	attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
+	xmlFree (attr);
 
 	main_node = xmlNewNode (NULL, (const xmlChar *) TASKS_NAME);
+	attr = xmlNewProp (main_node, (const xmlChar *) "version", (const xmlChar *) appGUI->version);
 	xmlDocSetRootElement (doc, main_node);
 
 	node = xmlNewChild (main_node, NULL, (const xmlChar *) TASKS_CATEGORY_ENTRIES_NAME, (xmlChar *) NULL);
@@ -1881,18 +1827,18 @@ xmlChar *escaped;
 	i = 0;
 
 	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
-		item = get_task_item (&iter, appGUI);
+		item = tsk_get_item (&iter, appGUI);
 
 		if (item != NULL) {
 			note_node = xmlNewChild (node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
 
+			utl_xml_put_int ("id", item->id, note_node);
 			utl_xml_put_int ("status", item->done, note_node);
 			utl_xml_put_uint ("due_date", item->due_date_julian, note_node);
 			utl_xml_put_int ("due_time", item->due_time, note_node);
 			utl_xml_put_uint ("start_date", item->start_date_julian, note_node);
 			utl_xml_put_uint ("done_date", item->done_date_julian, note_node);
 			utl_xml_put_int ("active", item->active, note_node);
-			utl_xml_put_int ("active_warning", item->active_warning, note_node);
 			utl_xml_put_int ("offline_ignore", item->offline_ignore, note_node);
 			utl_xml_put_int ("repeat", item->repeat, note_node);
 			utl_xml_put_int ("repeat_day", item->repeat_day, note_node);
@@ -1906,13 +1852,14 @@ xmlChar *escaped;
 			utl_xml_put_int ("warning_days", item->warning_days, note_node);
 			utl_xml_put_int ("warning_time", item->warning_time, note_node);
 			utl_xml_put_int ("postpone_time", item->postpone_time, note_node);
-			utl_xml_put_int ("priority", get_priority_index (gettext (item->priority)), note_node);
+			utl_xml_put_int ("sound_enable", item->sound_enable, note_node);
+			utl_xml_put_int ("priority", tsk_get_priority_index (gettext (item->priority)), note_node);
 			utl_xml_put_str ("alarm_command", item->alarm_command, note_node, doc);
 			utl_xml_put_str ("category", item->category, note_node, doc);
 			utl_xml_put_str ("summary", item->summary, note_node, doc);
 			utl_xml_put_str ("description", item->desc, note_node, doc);
 
-			task_item_free (item);
+			tsk_item_free (item);
 		}
 	}
 
