@@ -2,7 +2,8 @@
 /*
  * Osmo - a handy personal organizer
  *
- * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
+ * Copyright (C) 2007-2009 Tomasz Mąka <pasp@users.sourceforge.net>
+ *               2007-2009 Piotr Mąka <silloz@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,25 +28,19 @@
 enum helpers {
     UNKNOWN = 0,
     WWW,
-    EMAIL
+    EMAIL,
+    SOUND
 };
 
-guint       utl_get_current_day                 (void);
-guint       utl_get_current_month               (void);
-guint       utl_get_current_year                (void);
-guint32     utl_get_current_julian              (void);
+gchar *     utl_text_replace                    (const gchar *text, const gchar *regex, const gchar *replacement);
 gchar *     utl_get_day_name                    (guint day, gboolean short_name);
 gchar *     utl_get_julian_day_name             (guint32 julian);
-gchar *     utl_get_date_name                   (GDate *date);
-guint       utl_get_days_in_month               (GDate *date);
-guint       utl_get_weekend_days_in_month       (GDate *date);
+gchar *     utl_get_date_name                   (const GDate *date);
+guint       utl_get_weekend_days_in_month       (const GDate *date);
 guint       utl_get_weekend_days_in_month_my    (guint month, guint year);
 guint       utl_get_days_per_year               (guint year);
-void        utl_gdate_to_dmy                    (GDate *date, gint *day, gint *month, gint *year);
-void        utl_julian_to_dmy                   (guint32 julian, guint *day, guint *month, guint *year);
 void        utl_subtract_from_date              (guint32 date, gint time, gint days, gint seconds, guint32 *new_date, gint *new_time);
-guint32     utl_dmy_to_julian                   (guint day, guint month, guint year);
-guint       utl_calc_moon_phase                 (GDate *date);
+guint       utl_calc_moon_phase                 (const GDate *date);
 gchar *     utl_get_moon_phase_name             (gint phase);
 
 void        utl_xml_get_int                     (gchar *name, gint *iname, xmlNodePtr node);
@@ -61,7 +56,7 @@ void        utl_xml_put_strn                    (gchar *name, gchar *string, gin
 
 void        utl_name_strcat                     (gchar *first, gchar *second, gchar *buffer);
 gboolean    utl_run_helper                      (gchar *parameter, gint helper);
-void        utl_run_command                     (gchar *command);
+void        utl_run_command                     (gchar *command, gboolean sync);
 gboolean    utl_is_valid_command                (gchar *command);
 gint        utl_get_link_type                   (gchar *link);
 
@@ -70,5 +65,8 @@ void        utl_cairo_draw                      (cairo_t *cr, gint stroke);
 void        utl_draw_rounded_rectangle          (cairo_t *cr, gint x, gint y, gint w, gint h, gint a, gint s);
 void        utl_draw_left_arrow                 (cairo_t *cr, gdouble x, gdouble y, gdouble w, gdouble h, gdouble a);
 
+void        utl_play_alarm_sound                (guint repetitions);
+gchar *     utl_add_timestamp_to_filename       (gchar *filename, gchar *extension);
+
 #endif /* _UTILS_H */
 
