@@ -1,4 +1,3 @@
-
 /*
  * Osmo - a handy personal organizer
  *
@@ -82,21 +81,21 @@ utl_gui_font_select_cb (GtkWidget *widget, gpointer user_data)
 /*------------------------------------------------------------------------------*/
 
 gint
-utl_gui_get_sw_vscrollbar_width (GtkWidget *scrolled_window) {
+utl_gui_get_sw_vscrollbar_width (GtkWidget *scrolled_window)
+{
+	GtkWidget *vscrollbar;
+	GValue *value;
+	gint width;
 
-GtkWidget *vscrollbar;
-gint width;
-GValue *value;
-
-    value = g_new0 (GValue, 1);
+	value = g_new0 (GValue, 1);
 	value = g_value_init (value, G_TYPE_INT);
 
-    vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (scrolled_window));
-    gtk_widget_style_get_property (vscrollbar, "slider-width", value);
-    width = g_value_get_int (value);
+	vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (scrolled_window));
+	gtk_widget_style_get_property (vscrollbar, "slider-width", value);
+	width = g_value_get_int (value);
 
 	g_value_unset (value);
-    g_free (value);
+	g_free (value);
 
 	return width;
 }
@@ -217,7 +216,7 @@ gboolean done = FALSE;
 /*------------------------------------------------------------------------------*/
 
 void
-utl_gui_text_buffer_set_text_with_tags (GtkTextBuffer *buffer, const gchar *text) {
+utl_gui_text_buffer_set_text_with_tags (GtkTextBuffer *buffer, const gchar *text, gboolean clear) {
 
 GtkTextIter start, end;
 GList *tags = NULL;
@@ -227,11 +226,13 @@ gchar tag_char_utf8[7] = {0};
 
     if (!text)
         return;
-
+			
     gtk_text_buffer_begin_user_action (GTK_TEXT_BUFFER (buffer));
 
-    gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
-    gtk_text_buffer_delete (GTK_TEXT_BUFFER (buffer), &start, &end);
+	if (clear == TRUE) {
+        gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
+	    gtk_text_buffer_delete (GTK_TEXT_BUFFER (buffer), &start, &end);
+	}
     gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
 
     g_unichar_to_utf8 (TAG_CHAR, tag_char_utf8);
@@ -279,6 +280,97 @@ gchar tag_char_utf8[7] = {0};
 
 /*------------------------------------------------------------------------------*/
 
+void
+utl_gui_text_buffer_toggle_tags (GtkTextBuffer *buffer, const gchar *tag_name) {
+
+GtkTextTagTable *tag_table;
+GtkTextTag *tag;
+GtkTextIter start, end, titer;
+gboolean itagged;
+	
+	tag_table = gtk_text_buffer_get_tag_table (buffer);
+	tag = gtk_text_tag_table_lookup (tag_table, tag_name);
+	
+	g_return_if_fail (tag != NULL);
+
+	gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
+	
+	itagged = TRUE;
+
+	for (titer = start; !gtk_text_iter_equal (&titer, &end); gtk_text_iter_forward_char (&titer)) {
+		if ((itagged = gtk_text_iter_has_tag (&titer, tag)) == FALSE) {
+			break;
+		}
+	}
+	
+	if (itagged) {
+		gtk_text_buffer_remove_tag (buffer, tag, &start, &end);
+	} else {
+		gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+gchar *
+utl_gui_text_strip_tags (gchar *text) {
+
+gchar *output = g_strdup(""), *oldoutput = NULL;
+gchar tag_char_utf8[7] = {0};
+GList *tags = NULL;
+gchar **tokens;
+gint count;
+
+	g_return_val_if_fail (output != NULL, NULL);
+
+    g_unichar_to_utf8 (TAG_CHAR, tag_char_utf8);
+
+    tokens = g_strsplit (text, tag_char_utf8, 0);
+
+    for (count = 0; tokens[count]; count++)
+    {
+        if (count % 2 == 0)
+        {
+			oldoutput = output;
+	        output = g_strconcat (output, tokens[count], NULL);
+            g_free (oldoutput);
+        }
+        else
+        {
+            if (tokens[count][0] != '/')
+            {
+                tags = g_list_prepend (tags, tokens[count]);
+            }
+            else
+            {
+                GList *element = g_list_find_custom (tags, &(tokens[count][1]), (GCompareFunc) g_ascii_strcasecmp);
+
+                if (element)
+                {
+                    tags = g_list_delete_link (tags, element);
+                }
+            }
+        }
+    }
+
+    g_strfreev (tokens);
+
+	return output;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+utl_gui_text_buffer_remove_all_tags (GtkTextBuffer *buffer) {
+
+GtkTextIter start, end;
+
+	gtk_text_buffer_get_bounds (buffer, &start, &end);
+	gtk_text_buffer_remove_all_tags (buffer, &start, &end);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 utl_gui_change_bg_widget_state (GtkWidget *widget, gchar *color_str, GUI *appGUI) {
 
@@ -410,7 +502,7 @@ gint response = -1;
     if (info_dialog != NULL) {
         gtk_widget_show (info_dialog);
         response = gtk_dialog_run(GTK_DIALOG(info_dialog));
-        gtk_widget_destroy(info_dialog);
+        gtk_widget_destroy (info_dialog);
     }
 
     return response;
@@ -826,6 +918,7 @@ GSList *tags = NULL, *tagp = NULL;
 GtkTextTag *tag;
 gchar *link;
 gint slink;
+gchar tmpbuf[BUFFER_SIZE];
 
     if (ev->type != GDK_BUTTON_RELEASE) {
         return FALSE;
@@ -855,9 +948,11 @@ gint slink;
         tag = tagp->data;
         slink = (gint) g_object_get_data (G_OBJECT (tag), "link");
 
+
         if (slink != 0) {
             link = g_slist_nth_data (links_list, slink);
-            utl_run_helper(link, utl_get_link_type(link));
+			g_snprintf (tmpbuf, BUFFER_SIZE, "\"%s\"", link);
+            utl_run_helper(tmpbuf, utl_get_link_type(link));
             break;
         }
     }
